@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: icontextoestudio.cpp 4076 2011-08-11 06:37:52Z carlos $
+ *  $Id: icontextoestudio.cpp 4575 2012-01-20 14:21:44Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -32,6 +32,7 @@
 
 #include <main/controllers/controladorcarga.h>
 #include <main/controllers/controladorlog.h>
+#include <export/tagsprivadoscomunes.h>
 
 
 
@@ -47,8 +48,6 @@
 #include <vtkPointData.h>
 #include <vtkCharArray.h>
 
-#define TAG_WIDGETS					    0xb
-#define UID_TAGS_PRIVADOS_COMUNES	 "100"
 #define _GINKGO_TRACE
 
 GNC::GCS::IContextoEstudio::IContextoEstudio()
@@ -555,7 +554,7 @@ const std::string GNC::GCS::IContextoEstudio::GetNombreMedico()
 	std::string nombre ("");
 	if(ModeloIntegracion.IsValid()) {
 		std::ostringstream ostr;
-		ostr<<ModeloIntegracion->Medico.apellido1 << '^' << ModeloIntegracion->Medico.apellido2 << '^' << ModeloIntegracion->Medico.nombre;
+		ostr<<ModeloIntegracion->Medico.apellido1 << ' ' << ModeloIntegracion->Medico.apellido2 << '^' << ModeloIntegracion->Medico.nombre;
 		nombre = ostr.str();
 	} else {
 		GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","NombreMedico",nombre);
@@ -643,6 +642,8 @@ void GNC::GCS::IContextoEstudio::SetModificadoFicheroActivo()
 
 void GNC::GCS::IContextoEstudio::SetModificado(const int indice)
 {
+	if (IgnorarModificaciones)
+		return;
 	if(indice<0 || indice >= (int)Ficheros.size())
 		return;
 
@@ -744,7 +745,10 @@ bool GNC::GCS::IContextoEstudio::GuardarUnDiagnostico()
 
 		Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[0]->RutaDiagnostico);
 
-		correcto  = correcto && wxCopyFile(pathTmp,FROMPATH( Ficheros[0]->RutaDiagnostico ));
+		if (!wxCopyFile(pathTmp,FROMPATH( Ficheros[0]->RutaDiagnostico ))) {
+			LOG_ERROR("IContextoEstudio", "error copying file " << stdPathTmp << " TO " << Ficheros[0]->RutaDiagnostico);
+			correcto = false;
+		}
 
 		wxRemoveFile(pathTmp);
 		#if defined(_WINDOWS)
@@ -876,7 +880,10 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 
 			Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[i]->RutaDiagnostico);
 
-			correcto  = correcto && wxCopyFile(pathTmp,FROMPATH( Ficheros[i]->RutaDiagnostico ));
+			if (!wxCopyFile(pathTmp,FROMPATH( Ficheros[i]->RutaDiagnostico ))) {
+				LOG_ERROR("IContextoEstudio", "error copying file " << stdPathTmp << " TO " << Ficheros[0]->RutaDiagnostico);
+				correcto = false;
+			}
 
 			wxRemoveFile(pathTmp);
 			#if defined(_WINDOWS)
@@ -1020,6 +1027,28 @@ void GNC::GCS::IContextoEstudio::GuardarWidgets(int indice)
 	delete []vectorWidgets;
 }
 
+bool GNC::GCS::IContextoEstudio::IsKeyImageActive()
+{
+	return IsKeyImage(IndiceFicheroActivo);
+}
+
+bool GNC::GCS::IContextoEstudio::IsKeyImage(int indice)
+{
+	GnkPtr<GIL::DICOM::TipoPrivateTags> pTagsPrivados = GetTagsPrivados(indice);
+	if (!pTagsPrivados.IsValid())
+		return false;
+
+	if (ModoFuncionamiento == TMF_UNDiagnostico) {
+		indice = 0;
+	}
+	std::string isKey;
+	if (pTagsPrivados->GetTag(TAG_KEY_IMAGE, isKey)) {
+		return isKey.compare("YES") == 0;
+	} else {
+		return false;
+	}
+}
+
 void GNC::GCS::IContextoEstudio::CargarWidgetsActivo(bool force)
 {
 	CargarWidgets(IndiceFicheroActivo, force);
