@@ -11,6 +11,7 @@
  *
  */
 //#define _GINKGO_TRACE
+#include <wx/string.h>
 #include <api/globals.h>
 #include <main/controllers/configurationcontroller.h>
 #include "icontroladormodulo.h"
@@ -22,10 +23,6 @@ GNC::GCS::IControladorModulo::IControladorModulo(GNC::GCS::IEntorno* pEntorno, c
 {
 	m_pEntorno       = pEntorno;
 	m_UID            = uid;
-	m_VersionMayor   = 0;
-	m_VersionMinor   = 0;
-	m_VersionRelease = 0;
-	m_Bitmap         = NULL;
 	m_priority = priority;
 	GTRACE("IControladorModulo::IControladorModulo( " << m_UID << " )");
 }
