@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: icontroladormodulo.h 3963 2011-07-11 14:03:51Z tovar $
+ *  $Id: icontroladormodulo.h 4555 2012-01-17 10:03:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -224,16 +224,6 @@ namespace GNC {
 				return m_UID;
 			}
 
-			const wxBitmap* GetBitmap() {
-				return m_Bitmap;
-			}
-
-			/* Obtiene el Nombre del módulo (que aparece en el menú)*/
-			const std::string& GetNombre() const
-			{
-				return m_Nombre;
-			}
-
 			virtual bool SoportaImportacion() const
 			{
 				return false;
@@ -333,18 +323,8 @@ namespace GNC {
 			TipoMapaIdsHL7       m_ListaRegistros;
 
 			std::string m_UID;
-			std::string m_Nombre;
 			std::string m_ImporterDescription;
-			std::string m_CopyRight;
-			std::string m_Author;
-			int         m_VersionMayor;
-			int         m_VersionMinor;
-			int         m_VersionRelease;
-			std::string m_CodeName;
-			std::string m_Version;
 			int		    m_priority;
-
-			wxBitmap*   m_Bitmap;
 		};
 	}
 }
