@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: initwx.cpp 4406 2011-11-16 09:53:14Z tovar $
+ *  $Id: initwx.cpp 4491 2011-12-14 10:17:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -443,8 +443,10 @@ bool Ginkgo::OnInit()
 		GNC::ControladorHerramientas* cH = GNC::ControladorHerramientas::Instance();
 		try {
 			cH->RegistrarHerramienta(new GNC::HerramientaPuntero());
-			cH->RegistrarHerramienta(new GNC::HerramientaSlider());
-			cH->RegistrarHerramienta(new GNC::HerramientaWindowLevel());
+			cH->RegistrarHerramienta(new GNC::ToolZoom());
+			cH->RegistrarHerramienta(new GNC::ToolPan());
+			cH->RegistrarHerramienta(new GNC::ToolSlider());
+			cH->RegistrarHerramienta(new GNC::ToolWindowLevel());
 			cH->RegistrarHerramienta(new GNC::HerramientaRegla());
 			cH->RegistrarHerramienta(new GNC::HerramientaAngulo());
 			cH->RegistrarHerramienta(new GNC::HerramientaMarcado());
@@ -557,8 +559,10 @@ int Ginkgo::OnExit()
 	//desregistrar herramientas
 	GNC::GCS::IControladorHerramientas* cH = GNC::ControladorHerramientas::Instance();
 	GNC::GCS::IHerramientaPuntero*          hPuntero        = NULL;
-	GNC::GCS::IHerramientaSlider*           hSlider         = NULL;
-	GNC::GCS::IHerramientaWindowLevel*      hwl             = NULL;
+	GNC::GCS::IToolSlider*                  hSlider         = NULL;
+	GNC::GCS::IToolPan*                     hPan            = NULL;
+	GNC::GCS::IToolZoom*                    hZoom           = NULL;
+	GNC::GCS::IToolWindowLevel*             hwl             = NULL;
 	GNC::GCS::IHerramientaRegla*            hregla          = NULL;
 	GNC::GCS::IHerramientaAngulo*           hAngulo         = NULL;
 	GNC::GCS::IHerramientaMarcado*          hMarcado        = NULL;
@@ -580,12 +584,22 @@ int Ginkgo::OnExit()
 			cH->DesRegistrarHerramienta(hPuntero);
 			delete hPuntero;
 		}
-		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaSlider>(GNC::GCS::IHerramientaSlider::ID);
+		hPan = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolPan>(GNC::GCS::IToolPan::ID);
+		if (hPan != NULL) {
+			cH->DesRegistrarHerramienta(hPan);
+			delete hPan;
+		}
+		hZoom = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolZoom>(GNC::GCS::IToolZoom::ID);
+		if (hZoom != NULL) {
+			cH->DesRegistrarHerramienta(hZoom);
+			delete hZoom;
+		}		
+		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolSlider>(GNC::GCS::IToolSlider::ID);
 		if (hSlider != NULL) {
 			cH->DesRegistrarHerramienta(hSlider);
 			delete hSlider;
 		}
-		hwl = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaWindowLevel>(GNC::GCS::IHerramientaWindowLevel::ID);
+		hwl = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolWindowLevel>(GNC::GCS::IToolWindowLevel::ID);
 		if (hwl != NULL) {
 			cH->DesRegistrarHerramienta(hwl);
 			delete hwl;
@@ -757,8 +771,8 @@ void Ginkgo::WriteHeaderLog(){
 
 	version << GINKGO_CODENAME;
 
-	date=now.Format(wxT("%d/%m/%Y %H:%M:%S"),wxDateTime::CET);
+	date=now.Format(_("%d/%m/%Y %H:%M:%S"),wxDateTime::CET);
 
-	LOG_INFO("Core", "Arrancando Ginkgo " + version.str() + "    " + std::string(date.ToUTF8()));
+	LOG_INFO("Core", _Std("Starting Ginkgo CADx") + " " + version.str() + "    " + std::string(date.ToUTF8()));
 }
 //endregion
