@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandopacs.cpp 4338 2011-10-27 08:01:08Z tovar $
+*  $Id: comandopacs.cpp 4477 2011-12-13 11:16:56Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -330,57 +330,7 @@ namespace GADAPI
 		try {
 			pCI = GNC::Entorno::Instance()->GetPACSController();
 			pCI->GetConnection(this);
-			switch (m_pPACSParams->m_Ambito) {
-				case ComandoPACSParams::TA_Estudio:
-					{
-						if(m_pPACSParams->m_studyUID != "") {
-							GTRACE("Descargando estudio " << m_pPACSParams->m_estudioID);
-							std::stringstream ostr;
-							ostr << _Std("Downloading Study") ;
-							ostr << '1';
-							ostr << _Std(" of ");
-							ostr<<  '1';
-							std::string mensaje = ostr.str();
-							if (!NotificarProgreso(0.5f,mensaje)) {
-								 return;
-							}
-							pCI->ObtenerEstudio(this, m_pPACSParams->m_serverSeleccionado, m_pPACSParams->m_studyUID, m_pPACSParams->m_accessionNumber, m_pPACSParams->m_pModelo, this);
-						} else {
-							for(std::list<std::string>::iterator it = m_pPACSParams->m_listaUID.begin();it!= m_pPACSParams->m_listaUID.end(); it++) {
-								std::string uidEstudio = (*it);
-								GTRACE("Descargando estudio " << uidEstudio);
-								pCI->ObtenerEstudio(this, m_pPACSParams->m_serverSeleccionado, uidEstudio, m_pPACSParams->m_accessionNumber, m_pPACSParams->m_pModelo, this);
-							}
-						}
-					}
-					break;
-				case ComandoPACSParams::TA_Serie:
-					{
-						for(std::list<std::string>::iterator it = m_pPACSParams->m_listaUID.begin();it!= m_pPACSParams->m_listaUID.end(); it++) {
-							std::string uidSerie = (*it);
-							GTRACE(_Std("Downloading series ") << uidSerie << " " << _Std("study") << m_pPACSParams->m_estudioID);
-							pCI->ObtenerSerie(this, m_pPACSParams->m_serverSeleccionado, uidSerie, m_pPACSParams->m_pModelo, this);
-						}
-					}
-					break;
-				case ComandoPACSParams::TA_Imagen:
-					{
-						for(std::list<std::string>::iterator it = m_pPACSParams->m_listaUID.begin();it!= m_pPACSParams->m_listaUID.end(); it++) {
-							std::string uidImagen = (*it);
-							GTRACE("Descargando imagen " << uidImagen);
-							pCI->ObtenerImagen(this, m_pPACSParams->m_serverSeleccionado, uidImagen, m_pPACSParams->m_pModelo, this);
-						}
-					}
-					break;
-				case ComandoPACSParams::TA_NotSpecified:
-					{
-						pCI->QueryRetrieve(this, m_pPACSParams->m_serverSeleccionado, m_pPACSParams->m_pModelo, m_pPACSParams->m_base, this);
-					}
-					break;
-				default:
-					throw GIL::DICOM::PACSException(_Std("Unsupported scope"));
-			}
-
+			pCI->QueryRetrieve(this, m_pPACSParams->m_serverSeleccionado, m_pPACSParams->m_pModelo, m_pPACSParams->m_base, this);
 		}
 		catch (GinkgoNoServerFoundException& ) {
 			GTRACE("excepcion no server found... " << this);
