@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: exporttodicomdircommand.cpp 4410 2011-11-18 08:34:07Z tovar $
+*  $Id: exporttodicomdircommand.cpp 4575 2012-01-20 14:21:44Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -27,6 +27,7 @@
 #include <main/controllers/configurationcontroller.h>
 #include <main/controllers/controladorhistorial.h>
 #include <main/controllers/dcmtk/dicommanager.h>
+#include <main/controllers/controladorlog.h>
 #include <main/entorno.h>
 
 #include <api/globals.h>
@@ -41,12 +42,13 @@
 #include "comandomergediagnosticwithimage.h"
 
 
-
+#define IDC_EXPORT_TO_DICOMDIR           118
 
 namespace GADAPI {
 
 	ExportToDicomDirCommand::ExportToDicomDirCommand(ExportToDicomDirCommandParams* pParams): GNC::GCS::IComando(pParams,"Export Dicom Dir")
 	{
+		SetId(IDC_EXPORT_TO_DICOMDIR);
 		m_pExportacionParams = pParams;
 	}
 
@@ -187,6 +189,26 @@ namespace GADAPI {
 		if (!NotificarProgreso(0.0, _Std("Exporting files...")) )
 			return;
 
+		std::string pathOfDicomDir;
+		{
+			std::ostringstream ostr;
+			ostr << m_pExportacionParams->m_destinationPath;
+			ostr << (char)wxFileName::GetPathSeparator();
+			ostr << "DICOMDIR";
+			pathOfDicomDir = ostr.str();
+		}
+
+		//clean dicomdir file and dicomdir directory if present...
+		{
+			std::ostringstream ostr;
+			ostr << m_pExportacionParams->m_destinationPath;
+			ostr << (char) wxFileName::GetPathSeparator();
+			ostr << "DICOM";
+			GNC::Entorno::Instance()->RemoveDirRecursive(ostr.str());
+			wxRemoveFile(FROMPATH(pathOfDicomDir));
+		}
+		//
+
 		std::map<std::string, int> mapOfPathPatients;
 		std::map<std::string, int> mapOfPathStudies;
 		std::map<std::string, int> mapOfPathSeries;
@@ -203,15 +225,6 @@ namespace GADAPI {
 		int numberOfSeries = m_pExportacionParams->m_seriesList.size() + m_pExportacionParams->m_diagnosticList.size();
 		int actualSerie = 1;
 
-		std::string pathOfDicomDir;
-		{
-			std::ostringstream ostr;
-			ostr << m_pExportacionParams->m_destinationPath;
-			ostr << (char)wxFileName::GetPathSeparator();
-			ostr << "DICOMDIR";
-			pathOfDicomDir = ostr.str();
-		}
-
 		DcmDicomDir dicomDir(pathOfDicomDir.c_str(), "GINKGOCADXCD");
 		DcmDirectoryRecord *   root = &(dicomDir.getRootRecord());
 		
@@ -261,6 +274,7 @@ namespace GADAPI {
 					wxString pathOfImageWx = fullPathWx + wxFileName::GetPathSeparator() + wxString::FromUTF8(pathOfImage.c_str());
 					std::string absolutepathFile = GNC::Entorno::Instance()->GetPathAbsolutoFichero((*itDCMModels).m_pathRelativo);
 					if (!wxCopyFile(FROMPATH(absolutepathFile),  pathOfImageWx)) {
+						LOG_ERROR("ExportToDicomDirCommand", "Error copying file " << absolutepathFile << " TO " << pathOfImageWx.ToUTF8());
 						m_pExportacionParams->m_Error = _Std("There was an error writing file");
 						m_pExportacionParams->m_hasError = true;
 						return;
@@ -334,8 +348,6 @@ namespace GADAPI {
 				cmd.Execute();
 			}			
 		}
-		//Anonymize...
-		//TODO!!
 		//read tmp directory and insert into dcmdir...
 		{
 			wxString tmpDirWx = FROMPATH(m_TmpDir);
