@@ -128,7 +128,10 @@ public:
 
 
     void SetOptOn(int level, int opt)
-        { int on = 1; setsockopt(m_sockfd, level, opt, (char*)on, sizeof(on)); }
+    { 
+		 char tmp = (char) opt;
+		 int on = 1; setsockopt(m_sockfd, level, opt, (char*)tmp, sizeof(on)); 
+	 }
 
     void AddBytesRecv(int n) { m_bytes_recv += n; g_bytes_recv += n; }
     void AddBytesSent(int n) { m_bytes_sent += n; g_bytes_sent += n; }
