@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: icontratoscore.h 3905 2011-06-30 08:47:47Z tovar $
+*  $Id: icontratoscore.h 4529 2012-01-13 13:12:55Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,6 +14,7 @@
 
 #include <api/icontrato.h>
 #include <api/math/geometria.h>
+#include <api/math/geometria3d.h>
 #include <api/controllers/ipacscontroller.h>
 #ifdef __DEPRECATED
 #undef __DEPRECATED
@@ -69,47 +70,61 @@ namespace GNC {
 		protected:
 			GNC::GCS::IWidgetsManager*    m_pManager;
 		};
+		
+		class EXTAPI IContractSlider: public IContrato {
+		public:
 
-		class EXTAPI IContratoWindowLevel: public IContrato {
+			inline IContractSlider() {
+			}
+
+			inline ~IContractSlider() {
+			}
+			
+			virtual void SetSlice(int slicenum) = 0;
+			virtual int GetSlice() const = 0;
+			virtual int GetNumberOfSlices() const = 0;
+		};		
+
+		class EXTAPI IContractWindowLevel: public IContrato {
 		public:
 			class WindowLevel{
 			public:
+				typedef enum TWL_TYPE {
+					TWLT_FILE,
+					TWLT_PREDEFINED,
+					TWLT_USER_DEFINED
+				} TWL_TYPE;
+				
 				WindowLevel(){
 					m_label = std::string("");
 					m_window = 0;
 					m_level = 0;
+					m_type = TWLT_USER_DEFINED;
 				}
 
-				WindowLevel(const std::string& label, const double& window,const double& level, bool userDefined = false){
+				WindowLevel(const std::string& label, const double& window,const double& level, TWL_TYPE type){
 					m_label = label;
 					m_window = window;
 					m_level = level;
-					m_userDefined = userDefined;
-				}
-
-				WindowLevel(const double& window,const double& level, bool userDefined = false){
-					m_label = std::string("");
-					m_window = window;
-					m_level = level;
-					m_userDefined = userDefined;
+					m_type = type;
 				}
 
 				WindowLevel(const WindowLevel& otro) {
 					m_window = otro.m_window;
 					m_level = otro.m_level;
 					m_label = otro.m_label;
-					m_userDefined = otro.m_userDefined;
+					m_type = otro.m_type;
 				}
 
 				WindowLevel& operator=(const WindowLevel& otro) {
 					m_label = otro.m_label;
 					m_window = otro.m_window;
 					m_level = otro.m_level;
-					m_userDefined = otro.m_userDefined;
+					m_type = otro.m_type;
 					return *this;
 				}
 
-				bool			m_userDefined;
+				TWL_TYPE			m_type;
 				std::string m_label;
 				double m_window;
 				double m_level;
@@ -122,11 +137,11 @@ namespace GNC {
 
 			public: bool m_isCT;
 
-			IContratoWindowLevel():IContrato() {
+			IContractWindowLevel():IContrato() {
 				m_labelCurrent = "";
 			}
 
-			~IContratoWindowLevel(){
+			~IContractWindowLevel(){
 				m_listaWindowLevels.clear();
 			}
 
@@ -135,6 +150,16 @@ namespace GNC {
 				return m_listaWindowLevels.size() >0;
 			}
 
+			virtual void SetUserDefinedWindowLevel(double window, double level) {
+				if (m_listaWindowLevels.size() == 0 || (m_listaWindowLevels.size() > 0 && m_listaWindowLevels.back().m_type != WindowLevel::TWLT_USER_DEFINED)) {
+					m_listaWindowLevels.push_back(WindowLevel("USER_DEFINED", window, level, WindowLevel::TWLT_USER_DEFINED));
+				} else {
+					m_listaWindowLevels.back().m_window = window;
+					m_listaWindowLevels.back().m_level = level;
+				}
+				m_labelCurrent = m_listaWindowLevels.back().m_label;
+			}
+
 			virtual WindowLevel GetCurrentWindowLevel()
 			{
 				for (ListaWindowLevels::iterator it = m_listaWindowLevels.begin(); it != m_listaWindowLevels.end(); ++it)
@@ -144,10 +169,10 @@ namespace GNC {
 					}
 				}
 				if (m_listaWindowLevels.size() > 0) {
-					m_labelCurrent = m_listaWindowLevels[0].m_label;
-					return m_listaWindowLevels[0];
+					m_labelCurrent = m_listaWindowLevels.front().m_label;
+					return m_listaWindowLevels.front();
 				} else {
-					WindowLevel wl("",0,0,false);
+					WindowLevel wl("",0,0,WindowLevel::TWLT_USER_DEFINED);
 					return wl;
 				}
 			}
@@ -157,7 +182,7 @@ namespace GNC {
 				bool resultado = false;
 				for (ListaWindowLevels::iterator it = m_listaWindowLevels.begin(); it != m_listaWindowLevels.end(); ++it)
 				{
-					resultado = resultado || !(*it).m_userDefined;
+					resultado = resultado || (*it).m_type != WindowLevel::TWLT_USER_DEFINED;
 				}
 				return resultado;
 			}
@@ -166,12 +191,12 @@ namespace GNC {
 			{
 				for (ListaWindowLevels::iterator it = m_listaWindowLevels.begin(); it != m_listaWindowLevels.end(); ++it)
 				{
-					if (!(*it).m_userDefined) {
+					if ((*it).m_type != WindowLevel::TWLT_USER_DEFINED) {
 						m_labelCurrent = (*it).m_label;
 						return (*it);
 					}
 				}
-				WindowLevel wl("",0,0,false);
+				WindowLevel wl("",0,0,WindowLevel::TWLT_USER_DEFINED);
 				return wl;
 			}
 
@@ -180,7 +205,7 @@ namespace GNC {
 				ListaWindowLevels listaTemp;
 				for (ListaWindowLevels::iterator it = m_listaWindowLevels.begin(); it !=  m_listaWindowLevels.end(); ++it)
 				{
-					if ((*it).m_userDefined) {
+					if ((*it).m_type == WindowLevel::TWLT_USER_DEFINED) {
 						listaTemp.push_back((*it));
 					}
 				}
@@ -230,7 +255,7 @@ namespace GNC {
 							if (m_labelCurrent == "") {
 								m_labelCurrent = label;
 							}
-							WindowLevel wl(label,window,level);
+							WindowLevel wl(label,window,level, WindowLevel::TWLT_FILE);
 							m_listaWindowLevels.push_back(wl);
 						}
 
@@ -251,12 +276,12 @@ namespace GNC {
 					if (m_labelCurrent == "") {
 						m_labelCurrent = _Std("Abdomen");
 					}
-					m_listaWindowLevels.push_back(WindowLevel(_Std("Abdomen"), 400, 40));
-					m_listaWindowLevels.push_back(WindowLevel(_Std("Lung"), 1200, -600));
-					m_listaWindowLevels.push_back(WindowLevel(_Std("Vertebra"), 2000, 350));
-					m_listaWindowLevels.push_back(WindowLevel(_Std("Cranium"), 100, 35));
-					m_listaWindowLevels.push_back(WindowLevel(_Std("Mediastinum"), 350, 40));
-					m_listaWindowLevels.push_back(WindowLevel(_Std("Spine"), 300, 35));
+					m_listaWindowLevels.push_back(WindowLevel(_Std("Abdomen"), 400, 40, WindowLevel::TWLT_PREDEFINED));
+					m_listaWindowLevels.push_back(WindowLevel(_Std("Lung"), 1200, -600, WindowLevel::TWLT_PREDEFINED));
+					m_listaWindowLevels.push_back(WindowLevel(_Std("Vertebra"), 2000, 350, WindowLevel::TWLT_PREDEFINED));
+					m_listaWindowLevels.push_back(WindowLevel(_Std("Cranium"), 100, 35, WindowLevel::TWLT_PREDEFINED));
+					m_listaWindowLevels.push_back(WindowLevel(_Std("Mediastinum"), 350, 40, WindowLevel::TWLT_PREDEFINED));
+					m_listaWindowLevels.push_back(WindowLevel(_Std("Spine"), 300, 35, WindowLevel::TWLT_PREDEFINED));
 				}
 				//se meten i es necesario los user defined
 				for (ListaWindowLevels::iterator it = listaTemp.begin(); it !=  listaTemp.end(); ++it)
