@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: iherramientareset.h 3696 2011-04-14 08:40:28Z carlos $
+*  $Id: iherramientareset.h 4330 2011-10-25 10:28:33Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -23,7 +23,7 @@ namespace GNC {
 			typedef GNC::GCS::IContratable<TContratoWidgets> TContratableWidgets;
 
 			static const IHerramienta::UID ID = HCore_Reset;
-			IHerramientaReset() : IHerramienta(HCore_Reset,TMenuImagen, "Resetear Window Level y Zoom") {};
+			IHerramientaReset() : IHerramienta(HCore_Reset,TMenuImagen, _Std("Reset window level and zoom")) {};
 			~IHerramientaReset() {};
 
 			virtual void SetVistaActiva(GNC::GCS::IVista* pVista) = 0;
