@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: iherramientascore.h 4394 2011-11-11 09:45:22Z carlos $
+*  $Id: iherramientascore.h 4478 2011-12-13 11:55:00Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -21,20 +21,23 @@
 #define HCore_LazoChroma         7
 #define HCore_Elevacion          8
 #define HCore_Nota               9
-#define HCore_WindowLevel        10
-#define HCore_Deshacer	         11
-#define HCore_LayoutVentana	   12
-#define HCore_EdicionDICOM       13
-#define HCore_Calibrado		      14
-#define HCore_Debug              15
-#define HCore_Marcado            16
+#define HCore_Deshacer	         10
+#define HCore_LayoutVentana	     11
+#define HCore_EdicionDICOM       12
+#define HCore_Calibrado		     13
+#define HCore_Debug              14
+#define HCore_Marcado            15
+#define HCore_Rejilla		     16
 #define HCore_AnotacionesEsquina 17
-#define HCore_Rejilla		      18
-#define HCore_PanelTags			   19
-#define HCore_Reset              20
-#define HCore_Desencajar         21
-#define HCore_Interpolate        22
-#define HCore_Slider             23
+#define HCore_PanelTags			 18
+#define HCore_Reset              19
+#define HCore_Desencajar         20
+#define HCore_Interpolate        21
+
+#define HCore_Pan                22
+#define HCore_Zoom               23
+#define HCore_Slider             24
+#define HCore_WindowLevel        25
 
 #define SubFamiliaEdicionDeshacer 0
 //layout desencajar, anotaciones esquina...
