@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorcomandos.cpp 4078 2011-08-16 10:19:52Z tovar $
+ *  $Id: controladorcomandos.cpp 4602 2012-01-26 07:23:02Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -67,12 +67,9 @@ void* GNC::LanzadorComandos::Entry()
 
 	wxWindow* w = GNC::GCS::ControladorComandos::Instance()->GetVentanaRegistrada();
 
-	bool iniciado = false;
-
 	if (m_pComando != NULL && !m_pComando->EstaAbortado()) {
 
 		if (w != NULL) {
-			iniciado = true;
 			EventoProgreso ce(EventoProgreso::ComandoIniciado, m_idThreadGinkgo);
 			w->AddPendingEvent(ce);
 		}
