@@ -1,20 +1,23 @@
 /*
- *
- *  $Id: controladorherramientas.cpp 4124 2011-09-02 12:21:20Z carlos $
- *  Ginkgo CADx Project
- *
- *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
- *  http://ginkgo-cadx.com
- *
- *  This file is licensed under LGPL v3 license.
- *  See License.txt for details
- *
- *
- */
+*
+*  $Id: controladorherramientas.cpp 4602 2012-01-26 07:23:02Z tovar $
+*  Ginkgo CADx Project
+*
+*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
+*  http://ginkgo-cadx.com
+*
+*  This file is licensed under LGPL v3 license.
+*  See License.txt for details
+*
+*
+*/
 #include <api/globals.h>
 #include <api/ientorno.h>
 #include <wx/aui/aui.h>
+#include <wx/dc.h>
 #include <wx/aui/auibar.h>
+#include <wx/menu.h>
+#include <wx/xml/xml.h>
 #include <api/icontroladorvistas.h>
 #include <main/barraherramientasderecha.h>
 #include <main/entorno.h>
@@ -23,7 +26,6 @@
 #include <resources/ginkgoresourcemanager.h>
 #include <api/icontextoestudio.h>
 #include "controladorherramientas.h"
-#include <wx/xml/xml.h>
 
 
 #include <main/entorno.h>
@@ -33,44 +35,298 @@
 // <editor-fold defaultstate="collapsed" desc="patron singleton">
 #define ID_WX_HERRAMIENTA 1001
 
+class GinkgoToolBarArt : public AUI_NAMESPACE wxAuiDefaultToolBarArt {
+public:
+
+	GinkgoToolBarArt(GNC::ControladorHerramientas* pControlador) {
+		m_pControlador = pControlador;
+	}
+
+	virtual ~GinkgoToolBarArt() {}
+
+	void SetCustomBaseColor(const wxColor& color) {
+		m_base_colour = color;
+	}
+
+	wxColor GetCustomBaseColor() {
+		return m_base_colour;
+	}
+
+
+	////////////////////////////////////////////////////begin draw drowpdown////////////////////////////////////////
+	//WXWIDGETS DOESN'T SUPPORT DRAW CHECKED + DROPDOWN
+	// wxAuiBlendColour is used by wxAuiStepColour
+	unsigned char wxAuiBlendColour(unsigned char fg, unsigned char bg, double alpha)
+	{
+		double result = bg + (alpha * (fg - bg));
+		if (result < 0.0)
+			result = 0.0;
+		if (result > 255)
+			result = 255;
+		return (unsigned char)result;
+	}
+
+	// wxAuiStepColour() it a utility function that simply darkens
+	// or lightens a color, based on the specified percentage
+	// ialpha of 0 would be completely black, 100 completely white
+	// an ialpha of 100 returns the same colour
+	wxColor wxAuiStepColour(const wxColor& c, int ialpha)
+	{
+		if (ialpha == 100)
+			return c;
+
+		unsigned char r = c.Red(),
+			g = c.Green(),
+			b = c.Blue();
+		unsigned char bg;
+
+		// ialpha is 0..200 where 0 is completely black
+		// and 200 is completely white and 100 is the same
+		// convert that to normal alpha 0.0 - 1.0
+		ialpha = wxMin(ialpha, 200);
+		ialpha = wxMax(ialpha, 0);
+		double alpha = ((double)(ialpha - 100.0))/100.0;
+
+		if (ialpha > 100)
+		{
+			// blend with white
+			bg = 255;
+			alpha = 1.0 - alpha;  // 0 = transparent fg; 1 = opaque fg
+		}
+		else
+		{
+			// blend with black
+			bg = 0;
+			alpha += 1.0;         // 0 = transparent fg; 1 = opaque fg
+		}
+
+		r = wxAuiBlendColour(r, bg, alpha);
+		g = wxAuiBlendColour(g, bg, alpha);
+		b = wxAuiBlendColour(b, bg, alpha);
+
+		return wxColour(r, g, b);
+	}
+
+	void DrawDropDownButton(
+		wxDC& dc,
+		wxWindow* WXUNUSED(wnd),
+		const wxAuiToolBarItem& item,
+		const wxRect& rect)
+	{
+		//
+		const int BUTTON_DROPDOWN_WIDTH = 10;
+		const unsigned char
+			DISABLED_TEXT_GREY_HUE = wxAuiBlendColour(0, 255, 0.4);
+		const wxColour DISABLED_TEXT_COLOR(DISABLED_TEXT_GREY_HUE,
+			DISABLED_TEXT_GREY_HUE,
+			DISABLED_TEXT_GREY_HUE);
+		//
+
+		int text_width = 0, text_height = 0, text_x = 0, text_y = 0;
+		int bmp_x = 0, bmp_y = 0, dropbmp_x = 0, dropbmp_y = 0;
+
+		wxRect button_rect = wxRect(rect.x,
+			rect.y,
+			rect.width-BUTTON_DROPDOWN_WIDTH,
+			rect.height);
+		wxRect dropdown_rect = wxRect(rect.x+rect.width-BUTTON_DROPDOWN_WIDTH-1,
+			rect.y,
+			BUTTON_DROPDOWN_WIDTH+1,
+			rect.height);
+
+		if (m_flags & wxAUI_TB_TEXT)
+		{
+			dc.SetFont(m_font);
+
+			int tx, ty;
+			if (m_flags & wxAUI_TB_TEXT)
+			{
+				dc.GetTextExtent(wxT("ABCDHgj"), &tx, &text_height);
+				text_width = 0;
+			}
+
+			dc.GetTextExtent(item.GetLabel(), &text_width, &ty);
+		}
+
+
+
+		dropbmp_x = dropdown_rect.x +
+			(dropdown_rect.width/2) -
+			(m_button_dropdown_bmp.GetWidth()/2);
+		dropbmp_y = dropdown_rect.y +
+			(dropdown_rect.height/2) -
+			(m_button_dropdown_bmp.GetHeight()/2);
+
+
+		if (m_text_orientation == wxAUI_TBTOOL_TEXT_BOTTOM)
+		{
+			bmp_x = button_rect.x +
+				(button_rect.width/2) -
+				(item.GetBitmap().GetWidth()/2);
+			bmp_y = button_rect.y +
+				((button_rect.height-text_height)/2) -
+				(item.GetBitmap().GetHeight()/2);
+
+			text_x = rect.x + (rect.width/2) - (text_width/2) + 1;
+			text_y = rect.y + rect.height - text_height - 1;
+		}
+		else if (m_text_orientation == wxAUI_TBTOOL_TEXT_RIGHT)
+		{
+			bmp_x = rect.x + 3;
+
+			bmp_y = rect.y +
+				(rect.height/2) -
+				(item.GetBitmap().GetHeight()/2);
+
+			text_x = bmp_x + 3 + item.GetBitmap().GetWidth();
+			text_y = rect.y +
+				(rect.height/2) -
+				(text_height/2);
+		}
+
+
+		if (item.GetState() & wxAUI_BUTTON_STATE_PRESSED)
+		{
+			dc.SetPen(wxPen(m_highlight_colour));
+			dc.SetBrush(wxBrush(wxAuiStepColour(m_highlight_colour, 140)));
+			dc.DrawRectangle(button_rect);
+			dc.DrawRectangle(dropdown_rect);
+		}
+		else if (item.GetState() & wxAUI_BUTTON_STATE_HOVER ||
+			item.IsSticky())
+		{
+			dc.SetPen(wxPen(m_highlight_colour));
+			dc.SetBrush(wxBrush(wxAuiStepColour(m_highlight_colour, 170)));
+			dc.DrawRectangle(button_rect);
+			dc.DrawRectangle(dropdown_rect);
+		}
+		//MODIFIED
+		else if (item.GetState() & wxAUI_BUTTON_STATE_CHECKED)
+		{
+			// it's important to put this code in an else statment after the
+			// hover, otherwise hovers won't draw properly for checked items
+			dc.SetPen(wxPen(m_highlight_colour));
+			dc.SetBrush(wxBrush(wxAuiStepColour(m_highlight_colour, 170)));
+			dc.DrawRectangle(rect);
+		}
+		///END MODIFIED
+
+		wxBitmap bmp;
+		wxBitmap dropbmp;
+		if (item.GetState() & wxAUI_BUTTON_STATE_DISABLED)
+		{
+			bmp = item.GetDisabledBitmap();
+			dropbmp = m_disabled_button_dropdown_bmp;
+		}
+		else
+		{
+			bmp = item.GetBitmap();
+			dropbmp = m_button_dropdown_bmp;
+		}
+
+		if (!bmp.IsOk())
+			return;
+
+		dc.DrawBitmap(bmp, bmp_x, bmp_y, true);
+		dc.DrawBitmap(dropbmp, dropbmp_x, dropbmp_y, true);
+
+		// set the item's text color based on if it is disabled
+		dc.SetTextForeground(*wxBLACK);
+		if (item.GetState() & wxAUI_BUTTON_STATE_DISABLED)
+			dc.SetTextForeground(DISABLED_TEXT_COLOR);
+
+		if ( (m_flags & wxAUI_TB_TEXT) && !item.GetLabel().empty() )
+		{
+			dc.DrawText(item.GetLabel(), text_x, text_y);
+		}
+	}
+	////////////////////////////////////////////////////end draw drowpdown////////////////////////////////////////
+
+	virtual void DrawButton(
+		wxDC& dc,
+		wxWindow* wnd,
+		const wxAuiToolBarItem& item,
+		const wxRect& rect)
+	{
+		if (item.HasDropDown()) {
+			//we have modified default draw function to draw checked + drop down (not supported in wxWidgets)
+			DrawDropDownButton(dc, wnd, item, rect);
+		} else {
+			AUI_NAMESPACE wxAuiDefaultToolBarArt::DrawButton(dc, wnd, item, rect);
+		}
+		if (item.IsActive() && ( (item.GetState() & wxAUI_BUTTON_STATE_CHECKED) != 0) ) {
+
+			GNC::GCS::IHerramienta* pHerramienta = m_pControlador->ObtenerHerramienta(m_pControlador->GetId(item.GetId()));
+			if (pHerramienta != NULL && pHerramienta->Activada()) {
+				wxBitmap bmp;
+				if ( pHerramienta->GetTriggerButton().IsLeftEnabled() && pHerramienta->GetTriggerButton().IsRightEnabled()) {
+					//l+r
+					bmp = GinkgoResourcesManager::IconosHerramientas::GetIcoMouseRL();
+				} else if ( pHerramienta->GetTriggerButton().IsLeftEnabled() ) {
+					//l
+					bmp = GinkgoResourcesManager::IconosHerramientas::GetIcoMouseL();
+				} else {
+					//r
+					bmp = GinkgoResourcesManager::IconosHerramientas::GetIcoMouseR();
+				}
+
+				if ( pHerramienta->GetTriggerButton().IsLeftEnabled() ||  pHerramienta->GetTriggerButton().IsRightEnabled()) {
+					wxPoint point(rect.x, rect.height - bmp.GetHeight()+7);
+					dc.DrawBitmap(bmp, point);
+				}
+			}
+		}
+	}
+
+private:
+	GNC::ControladorHerramientas* m_pControlador;
+
+};
+
 class BarraHerramientasControlador:public AUI_NAMESPACE wxAuiToolBar{
 public:
 	BarraHerramientasControlador(wxWindow* pParent,GNC::ControladorHerramientas* pControlador,const GNC::GCS::IHerramienta::TFamiliasHerramientas& familia):AUI_NAMESPACE wxAuiToolBar(pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize,AUI_NAMESPACE wxAUI_TB_DEFAULT_STYLE )
 	{
-		this->Connect(wxID_ANY,wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler( BarraHerramientasControlador::OnActivarHerramienta));
+		this->Connect(wxID_ANY,wxEVT_LEFT_UP, wxMouseEventHandler( BarraHerramientasControlador::OnLeftUp) );
+		this->Connect(wxID_ANY,wxEVT_RIGHT_UP, wxMouseEventHandler( BarraHerramientasControlador::OnRightUp) );
+		this->Connect(wxID_ANY, wxEVT_COMMAND_AUITOOLBAR_TOOL_DROPDOWN,  wxAuiToolBarEventHandler(BarraHerramientasControlador::OnDropDownTool) );
+
 		SetToolBitmapSize(wxSize(16,16));
 		m_pControlador = pControlador;
-		AUI_NAMESPACE wxAuiDefaultToolBarArt* pToolArt= new AUI_NAMESPACE wxAuiDefaultToolBarArt();
-#if !defined(__WXOSX__) && defined(USE_PATCHED_LIBS)
-		wxColor color = pToolArt->GetDefaultBaseColor();
+		GinkgoToolBarArt* pToolArt = new GinkgoToolBarArt(m_pControlador);
+#if !defined(__WXOSX__)
+		wxColor color = pToolArt->GetCustomBaseColor();
 		switch(familia) {
-			case GNC::GCS::IHerramienta::TFamiliaVisualizacion:
-				color = wxColor(255,255,186);
-				break;
-			case GNC::GCS::IHerramienta::TFamiliaAnotacion:
-				color = wxColor(255,186,186);
-				break;
-			case GNC::GCS::IHerramienta::TFamiliaMedicion:
-				color = wxColor(217,255,186);
-				break;
-			case GNC::GCS::IHerramienta::TFamiliaVision:
-				color = wxColor(186,230,255);
-				break;
-			case GNC::GCS::IHerramienta::TFamiliaChroma:
-				color = wxColor(230,181,242);
-				break;
-			case GNC::GCS::IHerramienta::TMenuVer:
-				break;
-			case GNC::GCS::IHerramienta::TMenuImagen:
-				break;
-			case GNC::GCS::IHerramienta::TMenuHerramientas:
-				break;
-			case GNC::GCS::IHerramienta::TMenuEdicion:
-				break;
-			case GNC::GCS::IHerramienta::TMenu3D:
-				break;
+case GNC::GCS::IHerramienta::TFamiliaGlobal:
+case GNC::GCS::IHerramienta::TFamiliaVisualizacion:
+	color = wxColor(255,255,186);
+	break;
+case GNC::GCS::IHerramienta::TFamiliaAnotacion:
+	color = wxColor(255,186,186);
+	break;
+case GNC::GCS::IHerramienta::TFamiliaMedicion:
+	color = wxColor(217,255,186);
+	break;
+case GNC::GCS::IHerramienta::TFamiliaVision:
+	color = wxColor(186,230,255);
+	break;
+case GNC::GCS::IHerramienta::TFamiliaChroma:
+	color = wxColor(230,181,242);
+	break;
+case GNC::GCS::IHerramienta::TMenuVer:
+	break;
+case GNC::GCS::IHerramienta::TMenuImagen:
+	break;
+case GNC::GCS::IHerramienta::TMenuHerramientas:
+	break;
+case GNC::GCS::IHerramienta::TMenuExport:
+	break;
+case GNC::GCS::IHerramienta::TMenuEdicion:
+	break;
+case GNC::GCS::IHerramienta::TMenu3D:
+	break;
 		}
-		pToolArt->SetBaseColor(color);
+		pToolArt->SetCustomBaseColor(color);
 #endif
 
 		SetArtProvider(pToolArt);
@@ -78,15 +334,64 @@ public:
 
 	~BarraHerramientasControlador()
 	{
-		this->Disconnect(wxID_ANY,wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler( BarraHerramientasControlador::OnActivarHerramienta));
+		this->Disconnect(wxID_ANY,wxEVT_COMMAND_TOOL_CLICKED, wxMouseEventHandler( BarraHerramientasControlador::OnLeftUp));
+		this->Disconnect(wxID_ANY,wxEVT_COMMAND_TOOL_CLICKED, wxMouseEventHandler( BarraHerramientasControlador::OnRightUp));
+		this->Disconnect(wxID_ANY, wxEVT_COMMAND_AUITOOLBAR_TOOL_DROPDOWN,  wxAuiToolBarEventHandler(BarraHerramientasControlador::OnDropDownTool) );
 		m_pControlador=NULL;
 	}
 
-	void OnActivarHerramienta(wxCommandEvent& event)
+	virtual void OnRightUp(wxMouseEvent& evt)
 	{
-		m_pControlador->OnActivarHerramienta(event);
+		wxAuiToolBarItem* hit_item;
+		hit_item = FindToolByPosition(evt.GetX(), evt.GetY());
+		if (hit_item != NULL && hit_item->IsActive() && hit_item->GetKind() == wxITEM_CHECK) {
+			m_pControlador->OnActivarHerramienta(hit_item->GetId(), GNC::GCS::TriggerButton().EnableRight());
+		}
+		evt.Skip(false);
 	}
 
+	virtual void OnLeftUp(wxMouseEvent& evt)
+	{
+		wxAuiToolBarItem* hit_item;
+		hit_item = FindToolByPosition(evt.GetX(), evt.GetY());
+		if (hit_item != NULL && hit_item->IsActive() && hit_item->GetKind() == wxITEM_CHECK) {
+			m_pControlador->OnActivarHerramienta(hit_item->GetId(), GNC::GCS::TriggerButton().EnableLeft());
+		}
+		evt.Skip(false);
+	}
+
+	virtual void OnDropDownTool(wxAuiToolBarEvent& evt)
+	{
+		if (evt.IsDropDownClicked()){
+			wxAuiToolBarItem* hit_item;
+			hit_item = FindToolByPosition(evt.GetClickPoint().x, evt.GetClickPoint().y);
+			if (hit_item != NULL && hit_item->IsActive() && hit_item->GetKind() == wxITEM_CHECK) {
+				//Activate...
+				m_pControlador->OnActivarHerramienta(hit_item->GetId(), GNC::GCS::TriggerButton().EnableLeft());
+				//
+				wxMenu menuPopup;
+				GNC::GCS::IHerramienta* pHerramienta = m_pControlador->ObtenerHerramientaWx(hit_item->GetId());
+				if (pHerramienta != NULL) {
+					pHerramienta->AppendInMenu(this,&menuPopup);
+					// line up our menu with the button
+					wxRect rect = this->GetToolRect(evt.GetId());
+					wxPoint pt = this->ClientToScreen(rect.GetBottomLeft());
+					pt = ScreenToClient(pt);
+
+
+					PopupMenu(&menuPopup, pt);
+					// make sure the button is "un-stuck"
+					this->SetToolSticky(evt.GetId(), false);
+					//refresh icon
+					hit_item->SetBitmap(pHerramienta->GetIcono());
+					Refresh(true);
+				}
+			}
+			evt.Skip(false);
+		}
+	}
+
+private:
 	GNC::ControladorHerramientas* m_pControlador;
 
 };
@@ -109,16 +414,16 @@ namespace GNC {
 				//tools accelerators are ctrl + keycode
 				if (event.ControlDown() && event.GetKeyCode() != WXK_CONTROL) {
 					m_pController->OnKeyAccelerator(event);
-					#if defined(__WXGTK__)
+#if defined(__WXGTK__)
 					if (m_pParent != NULL) {
 						m_pParent->SetFocus();
 					}
-					#endif
+#endif
 				} else {
 					event.ResumePropagation(1);
 					event.Skip(true);
 				}
-				
+
 			}
 
 			void Connect(wxWindow* pParent) {
@@ -153,15 +458,8 @@ GNC::ControladorHerramientas::ControladorHerramientas()
 
 	m_contadorHerramientas = ID_WX_HERRAMIENTA;
 
-	m_pBarraSinOpciones = new AUI_NAMESPACE wxAuiToolBar(pEntorno->GetPanelHerramientasSuperior(),wxID_ANY, wxDefaultPosition, wxDefaultSize,AUI_NAMESPACE wxAUI_TB_DEFAULT_STYLE | AUI_NAMESPACE wxAUI_TB_HORZ_TEXT);
-	m_pBarraSinOpciones->AddTool(wxID_ANY,_("No options"),GinkgoResourcesManager::IconosHerramientas::GetIcoSinOpciones());
-	m_pBarraSinOpciones->EnableTool(wxID_ANY,false);
-	m_pBarraSinOpciones->Realize();
-	pEntorno->GetSizerHerramientasOpciones()->Add(m_pBarraSinOpciones, 1, wxEXPAND, 0);
-	m_pBarraSinOpciones->Show(false);
-
 	//ñapa para que se inserten en orden las barras de herramientas
-	for(int familia = GNC::GCS::IHerramienta::TFamiliaVisualizacion; familia<= GNC::GCS::IHerramienta::TFamiliaVision; ++familia)
+	for(int familia = GNC::GCS::IHerramienta::TFamiliaGlobal; familia <= GNC::GCS::IHerramienta::TFamiliaVision; ++familia)
 	{
 		BarraHerramientasControlador* pBarraHerramientas = new BarraHerramientasControlador(pEntorno->GetPanelHerramientasSuperior(),this,(GNC::GCS::IHerramienta::TFamiliasHerramientas)familia);
 		pBarraHerramientas->SetAutoLayout(true);
@@ -170,7 +468,8 @@ GNC::ControladorHerramientas::ControladorHerramientas()
 	}
 
 	m_pBarraHerramientasDerecha = new GNC::GUI::BarraHerramientasDerecha(pEntorno->GetPanelHerramientasSuperior(), pEntorno->GetVentanaPrincipal());
-	pEntorno->GetPanelHerramientasSuperior()->GetSizer()->Add( m_pBarraHerramientasDerecha, 0, wxEXPAND, 0 );
+
+	pEntorno->GetPanelHerramientasSuperior()->GetSizer()->Add( m_pBarraHerramientasDerecha, 1, wxEXPAND, 0 );
 
 	m_pKeyEventHandler = new GNC::GUI::EventHandlerKeyToolsController(this);
 }
@@ -285,6 +584,16 @@ void GNC::ControladorHerramientas::DesRegistrarHerramienta(GNC::GCS::IHerramient
 	}
 }
 
+GNC::GCS::IHerramienta* GNC::ControladorHerramientas::ObtenerHerramientaWx(long id)
+{
+	if(m_MapaIdsHerramientas.find(id) != m_MapaIdsHerramientas.end()){
+		int idHerramienta = m_MapaIdsHerramientas[id];
+		return ObtenerHerramienta(idHerramienta);
+	} else {
+		return NULL;
+	}
+}
+
 GNC::GCS::IHerramienta* GNC::ControladorHerramientas::ObtenerHerramienta(GNC::GCS::IHerramienta::UID id)
 {
 	GNC::GCS::IHerramienta* pHerramienta = NULL;
@@ -303,7 +612,9 @@ bool GNC::ControladorHerramientas::MostrarHerramientaBarra(GNC::GCS::IHerramient
 		if(pBarraHerramientas->FindTool(idWx)==NULL && !pHerramienta->IsMenu()){
 			//si no esta metida...
 			pBarraHerramientas->AddTool(idWx,wxString::FromUTF8(pHerramienta->Nombre.c_str()),pHerramienta->GetIcono(),wxString::FromUTF8(pHerramienta->GetDescripcion().c_str()),wxITEM_CHECK);
-
+			if (pHerramienta->IsDropDown()) {
+				pBarraHerramientas->SetToolDropDown(idWx, true);
+			}
 			return true;
 		}
 	}
@@ -333,14 +644,9 @@ void GNC::ControladorHerramientas::ActivarHerramientaBarra(GNC::GCS::IHerramient
 		barraOpciones->Show(activar);
 		if (activar) {
 			//barraOpciones->Layout();
-                        //barraOpciones->Refresh(true);
-		}
-	} else {
-		m_pBarraSinOpciones->Show(activar);
-		if (activar) {
-			//m_pBarraSinOpciones->Layout();
-                        //m_pBarraSinOpciones->Refresh(true);
+			//barraOpciones->Refresh(true);
 		}
+	} else {		
 	}
 }
 
@@ -355,18 +661,28 @@ unsigned long GNC::ControladorHerramientas::GetIdWx(unsigned long idHerramienta)
 	return 0;
 }
 
+unsigned long GNC::ControladorHerramientas::GetId(unsigned long id)
+{
+	if(m_MapaIdsHerramientas.find(id) != m_MapaIdsHerramientas.end()){
+		return m_MapaIdsHerramientas[id];		
+	}
+	return 0;
+}
+
 
 /* Refresca las propiedades (visibilidad, etc) de las herramientas frente a cambios de estado */
 void GNC::ControladorHerramientas::RefrescarHerramientas()
 {
 	GTRACE("GNC::ControladorHerramientas::RefrescarHerramientas()");
 	// Obtenemos la herramienta activa en el módulo
-	GNC::GCS::IHerramienta* pHerramientaActivaEnModulo = NULL;
+	GNC::GCS::IHerramienta* pActiveLeftTool = NULL;
+	GNC::GCS::IHerramienta* pActiveRightTool = NULL;
 	if (m_pModuloActivo != NULL && m_pVistaActiva != NULL) {
-		pHerramientaActivaEnModulo = m_HerramientaActiva[m_pModuloActivo];
+		pActiveLeftTool = m_HerramientaActivaBotonIzquierdo[m_pModuloActivo];
+		pActiveRightTool = m_HerramientaActivaBotonDerecho[m_pModuloActivo];
 	}
 
-	#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 	std::cout << "RefrescarHerramientas() HerramientaActivaEnModulo = ";
 	if (pHerramientaActivaEnModulo != NULL ) {
 		std::cout << pHerramientaActivaEnModulo->Nombre.c_str();
@@ -375,135 +691,133 @@ void GNC::ControladorHerramientas::RefrescarHerramientas()
 		std::cout << "NULL";
 	}
 	std::cout << std::endl;
-	#endif
+#endif
 	//si se ha añadido/eliminado alguna pues habra que hacer rebuild...
 	bool rebuild=false;
 
-	GNC::GCS::IHerramienta* pHerramientaActiva = NULL;
 
 	for (MapaHerramientas::iterator it = m_Herramientas.begin(); it != m_Herramientas.end(); it++) {
 		GNC::GCS::IHerramienta* pHerramienta = (*it).second;
+		pHerramienta->SetVistaActiva(m_pVistaActiva);
+		pHerramienta->Conectar(false);
+		//pHerramienta->GetTriggerButton().ResetTriggerButtonMask();
 
-		if (pHerramienta != NULL) {
-			pHerramienta->SetVistaActiva(m_pVistaActiva);
-			pHerramienta->Conectar(false);
-			bool validaContratos = pHerramienta->ValidaContratos(m_pVistaActiva);
+		if (pHerramienta->ValidaContratos(m_pVistaActiva)) {
+			pHerramienta->Habilitar(true);
+			pHerramienta->Mostrar(true);
+			rebuild |= MostrarHerramientaBarra(pHerramienta, true);			
+		}
+		else {
+			pHerramienta->Habilitar(false);
+			pHerramienta->Mostrar(false);
+			rebuild |= MostrarHerramientaBarra(pHerramienta, false);
+		}
+	}
 
-			if ( pHerramientaActivaEnModulo == NULL || pHerramienta == pHerramientaActivaEnModulo) {
-				if (!validaContratos) {
-					//no se muestra, no hace falta desactivarla
-					pHerramienta->Habilitar(false);
-					pHerramienta->Mostrar(false);
-					GTRACE("Asignada HerramientaActivaModulo = NULL, por no validar contratos.");
 
-					rebuild = MostrarHerramientaBarra(pHerramienta,false) || rebuild ;
-				}
-				else {
-					rebuild = MostrarHerramientaBarra(pHerramienta,true) || rebuild ;
+	if (m_pModuloActivo != NULL && m_pVistaActiva != NULL) {
 
-					if (m_pVistaActiva != NULL && m_pVistaActiva->SoportaHerramienta(pHerramienta)) {
-						pHerramienta->Activar(true);
-						pHerramienta->Habilitar(true);
-						pHerramienta->Mostrar(true);
-						pHerramienta->Conectar(true);
-
-						HabilitarHerramientaBarra(pHerramienta,true);
-						ActivarHerramientaBarra(pHerramienta,true);
-						pHerramientaActiva = pHerramienta;
-
-						if(pHerramientaActivaEnModulo == NULL){
-							pHerramientaActivaEnModulo = pHerramientaActiva;
-							m_HerramientaActiva[m_pModuloActivo] = pHerramientaActiva;
-						}
-					}
-					else {
-						pHerramienta->Activar(false);
-						pHerramienta->Habilitar(false);
-						pHerramienta->Mostrar(true);
-						pHerramienta->Conectar(true);
-
-						HabilitarHerramientaBarra(pHerramienta,false);
-						ActivarHerramientaBarra(pHerramienta,false);
-					}
-				}
-			}
-			else if (pHerramienta->Habilitada()) {
-				if (!validaContratos) {
-					pHerramienta->Activar(false);
-					pHerramienta->Habilitar(false);
-					pHerramienta->Mostrar(false);
-
-					rebuild = MostrarHerramientaBarra(pHerramienta,false) || rebuild ;
-				}
-				else if (m_pVistaActiva != NULL && m_pVistaActiva->SoportaHerramienta(pHerramienta)) {
-					pHerramienta->Activar(false);
-					pHerramienta->Habilitar(true);
-					pHerramienta->Mostrar(true);
-
-					rebuild = MostrarHerramientaBarra(pHerramienta,true) || rebuild ;
-					HabilitarHerramientaBarra(pHerramienta,true);
-					ActivarHerramientaBarra(pHerramienta,false);
-				}
-				else {
-					pHerramienta->Activar(false);
-					pHerramienta->Habilitar(false);
-					pHerramienta->Mostrar(true);
-
-					rebuild = MostrarHerramientaBarra(pHerramienta,true) || rebuild ;
-					HabilitarHerramientaBarra(pHerramienta,false);
-					ActivarHerramientaBarra(pHerramienta,false);
-				}
-			}
-			else {
-				if (!validaContratos) {
-					pHerramienta->Activar(false);
-					pHerramienta->Habilitar(false);
-					pHerramienta->Mostrar(false);
-
-					rebuild = MostrarHerramientaBarra(pHerramienta,false) || rebuild ;
-				}
-				else if (m_pVistaActiva != NULL && m_pVistaActiva->SoportaHerramienta(pHerramienta)) {
-					pHerramienta->Activar(false);
-					pHerramienta->Habilitar(true);
-					pHerramienta->Mostrar(true);
-
-					rebuild = MostrarHerramientaBarra(pHerramienta,true) || rebuild ;
-					HabilitarHerramientaBarra(pHerramienta,true);
-					ActivarHerramientaBarra(pHerramienta,false);
-				}
-				else {
-					pHerramienta->Activar(false);
-					pHerramienta->Habilitar(false);
-					pHerramienta->Mostrar(true);
-
-					rebuild = MostrarHerramientaBarra(pHerramienta,true) || rebuild ;
-					HabilitarHerramientaBarra(pHerramienta,false);
-					ActivarHerramientaBarra(pHerramienta,false);
+		// Select first right tool available
+		if (pActiveRightTool == NULL) {
+			for (MapaHerramientas::iterator it = m_Herramientas.begin(); pActiveRightTool == NULL && it != m_Herramientas.end(); it++) {
+				GNC::GCS::IHerramienta* pTool = (*it).second;
+				if (pTool->IDFamilia == GNC::GCS::IHerramienta::TFamiliaVisualizacion && pTool->Habilitada() && m_pVistaActiva->SoportaHerramienta(pTool) ) {
+					pActiveRightTool = pTool;
 				}
 			}
 		}
+		if (pActiveRightTool != NULL) {
+			pActiveRightTool->GetTriggerButton().EnableRight();
+			if (pActiveRightTool->Habilitada()) {
+				if (m_pVistaActiva->SoportaHerramienta(pActiveRightTool)) {
+					pActiveRightTool->Activar(true);
+					pActiveRightTool->Conectar(true);
+					HabilitarHerramientaBarra(pActiveRightTool,true);
+					ActivarHerramientaBarra(pActiveRightTool,true);
+					rebuild |= MostrarHerramientaBarra(pActiveRightTool,true);
+				}
+				else {
+					pActiveRightTool->Activar(true);
+					pActiveRightTool->Conectar(false);
+					HabilitarHerramientaBarra(pActiveRightTool,false);
+					ActivarHerramientaBarra(pActiveRightTool,false);
+					rebuild |= MostrarHerramientaBarra(pActiveRightTool, false);
+				}
+			}
+			else {
+				pActiveRightTool->Activar(false);
+				pActiveRightTool->Habilitar(false);
+				pActiveRightTool->Mostrar(false);
+				HabilitarHerramientaBarra(pActiveRightTool,false);
+				ActivarHerramientaBarra(pActiveRightTool,false);
+				rebuild |= MostrarHerramientaBarra(pActiveRightTool,false);
+			}
+		}
+
+
+		// Select first left tool available
+		if (pActiveLeftTool == NULL) {
+			for (MapaHerramientas::iterator it = m_Herramientas.begin(); pActiveLeftTool == NULL && it != m_Herramientas.end(); it++) {
+				GNC::GCS::IHerramienta* pTool = (*it).second;
+				if (pTool->IDFamilia != GNC::GCS::IHerramienta::TFamiliaVisualizacion && pTool->Habilitada() && m_pVistaActiva->SoportaHerramienta(pTool) ) {
+					pActiveLeftTool = pTool;
+				}
+			}
+		}
+		if (pActiveLeftTool != NULL) {
+			pActiveLeftTool->GetTriggerButton().EnableLeft();
+			if (pActiveLeftTool->Habilitada()) {
+				if (m_pVistaActiva->SoportaHerramienta(pActiveLeftTool)) {
+					pActiveLeftTool->Activar(true);
+					pActiveLeftTool->Conectar(true);
+					HabilitarHerramientaBarra(pActiveLeftTool,true);
+					ActivarHerramientaBarra(pActiveLeftTool,true);
+					rebuild |= MostrarHerramientaBarra(pActiveLeftTool,true);
+				}
+				else {
+					pActiveLeftTool->Activar(true);
+					pActiveLeftTool->Conectar(false);
+					HabilitarHerramientaBarra(pActiveLeftTool,false);
+					ActivarHerramientaBarra(pActiveLeftTool,false);
+					rebuild |= MostrarHerramientaBarra(pActiveLeftTool, false);
+				}
+			}
+			else {
+				pActiveLeftTool->Activar(false);
+				pActiveLeftTool->Habilitar(false);
+				pActiveLeftTool->Mostrar(false);
+				HabilitarHerramientaBarra(pActiveLeftTool,false);
+				ActivarHerramientaBarra(pActiveLeftTool,false);
+				rebuild |= MostrarHerramientaBarra(pActiveLeftTool,false);
+			}
+		}
+
+
 	}
+	else {
+
+	}
+
+	if (m_pModuloActivo != NULL && m_pVistaActiva != NULL) {
+		m_HerramientaActivaBotonDerecho[m_pModuloActivo] = pActiveRightTool;
+		m_HerramientaActivaBotonIzquierdo[m_pModuloActivo] = pActiveLeftTool;
+	}
+
 
 	//si no tiene opciones hay q darle otro toque
 	if(m_pVistaActiva == NULL)
 	{
-		m_pBarraHerramientasDerecha->Show(false);
-		m_pBarraSinOpciones->Show(false);
+		//m_pBarraHerramientasDerecha->Show(false);
 	} else {
-		if((pHerramientaActiva == NULL) || (pHerramientaActiva != NULL && pHerramientaActiva->GetPanelHerramientaOpciones() == NULL) ) {
-			m_pBarraSinOpciones->Show(true);
-		} else {
-			m_pBarraSinOpciones->Show(false);
-		}
-		m_pBarraHerramientasDerecha->Show(true);
+		//m_pBarraHerramientasDerecha->Show(true);
 	}
 
 	ReconstruirBarrasHerramientas(rebuild);
 	GNC::Entorno::Instance()->GetPanelHerramientasSuperior()->Layout();
 
-	#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 	std::cout << "--" << std::endl;
-	#endif
+#endif
 }
 
 GNC::ControladorHerramientas::ListaHerramientas GNC::ControladorHerramientas::GetHerramientas(){
@@ -614,15 +928,15 @@ void GNC::ControladorHerramientas::Serializar(GNC::GCS::IVista* pVista, int posi
 void GNC::ControladorHerramientas::OnModuloCargado(GNC::GCS::IControladorModulo* pModulo)
 {
 	GTRACE("GNC::ControladorHerramientas::OnModuloCargado(" << pModulo << ")");
-	m_HerramientaActiva[pModulo] = NULL;
+	m_HerramientaActivaBotonIzquierdo[pModulo] = NULL;
 }
 
 void GNC::ControladorHerramientas::OnModuloDescargado(GNC::GCS::IControladorModulo* pModulo)
 {
 	GTRACE("GNC::ControladorHerramientas::OnModuloDescargado(" << pModulo << ")");
-	HerramientaActivas::iterator it = m_HerramientaActiva.find(pModulo);
-	if (it != m_HerramientaActiva.end()) {
-		m_HerramientaActiva.erase(it);
+	HerramientaActivas::iterator it = m_HerramientaActivaBotonIzquierdo.find(pModulo);
+	if (it != m_HerramientaActivaBotonIzquierdo.end()) {
+		m_HerramientaActivaBotonIzquierdo.erase(it);
 	}
 }
 
@@ -642,28 +956,39 @@ void GNC::ControladorHerramientas::OnVistaActivada(GNC::GCS::IVista* pVista)
 	//antes de activar... desactivar si es preciso
 	if (m_pVistaActiva != NULL)
 	{
-		#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 		std::cout << "OnVistaDesactivada( " << pVista->GetTitulo().c_str() << ") Modulo = " << pVista->GetControlador()->GetModulo()->GetNombre().c_str() << std::endl;
 		std::cout << "  ANT: VistaActiva = " << pVista->GetTitulo().c_str() << ", ModuloActivo = " << m_pModuloActivo->GetNombre().c_str() << std::endl;
-		#endif
+#endif
 
 		//disconnect key events...
 		m_pKeyEventHandler->Disconnect();
 		//
 
-		GNC::GCS::IHerramienta* pH = m_HerramientaActiva[m_pModuloActivo];
+		GNC::GCS::IHerramienta* pH = NULL;
+
+		pH = m_HerramientaActivaBotonIzquierdo[m_pModuloActivo];
 		if (pH != NULL) {
 			pH->SetVistaActiva(pVista);
 			pH->Conectar(false);
 			pH->Activar(false);
 			ActivarHerramientaBarra(pH,false);
 		}
+
+		pH = m_HerramientaActivaBotonDerecho[m_pModuloActivo];
+		if (pH != NULL) {
+			pH->SetVistaActiva(pVista);
+			pH->Conectar(false);
+			pH->Activar(false);
+			ActivarHerramientaBarra(pH,false);
+		}
+
 		m_pVistaActiva = NULL;
 		m_pModuloActivo = NULL;
 
-		#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 		std::cout << "  DES: VistaActiva = NULL, ModuloActivo = NULL" << std::endl;
-		#endif
+#endif
 
 		RefrescarHerramientas();
 
@@ -671,7 +996,7 @@ void GNC::ControladorHerramientas::OnVistaActivada(GNC::GCS::IVista* pVista)
 	}
 
 
-	#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 	std::cout << "OnVistaActivada( " << pVista->GetTitulo().c_str() << " ) Modulo = " << pVista->GetControlador()->GetModulo()->GetNombre().c_str() << std::endl;
 	std::cout << "  ANT: VistaActiva = ";
 	if (m_pVistaActiva != NULL) {
@@ -688,7 +1013,7 @@ void GNC::ControladorHerramientas::OnVistaActivada(GNC::GCS::IVista* pVista)
 		std::cout << "NULL";
 	}
 	std::cout << std::endl;
-	#endif
+#endif
 
 	m_pVistaActiva = pVista;
 	if(m_pVistaActiva !=NULL){
@@ -701,9 +1026,9 @@ void GNC::ControladorHerramientas::OnVistaActivada(GNC::GCS::IVista* pVista)
 		m_pModuloActivo = NULL;
 	}
 
-	#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 	std::cout << "  DES: VistaActiva = " << m_pVistaActiva->GetTitulo().c_str() << ", ModuloActivo = " << m_pModuloActivo->GetNombre().c_str() << std::endl;
-	#endif
+#endif
 
 	RefrescarHerramientas();
 
@@ -714,28 +1039,28 @@ void GNC::ControladorHerramientas::OnVistaActivada(GNC::GCS::IVista* pVista)
 /*
 void GNC::ControladorHerramientas::OnVistaDesactivada(GNC::GCS::IVista* pVista)
 {
-	#ifdef _GINKGO_TRACE
-	std::cout << "OnVistaDesactivada( " << pVista->GetTitulo().c_str() << ") Modulo = " << pVista->GetControlador()->GetModulo()->GetNombre().c_str() << std::endl;
-	std::cout << "  ANT: VistaActiva = " << pVista->GetTitulo().c_str() << ", ModuloActivo = " << m_pModuloActivo->GetNombre().c_str() << std::endl;
-	#endif
+#ifdef _GINKGO_TRACE
+std::cout << "OnVistaDesactivada( " << pVista->GetTitulo().c_str() << ") Modulo = " << pVista->GetControlador()->GetModulo()->GetNombre().c_str() << std::endl;
+std::cout << "  ANT: VistaActiva = " << pVista->GetTitulo().c_str() << ", ModuloActivo = " << m_pModuloActivo->GetNombre().c_str() << std::endl;
+#endif
 
-	if (m_pVistaActiva == pVista) {
-		GNC::GCS::IHerramienta* pH = m_HerramientaActiva[m_pModuloActivo];
-		if (pH != NULL) {
-			pH->SetVistaActiva(pVista);
-			pH->Conectar(false);
-			pH->Activar(false);
-			ActivarHerramientaBarra(pH,false);
-		}
-		m_pVistaActiva = NULL;
-		m_pModuloActivo = NULL;
+if (m_pVistaActiva == pVista) {
+GNC::GCS::IHerramienta* pH = m_HerramientaActivaBotonIzquierdo[m_pModuloActivo];
+if (pH != NULL) {
+pH->SetVistaActiva(pVista);
+pH->Conectar(false);
+pH->Activar(false);
+ActivarHerramientaBarra(pH,false);
+}
+m_pVistaActiva = NULL;
+m_pModuloActivo = NULL;
 
-		#ifdef _GINKGO_TRACE
-		std::cout << "  DES: VistaActiva = NULL, ModuloActivo = NULL" << std::endl;
-		#endif
+#ifdef _GINKGO_TRACE
+std::cout << "  DES: VistaActiva = NULL, ModuloActivo = NULL" << std::endl;
+#endif
 
-		RefrescarHerramientas();
-	}
+RefrescarHerramientas();
+}
 }*/
 
 // </editor-fold>
@@ -751,15 +1076,8 @@ void GNC::ControladorHerramientas::ActivarHerramientaPorDefecto(GNC::GCS::IContr
 }
 
 /* Activa la herramienta especificada al módulo especificado. pHerramienta puede ser NULL */
-void GNC::ControladorHerramientas::ActivarHerramienta(GNC::GCS::IControladorModulo* , GNC::GCS::IHerramienta::UID )
+void GNC::ControladorHerramientas::ActivarHerramienta(GNC::GCS::IControladorModulo* , GNC::GCS::IHerramienta::UID, int )
 {
-	;
-}
-
-/* Obtiene la herramienta activa del módulo especificado. Puede devolver NULL */
-GNC::GCS::IHerramienta* GNC::ControladorHerramientas::GetHerramientaActiva(GNC::GCS::IControladorModulo* )
-{
-	return NULL;
 }
 
 // </editor-fold>
@@ -770,7 +1088,7 @@ GNC::GCS::IHerramienta* GNC::ControladorHerramientas::GetHerramientaActiva(GNC::
 // <editor-fold defaultstate="collapsed" desc="Realizacion de interfaz ISolicitadorCambioHerramienta...">
 
 /* Recepción de solicitud de cambio de herramienta */
-void GNC::ControladorHerramientas::SolicitarActivacion(GNC::GCS::IHerramienta* herramienta)
+void GNC::ControladorHerramientas::SolicitarActivacion(GNC::GCS::IHerramienta* pTool, const GNC::GCS::TriggerButton& buttonMask)
 {
 	GNC::Entorno* pEntorno = GNC::Entorno::Instance();
 
@@ -778,7 +1096,7 @@ void GNC::ControladorHerramientas::SolicitarActivacion(GNC::GCS::IHerramienta* h
 
 	pEntorno->GetVentanaPrincipal()->SuperFreeze();
 
-	#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 	std::cout << "SolicitarActivacion( " << herramienta->Nombre.c_str() << " ). Modulo activo = ";
 	if (m_pModuloActivo != NULL) {
 		std::cout << m_pModuloActivo->GetNombre().c_str();
@@ -791,63 +1109,87 @@ void GNC::ControladorHerramientas::SolicitarActivacion(GNC::GCS::IHerramienta* h
 		std::cerr << "Aviso: ModuloActivo == NULL. Solicitud ignorada" << std::endl;
 		return;
 	}
-	#endif
+#endif
 
-	if (herramienta != NULL && (!herramienta->Habilitada() || !herramienta->Mostrada()) ) { // No permitimos activar herramientas no habilitadas u ocultas
-		std::cerr << "Herramienta no activada u oculta: " << herramienta->Nombre.c_str() << std::endl;
+	if (pTool != NULL && (!pTool->Habilitada() || !pTool->Mostrada()) ) { // No permitimos activar herramientas no habilitadas u ocultas
+		std::cerr << "Herramienta no activada u oculta: " << pTool->Nombre.c_str() << std::endl;
 		pEntorno->GetVentanaPrincipal()->SuperFreeze();
 		return;
 	}
 
-	HerramientaActivas::iterator it = m_HerramientaActiva.find(m_pModuloActivo);
-	if (it == m_HerramientaActiva.end()) {
-		pEntorno->GetVentanaPrincipal()->SuperFreeze();
-		throw GNC::GCS::ControladorHerramientasException("No se encontro el modulo asociado a la herramienta");
-	}
-
-	GNC::GCS::IHerramienta* herramientaAnterior = (*it).second;
-	m_pBarraSinOpciones->Show(false);
-
-	if (herramientaAnterior != NULL) { // Deshabilitamos la herramienta anterior
-		herramientaAnterior->Conectar(false);
-		herramientaAnterior->Activar(false);
-
-		ActivarHerramientaBarra(herramientaAnterior,false);
-	}
-	if (herramienta != NULL) {
-		if (herramienta->Habilitada()) {
-			herramienta->Activar(true);
-			ActivarHerramientaBarra(herramienta,true);
+	// Disable other tool using current button
+	if ( buttonMask.IsLeftEnabled() ) {
+		HerramientaActivas::iterator it = m_HerramientaActivaBotonIzquierdo.find(m_pModuloActivo);
+		if (it != m_HerramientaActivaBotonIzquierdo.end()) {
+			GNC::GCS::IHerramienta* pOtherTool = (*it).second;
+			if (pOtherTool != NULL && pOtherTool != pTool) {
+				pOtherTool->GetTriggerButton().DisableLeft();
+				if (pOtherTool->GetTriggerButton().IsEmpty()) {
+					pOtherTool->Conectar(false);
+					pOtherTool->Activar(false);
+					ActivarHerramientaBarra(pOtherTool, false);
+				}
+				else {
+					pOtherTool->Conectar(false);
+					pOtherTool->Conectar(true);
+				}
+			}
 		}
-		herramienta->Conectar(true);
+		pTool->GetTriggerButton().EnableLeft();
+		m_HerramientaActivaBotonIzquierdo[m_pModuloActivo] = pTool;
+	}
+	if ( buttonMask.IsRightEnabled() ) {
+
+		HerramientaActivas::iterator it = m_HerramientaActivaBotonDerecho.find(m_pModuloActivo);
+		if (it != m_HerramientaActivaBotonDerecho.end()) {
+			GNC::GCS::IHerramienta* pOtherTool = (*it).second;
+			if (pOtherTool != NULL && pOtherTool != pTool) {				
+				pOtherTool->GetTriggerButton().DisableRight();
+				if (pOtherTool->GetTriggerButton().IsEmpty()) {
+					pOtherTool->Conectar(false);
+					pOtherTool->Activar(false);
+					ActivarHerramientaBarra(pOtherTool, false);
+				}
+				else {
+					pOtherTool->Conectar(false);
+					pOtherTool->Conectar(true);
+				}				
+			}
+		}
+		pTool->GetTriggerButton().EnableRight();
+		m_HerramientaActivaBotonDerecho[m_pModuloActivo] = pTool;
+	}
+
+	if (pTool != NULL) {
+		if (pTool->Habilitada()) {			
+			pTool->Activar(true);
+			ActivarHerramientaBarra(pTool, true);
+		}
+		pTool->Conectar(false);
+		pTool->Conectar(true);
 
 		GNC::GCS::ControladorVistas::Instance()->GetVistaActiva()->Activar();
-
-		m_HerramientaActiva[m_pModuloActivo] = herramienta;
 	}
 
-
-
 	//pEntorno->GetPanelHerramientasSuperior()->GetParent()->Layout();
-
-        pEntorno->GetPanelHerramientasSuperior()->Layout();
-       // pEntorno->GetPanelHerramientasSuperior()->GetParent()->Refresh();
+	pEntorno->GetPanelHerramientasSuperior()->Layout();
+	// pEntorno->GetPanelHerramientasSuperior()->GetParent()->Refresh();
 
 	pEntorno->GetVentanaPrincipal()->SuperThaw();
 
-
-	#ifdef _GINKGO_TRACE
+#ifdef _GINKGO_TRACE
 	std::cout << "--" << std::endl;
-	#endif
+#endif
 
 }
 
 
-void GNC::ControladorHerramientas::OnActivarHerramienta(wxCommandEvent& event)
+void GNC::ControladorHerramientas::OnActivarHerramienta(long toolId, const GNC::GCS::TriggerButton& buttonmask)
 {
-	if(m_MapaIdsHerramientas.find(event.GetId()) != m_MapaIdsHerramientas.end()){
-		int idHerramienta = m_MapaIdsHerramientas[event.GetId()];
-		SolicitarActivacion(m_Herramientas[idHerramienta]);
+
+	if(m_MapaIdsHerramientas.find(toolId) != m_MapaIdsHerramientas.end()){
+		int idHerramienta = m_MapaIdsHerramientas[toolId];
+		SolicitarActivacion(m_Herramientas[idHerramienta], buttonmask);
 	}
 }
 
@@ -860,8 +1202,15 @@ void GNC::ControladorHerramientas::OnKeyAccelerator(wxKeyEvent& event)
 
 		if (pHerramienta != NULL) {
 			if (pHerramienta->Habilitada() && !pHerramienta->Activada() && pHerramienta->GetAcceleratorCode() == keyCode) {
-				SolicitarActivacion(pHerramienta);
-				event.Skip(false);				
+				GNC::GCS::TriggerButton buttonMask;
+				if (event.ShiftDown()) {
+					buttonMask.EnableRight();
+				}
+				else {
+					buttonMask.EnableLeft();
+				}
+				SolicitarActivacion(pHerramienta, buttonMask);
+				event.Skip(false);
 				break;
 			}
 		}
@@ -892,7 +1241,7 @@ void GNC::ControladorHerramientas::FreezeBarrasHerramientas()
 {
 	/*
 	for(MapaBarrasHerramientas::iterator it = m_MapaBarrasHerramientas.begin(); it!= m_MapaBarrasHerramientas.end(); it++) {
-		(*it).second->Freeze();
+	(*it).second->Freeze();
 	}
 	*/
 }
@@ -901,9 +1250,9 @@ void GNC::ControladorHerramientas::ThawBarrasHerramientas()
 {
 	/*
 	for(MapaBarrasHerramientas::iterator it = m_MapaBarrasHerramientas.begin(); it!= m_MapaBarrasHerramientas.end(); it++) {
-		if((*it).second->IsFrozen()) {
-			(*it).second->Thaw();
-		}
+	if((*it).second->IsFrozen()) {
+	(*it).second->Thaw();
+	}
 	}
 	*/
 }
