@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorhl7.cpp 4303 2011-10-18 10:31:44Z tovar $
+ *  $Id: controladorhl7.cpp 4555 2012-01-17 10:03:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -210,7 +210,7 @@ std::string GIL::HL7::ControladorHL7::GetUID(const std::string& idPlantilla) con
 			numTokens = tkidmodulo.CountTokens();
 			if (numTokens != 3){
 				std::ostringstream os;
-				os << _Std("Id malformed template in the module configuration") << m->GetNombre() << "(" << uid.c_str() << _Std("):\nIs not a valid HL7 identifier (ie: code^description^namespaceId)");
+				os << _Std("Id malformed template in the module configuration") << "(" << uid.c_str() << _Std("):\nIs not a valid HL7 identifier (ie: code^description^namespaceId)");
 				throw HL7Exception(os.str(),"PID");
 			}
 
@@ -231,21 +231,6 @@ std::string GIL::HL7::ControladorHL7::GetUID(const std::string& idPlantilla) con
 
 }
 
-std::string GIL::HL7::ControladorHL7::GetNombreModulo(const std::string& idPlantilla) const
-{
-	std::string uidModulo = GetUID(idPlantilla);
-	std::string nombreModulo("");
-
-	GNC::ControladorExtensiones::ListaModulos listaModulos = GNC::ControladorExtensiones::Instance()->Modulos();
-	for(GNC::ControladorExtensiones::IteradorListaModulos itModulos=listaModulos.begin();itModulos!=listaModulos.end();++itModulos){
-		std::ostringstream os;
-		os << itModulos->first;
-		if(os.str() == uidModulo) {
-			return itModulos->second->GetNombre();
-		}
-	}
-	return nombreModulo;
-}
 
 std::string GIL::HL7::ControladorHL7::GetUIDModulo(const std::string& idPlantilla) const
 {
