@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: dicommanager.cpp 4313 2011-10-18 13:23:37Z carlos $
+ *  $Id: dicommanager.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,7 +16,7 @@
 #include <wx/file.h>
 #include <wx/strconv.h>
 #include <wx/filename.h>
-
+#include <main/controllers/controladorlog.h>
 #include <api/globals.h>
 #include "dicommanager.h"
 #include <sstream>
@@ -667,30 +667,12 @@ namespace GIL
 					OFCondition cond;
 					if (itemPadre == NULL) {
 						cond = m_pDCMSource->getDataset()->insert(e, true, false);
-						char* str = NULL;
-						e->getString(str);
-						if(str!=NULL){
-							GTRACE("raiz << " << e->getTag().toString() <<  "=" << str)
-						}
-						else{
-							GTRACE("raiz << " << e->getTag().toString() <<  "=")
-						}
 					}
 					else {
 						cond = itemPadre->insert(e, true, false);
-						char* str = NULL;
-						e->getString(str);
-						if(str!=NULL){
-							GTRACE(itemPadre->getTag().toString().c_str() << " << " << e->getTag().toString() << " = " << str)
-						}
-						else{
-							GTRACE(itemPadre->getTag().toString().c_str() << " << " << e->getTag().toString() << " = ")
-						}
-
-
 					}
 					if (cond.bad()) {
-						std::cerr << "No se pudo insertar el elemento: (" << e->getTag().toString().c_str() << "): " << cond.text() << std::endl;
+						LOG_ERROR("DICOMMANAGER", "No se pudo insertar el elemento: (" << e->getTag().toString().c_str() << "): " << cond.text());
 					}
 					else {
 						numTotalInsertados++;
