@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicomservers.cpp 4272 2011-10-13 09:03:12Z tovar $
+ *  $Id: dicomservers.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -83,7 +83,7 @@ void DicomServerList::AddServer(const DicomServer& newServer, bool isDefault)
 		server->isDefault = isDefault;
 	}
 	else {
-		DicomServerHolder* newServerHolder = new DicomServerHolder(newServer.ID, newServer.AET, newServer.HostName, newServer.Port, newServer.Lossy, newServer.isDefault, newServer.PDU, newServer.useTLS, newServer.pacsUser, newServer.pacsPass, newServer.retrieveWithMove, newServer.retrieveSeries, newServer.verifyCredentials, newServer.certificate, newServer.privateKey);
+		DicomServerHolder* newServerHolder = new DicomServerHolder(newServer.ID, newServer.AET, newServer.HostName, newServer.Port, newServer.Lossy, newServer.isDefault, newServer.PDU, newServer.useTLS, newServer.pacsUser, newServer.pacsPass, newServer.retrieveWithMove, newServer.retrieveSeries, newServer.reuseConnection, newServer.verifyCredentials, newServer.certificate, newServer.privateKey);
 		newServerHolder->server.isDefault = isDefault;
 		if (serverHolders == NULL) {
 			lastInsertedHolder = serverHolders = newServerHolder;
@@ -219,7 +219,7 @@ void DicomServerList::Reload()
 		values.readIntValue("Puerto", port);
 		values.readIntValue("PDU", pdu, DEFAULT_PDU_LENGTH);
 
-		DicomServer server(id, aet, host, port, 0, false, pdu, false, "", "", false, true, false, "", "");
+		DicomServer server(id, aet, host, port, 0, false, pdu, false, "", "", false, false, true, false, "", "");
 		values.readBoolValue("isDefault",server.isDefault,false);
 		values.readBoolValue("useTLS",server.useTLS,false);
 		values.readStringValue("pacsUser", server.pacsUser);
@@ -228,6 +228,7 @@ void DicomServerList::Reload()
 		values.readStringValue("certificate", server.certificate);
 		values.readStringValue("privateKey", server.privateKey);
 		values.readBoolValue("retrieveWithMove",server.retrieveWithMove,true);
+		values.readBoolValue("reuseConnection", server.reuseConnection, false);
 		values.readBoolValue("retrieveSeries",server.retrieveSeries,true);
 
 		AddServer(server, server.isDefault);
@@ -246,7 +247,7 @@ void DicomServerList::Reload()
 	GNC::GCS::ConfigurationController::Instance()->readIntGeneral("/GinkgoCore/PACS/Local", "Puerto", port, 11112);
 	std::string localAet = GNC::Entorno::Instance()->GetDicomLocalAET();
 	
-	localServer = new DicomServer("ginkgo",localAet, "localhost", port, 0, false, 16384,false, "", "", false, true, false, "", "");
+	localServer = new DicomServer("ginkgo",localAet, "localhost", port, 0, false, 16384,false, "", "", false, true,false, false, "", "");
 	GNC::GCS::ConfigurationController::Instance()->readBoolGeneral("/GinkgoCore/PACS/Local", "useTLS", localServer->useTLS, false);
 	GNC::GCS::ConfigurationController::Instance()->readBoolGeneral("/GinkgoCore/PACS/Local", "verifyCredentials", localServer->verifyCredentials, false);
 #ifdef GINKGO_PRIVATE_KEY
