@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: pacscontroller.cpp 4351 2011-10-31 09:15:33Z tovar $
+*  $Id: pacscontroller.cpp 4516 2012-01-12 12:18:40Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -30,9 +30,12 @@
 #include <api/ientorno.h>
 #include <api/dicom/imodelodicom.h>
 #include <main/entorno.h>
-#include <wx/dir.h>
 #include <wx/filename.h>
+#include <wx/dir.h>
+#include <wx/file.h>
+#include <wx/tokenzr.h>
 #include <main/controllers/configurationcontroller.h>
+#include <main/controllers/dcmtk/dicommanager.h>
 
 #include <api/icontextoestudio.h>
 
@@ -93,7 +96,7 @@ namespace GIL {
 
 		}
 
-		void PACSController::Store(DcmDataset* dset)
+		void PACSController::Store(const std::string& fileName, DcmDataset* dset)
 		{
 
 			GTRACE("PACSController::Store() ");
@@ -122,9 +125,6 @@ namespace GIL {
 			if (dset->findAndGetOFString(DCM_SOPInstanceUID, OFImagenUId).good()) {
 				ImagenUId.assign(OFImagenUId.c_str());
 			}
-
-			DcmFileFormat f(dset);
-
 			//std::cout << "PacienteUId = " << PacienteUId << std::endl;
 			//std::cout << "EstudioUId = " << EstudioUId << std::endl;
 			//std::cout << "SerieUId = " << SerieUId << std::endl;
@@ -133,7 +133,9 @@ namespace GIL {
 			std::string rutaStd;
 			GetRutaImagenTemp(PacienteUId,EstudioUId,SerieUId,ImagenUId,rutaStd);
 
-			f.saveFile(rutaStd.c_str(), dset->getOriginalXfer());
+			if (!wxRenameFile(FROMPATH(fileName), FROMPATH(rutaStd))) {
+				LOG_ERROR("PACSCONTROLLER-STORE", "Error writting file to temp dir");
+			}
 		}
 
 		IModeloDicom* PACSController::BuscarPaciente(
@@ -524,17 +526,92 @@ namespace GIL {
 									{
 										OFString uidImagen;
 										FileRecord->findAndGetOFString(DCM_ReferencedSOPInstanceUIDInFile, uidImagen);
-
+										
+										wxString currentPath = FROMPATH(basePath);
+										
 										wxString wxStr = FROMPATH(tmpString);
 										wxString separador = wxFileName::GetPathSeparator();
 										wxString barra = wxT('\\');
 										wxStr.Replace(barra,separador);
-										std::ostringstream ostr;
-										tmpString = TOPATH(wxStr);
-										ostr << basePath << separador.ToUTF8();
-										ostr << tmpString;
 
-										pModelo->InsertarImagen(uidSerie.c_str(),uidImagen.c_str(),ostr.str());
+										if (wxFileExists(currentPath + separador + wxStr)) 
+										{
+											currentPath+= separador + wxStr;
+										} 
+										else
+										{										
+											// recase: Get case insensitive path (if needed)
+											wxStringTokenizer tokenizer(wxStr, separador);
+											bool validPath = true; // When false, "recase" will do nothing more
+											
+											while (validPath && tokenizer.HasMoreTokens() )
+											{
+												wxString relPathPart = tokenizer.GetNextToken();
+												
+												if (tokenizer.HasMoreTokens()) { // Scanning subdirectories
+													wxString entry;
+													if (validPath && !wxDir::Exists(currentPath + separador + relPathPart)) {
+														wxDir dir;
+														bool cont = dir.Open(currentPath) && dir.GetFirst(&entry, wxEmptyString, wxDIR_DIRS | wxDIR_HIDDEN );
+														bool found = false;
+														while ( cont )
+														{
+															if (entry.CmpNoCase(relPathPart) == 0) {
+																found = true;
+																cont = false;
+															}
+															if (cont) {
+																cont = dir.GetNext(&entry);
+															}
+														}
+														if (!found) {
+															currentPath += separador + relPathPart; // Assign case sentitive subdir to current path. (Will be non-existing)
+															validPath = false;
+														}
+														else {
+															currentPath += separador + entry; // Assign case sentitive subdir to current path
+														}
+													}
+													else {
+														currentPath += separador + relPathPart; // Assign case sentitive subdir to current path (Could be non-existing if validPath == false)
+													}
+													
+												}
+												else { // Scanning end file
+													
+													wxString entry;
+													
+													if (validPath && !wxFile::Access(currentPath + separador + relPathPart, wxFile::read)) {
+														wxDir dir;
+														bool cont = dir.Open(currentPath) && dir.GetFirst(&entry, wxEmptyString, wxDIR_FILES | wxDIR_HIDDEN );
+														bool found = false;
+														while ( cont )
+														{
+															if (entry.CmpNoCase(relPathPart) == 0) {
+																cont = false;
+																found = true;
+															}
+															if (cont) {
+																cont = dir.GetNext(&entry);
+															}
+														}
+														if (!found) {
+															currentPath += separador + relPathPart; // Assign case sentitive filename to current path. (Will be non-existing)
+															validPath = false;
+														}
+														else {
+															currentPath += separador + entry; // Assign case sentitive filename to current path
+														}
+													}
+													else {
+														currentPath += separador + relPathPart; // Assign case sentitive filename to current path (Could be non-existing if validPath == false)
+													}
+												}
+												
+											}
+										}//end recase
+										
+										pModelo->InsertarImagen(uidSerie.c_str(), uidImagen.c_str(), std::string(TOPATH(currentPath)));
 									}
 								}
 							}
@@ -613,18 +690,35 @@ namespace GIL {
 			return valido;
 		}
 
-		bool PACSController::ObtenerEstudio(void* connectionKey, const std::string& serverId, const std::string& uidEstudio, const std::string& AccNumber, IModeloDicom* pModelo, GNC::IProxyNotificadorProgreso* pNotificador)
+		void PACSController::FillInQuery(const GIL::DICOM::TipoJerarquia& base, DcmDataset* query)
 		{
-			//ESTO ES PARA QUE FUNCIONE EL PACS DE SIEMENS, VER SI SE PUEDE QUITAR...
-			ReleaseConnection(connectionKey);
-			GetConnection(connectionKey);
+			for (ListaTags::const_iterator it = base.tags.begin(); it != base.tags.end(); it++) {
+				DcmElement* e = GIL::DICOM::DICOMManager::CrearElementoConValor((*it).first.c_str());
 
-			GTRACE("PACSController::ObtenerEstudio( " << serverId.c_str() << ", " << uidEstudio.c_str() << ", " << uidSerie.c_str());
+				if (e != NULL) {
+					e->putString( (*it).second.c_str() );
+					OFCondition cond;
+					cond = query->insert(e, true, false);
+					
+					if (cond.bad()) {
+						LOG_ERROR("PACSCONTROLLER", "No se pudo insertar el elemento: (" << e->getTag().toString().c_str() << "): " << cond.text());
+					}
+				}
+			}
+		}
+
+		bool PACSController::ObtenerEstudio(void* connectionKey, const std::string& serverId, const GIL::DICOM::TipoJerarquia& base, IModeloDicom* pModelo, GNC::IProxyNotificadorProgreso* pNotificador)
+		{
+			DicomServerList* listaServidores = DicomServerList::Instance();
+			DicomServer* server = listaServidores->GetServer(serverId);
+			if (!server->GetReuseConnection()) {
+				ReleaseConnection(connectionKey);
+				GetConnection(connectionKey);
+			}
 
 			if (pModelo == NULL) {
 				return false;
 			}
-			DicomServerList* listaServidores = DicomServerList::Instance();
 
 			DcmDataset query;
 			DcmElement* e = NULL;
@@ -648,33 +742,23 @@ namespace GIL {
 			e = newDicomElement(DCM_StudyID);
 			query.insert(e);
 
-			if (!AccNumber.empty()){
-				e = newDicomElement(DCM_AccessionNumber);
-				e->putString(AccNumber.c_str());
-			    query.insert(e);
-			}
+
+			FillInQuery(base, &query);
 
 			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
-			DicomServer* server = listaServidores->GetServer(serverId);
 			if (server->GetRetrieveSeries()) {
 				//buscar + descargar series...
 				//we have to know the series uids and obtain series by series
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("SERIES");
-				query.insert(e);
-
-				if (!uidEstudio.empty()) {		
-					e = newDicomElement(DCM_StudyInstanceUID);
-					e->putString(uidEstudio.c_str());
-					query.insert(e);
-				}
+				query.insert(e, true);
 
 				e = newDicomElement(DCM_SeriesInstanceUID);
-				query.insert(e);
+				query.insert(e, true);
 
 				e = newDicomElement(DCM_Modality);
-				query.insert(e);
+				query.insert(e, true);
 
 				std::list<std::string> listOfUIDS;
 				std::list<std::string> listOfModalities;
@@ -684,7 +768,6 @@ namespace GIL {
 
 					std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
-					DicomServer* server = listaServidores->GetServer(serverId);
 					if (server->useTLS) {
 						f.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
 					}
@@ -728,24 +811,21 @@ namespace GIL {
 				for (std::list<std::string>::iterator itUIDS = listOfUIDS.begin(), itModalities = listOfModalities.begin();
 					itUIDS != listOfUIDS.end(); itUIDS++, itModalities++) 
 				{
-//ESTO ES PARA QUE FUNCIONE EL PACS DE SIEMENS, VER SI SE PUEDE QUITAR...
-					ReleaseConnection(connectionKey);
-					GetConnection(connectionKey);
-//
-					ObtenerSerie(connectionKey, serverId, (*itUIDS), pModelo, pNotificador, (*itModalities));
+					if (!server->GetReuseConnection()) {
+						ReleaseConnection(connectionKey);
+						GetConnection(connectionKey);
+					}
+					GIL::DICOM::TipoJerarquia baseAux = base;
+					baseAux.tags["0020|000e"] = (*itUIDS);
+					baseAux.tags["0008|0060"] = (*itModalities);
+					ObtenerSerie(connectionKey, serverId, baseAux, pModelo, pNotificador);
 				}
 
 				query.clear();	
 			} else if (server->GetRetrieveWithMove()) {
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("STUDY");
-				query.insert(e);
-				
-				if (!uidEstudio.empty()) {		
-					e = newDicomElement(DCM_StudyInstanceUID);
-					e->putString(uidEstudio.c_str());
-					query.insert(e);
-				}
+				query.insert(e, true);
 
 				int puerto = 11112;
 				{
@@ -781,15 +861,8 @@ namespace GIL {
 				//we have to know the series uids and obtain series by series
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("SERIES");
-				
-				//needed to make find
-				e = newDicomElement(DCM_StudyInstanceUID);
-				if (uidEstudio.empty()) {
-					//throw GIL::DICOM::PACSException(_Std("Invalid study query: No StudyInstanceUID provided"));
-				}
-				e->putString(uidEstudio.c_str());
-				query.insert(e);
-				
+				query.insert(e, true);
+								
 				e = newDicomElement(DCM_SeriesInstanceUID);
 				query.insert(e);
 
@@ -801,7 +874,6 @@ namespace GIL {
 
 				std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
-				DicomServer* server = listaServidores->GetServer(serverId);
 				if (server->useTLS) {
 					f.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
 				}
@@ -825,14 +897,21 @@ namespace GIL {
 					if (stack->elem(i)->ident() == EVR_dataset) {
 						DcmDataset* dset = dynamic_cast<DcmDataset*>(stack->elem(i));
 						if (dset) {
+							OFString OFSStudyInstanceUID;
 							OFString OFSSeriesInstanceUID;
 							OFString OFSeriesModality;
 							if ( dset->findAndGetOFString(DCM_SeriesInstanceUID, OFSSeriesInstanceUID).good() && dset->findAndGetOFString(DCM_Modality, OFSeriesModality).good() )
 							{
-								std::string seriesInstanceUID(OFSSeriesInstanceUID.c_str());
-								std::string seriesModality(OFSeriesModality.c_str());
+								GIL::DICOM::TipoJerarquia baseAux = base;
+								std::string studyInstanceUID;
+								if (dset->findAndGetOFString(DCM_StudyInstanceUID, OFSStudyInstanceUID).good()) {
+									baseAux.tags["0020|000d"] = OFSStudyInstanceUID.c_str();
+								}
 
-								ObtenerSerie(connectionKey, serverId, seriesInstanceUID, pModelo, pNotificador, seriesModality);
+								baseAux.tags["0020|000e"] = OFSSeriesInstanceUID.c_str();
+								baseAux.tags["0008|0060"] = OFSeriesModality.c_str();
+
+								ObtenerSerie(connectionKey, serverId, baseAux, pModelo, pNotificador);
 							}
 						}
 
@@ -847,17 +926,18 @@ namespace GIL {
 
 		}
 
-		bool PACSController::ObtenerSerie(void* connectionKey, const std::string& serverId, const std::string& uidSerie, IModeloDicom* pModelo, GNC::IProxyNotificadorProgreso* pNotificador, const std::string& seriesModality)
+		bool PACSController::ObtenerSerie(void* connectionKey, const std::string& serverId, const GIL::DICOM::TipoJerarquia& base, IModeloDicom* pModelo, GNC::IProxyNotificadorProgreso* pNotificador)
 		{
-			GTRACE("PACSController::ObtenerSerie( " << serverId.c_str() << ", " << uidEstudio.c_str() << ", " << uidSerie.c_str());			
-
 			if (pModelo == NULL) {
 				return false;
 			}
 			DicomServerList* listaServidores = DicomServerList::Instance();
-
 			DicomServer* server = listaServidores->GetServer(serverId);
-			std::string modality = seriesModality;
+
+			std::string modality;
+			if (base.tags.find("0008|0060") != base.tags.end()) {
+				modality = base.tags.find("0008|0060")->second;
+			}
 
 			DcmElement* e = NULL;
 			DcmDataset query;
@@ -865,19 +945,20 @@ namespace GIL {
 			unsigned int numResults = 0;
 
 			if (!server->GetRetrieveWithMove() && modality.empty()) { // We have to find series modality
+				FillInQuery(base, &query);
+
 				e = newDicomElement(DCM_SpecificCharacterSet);
 				e->putString("ISO_IR 192");
 				query.insert(e);
 
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("SERIES");
-				query.insert(e);
+				query.insert(e, true);
 				
 				e = newDicomElement(DCM_StudyInstanceUID);
 				query.insert(e);
 
 				e = newDicomElement(DCM_SeriesInstanceUID);
-				e->putString(uidSerie.c_str());
 				query.insert(e);
 
 				e = newDicomElement(DCM_Modality);
@@ -888,7 +969,6 @@ namespace GIL {
 
 				std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
-				DicomServer* server = listaServidores->GetServer(serverId);
 				if (server->useTLS) {
 					f.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
 				}
@@ -928,10 +1008,10 @@ namespace GIL {
 
 					}
 				}
-
 				query.clear();
 			}// end query modality
 
+			FillInQuery(base, &query);
 
 			e = newDicomElement(DCM_SpecificCharacterSet);
 			e->putString("ISO_IR 192");
@@ -939,15 +1019,9 @@ namespace GIL {
 
 			e = newDicomElement(DCM_QueryRetrieveLevel);
 			e->putString("SERIES");
-			query.insert(e);
-
-			/* WARNING YOU CANT INSERT EMPTY STUDY INSTANCE UID AT SERIES LEVEL
-			e = newDicomElement(DCM_StudyInstanceUID);
-			query.insert(e);
-			*/
+			query.insert(e, true);
 
 			e = newDicomElement(DCM_SeriesInstanceUID);
-			e->putString(uidSerie.c_str());
 			query.insert(e);
 
 			e = newDicomElement(DCM_Modality);
@@ -987,7 +1061,6 @@ namespace GIL {
 					a.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
 				}
 				a.QueryServer(&query, server, pModelo, localAET, CT_MoveSerie);
-
 			}
 			else {
 				if (server) {
@@ -1011,45 +1084,38 @@ namespace GIL {
 				if (!a.QueryServer(&query, server, pModelo, localAET, CT_MoveSerie)) {
 					return false;
 				}
-
 			}
 
 			return true;
 
 		}
 
-		bool PACSController::ObtenerImagen(void* connectionKey, const std::string& serverId, const std::string& uidImagen, IModeloDicom* pModelo,GNC::IProxyNotificadorProgreso* pNotificador)
+		bool PACSController::ObtenerImagen(void* connectionKey, const std::string& serverId, const GIL::DICOM::TipoJerarquia& base, IModeloDicom* pModelo,GNC::IProxyNotificadorProgreso* pNotificador)
 		{
-			GTRACE("PACSController::ObtenerImagen( " << serverId.c_str() << ", " << uidEstudio.c_str() << ", " << uidSerie.c_str() << uidImagen.c_stR() << ")");
-
 			if (pModelo == NULL) {
 				return false;
 			}
 			DicomServerList* listaServidores = DicomServerList::Instance();
+			DicomServer* server = listaServidores->GetServer(serverId);
 
 			DcmDataset query;
 			DcmElement* e = NULL;
 
+			FillInQuery(base, &query);
+
 			e = newDicomElement(DCM_SpecificCharacterSet);
 			e->putString("ISO_IR 192");
 			query.insert(e);
 
 			e = newDicomElement(DCM_QueryRetrieveLevel);
 			e->putString("IMAGE");
-			query.insert(e);
-
-			e = newDicomElement(DCM_SOPInstanceUID);
-			if (!uidImagen.empty()) {
-				e->putString(uidImagen.c_str());
-			}
-			query.insert(e);
+			query.insert(e, true);
 
 			e = newDicomElement(DCM_InstanceNumber);
 			query.insert(e);
 
 			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
-			DicomServer* server = listaServidores->GetServer(serverId);
 			if (server->GetRetrieveWithMove()) {
 
 				if (server) {
@@ -1106,22 +1172,22 @@ namespace GIL {
 					base.getTag("0020|000d", uidEstudio);
 					base.getTag("0008|0050", accNumber);
 					if (accNumber == "" && uidEstudio == "") {
-						throw GIL::DICOM::PACSException(_Std("You have to specify uid study or accession number"));
+						throw GIL::DICOM::PACSException(_Std("You have to specify at least uid study or accession number"));
 					}
 
-					ObtenerEstudio(connectionKey, serverId, uidEstudio, accNumber, pModelo, pNotificador);
+					ObtenerEstudio(connectionKey, serverId, base, pModelo, pNotificador);
 				} else if (strTmp == "SERIES") {
 					std::string uidSeries;
 					if (!base.getTag("0020|000e",uidSeries)) {
-						throw GIL::DICOM::PACSException(_Std("You have to specify uid series"));
+						throw GIL::DICOM::PACSException(_Std("You have to specify at least uid series"));
 					}
-					ObtenerSerie(connectionKey, serverId, uidSeries, pModelo, pNotificador);
+					ObtenerSerie(connectionKey, serverId, base, pModelo, pNotificador);
 				} else if (strTmp == "IMAGE")  {
 					std::string uidImage;
 					if (!base.getTag("0008|0018",uidImage)) {
 						throw GIL::DICOM::PACSException(_Std("You have to specify uid series"));
 					}
-					ObtenerImagen(connectionKey, serverId, uidImage, pModelo, pNotificador);
+					ObtenerImagen(connectionKey, serverId, base, pModelo, pNotificador);
 				} else  {
 					throw GIL::DICOM::PACSException(_Std("Unknown query/retrieve level"));
 				}
