@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: pacscontroller.h 4392 2011-11-10 14:51:21Z tovar $
+ *  $Id: pacscontroller.h 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -91,11 +91,12 @@ namespace GIL {
 
 			virtual void SubirArchivos(void* connectionKey, const std::string& serverId, const std::vector<std::string>& pathsSubida, GNC::IProxyNotificadorProgreso* pNotificador, TipoTransferSyntaxEnvio transferSyntax);
 
+			virtual void FillInQuery(const GIL::DICOM::TipoJerarquia& base, DcmDataset* query);
+
 			virtual bool ObtenerEstudio(
 				void* connectionKey,
 				const std::string& serverId,
-				const std::string& uidEstudio,
-				const std::string& AccNumber,
+				const GIL::DICOM::TipoJerarquia& base,
 				IModeloDicom* pModelo,
 				GNC::IProxyNotificadorProgreso* pNotificador
 			);
@@ -103,16 +104,15 @@ namespace GIL {
 			virtual bool ObtenerSerie(
 				void* connectionKey,
 				const std::string& serverId,
-				const std::string& uidSerie,
+				const GIL::DICOM::TipoJerarquia& base,
 				IModeloDicom* pModelo,
-				GNC::IProxyNotificadorProgreso* pNotificador,
-				const std::string& seriesModality  = ""
+				GNC::IProxyNotificadorProgreso* pNotificador
 			);
 
 			virtual bool ObtenerImagen(
 				void* connectionKey,
 				const std::string& serverId,
-				const std::string& uidImagen,
+				const GIL::DICOM::TipoJerarquia& base,
 				IModeloDicom* pModelo,
 				GNC::IProxyNotificadorProgreso* pNotificador
 			);
