@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parserxmlenglish.cpp 4034 2011-07-21 09:44:05Z tovar $
+ *  $Id: parserxmlenglish.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -217,7 +217,7 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 						throw HL7XMLException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
-						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), pacsServer.verify, pacsServer.cert, pacsServer.key), true );
+						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key), true );
 					} else {
 						throw HL7XMLException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
 					}
@@ -279,6 +279,9 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 		else if (propVal.CmpNoCase(wxT("print")) == 0) {
 			modelo->accion = GIL::IModeloIntegracion::TA_Imprimir;
 		}
+		else if (propVal.CmpNoCase(wxT("open")) == 0) {
+			modelo->accion = GIL::IModeloIntegracion::TA_Open;
+		}
 		else {
 			throw HL7XMLException(_Std("\"action\" attribute invalid at \"gnkworkflow\" scope" ), xpp, "CONF/template");
 		}
@@ -325,6 +328,10 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 
 	//recorremos los hijos de las gnkworkflows
 	for (wxXmlNode* hijo = nodo->GetChildren(); hijo != NULL; hijo = hijo->GetNext()) {
+		//files...
+		if (hijo->GetName().CmpNoCase(wxT("file")) == 0 && hijo->GetChildren() != NULL){
+			modelo->Files.push_back(std::string(hijo->GetChildren()->GetContent().ToUTF8()));
+		}
 		//parseamos los campos dimse
 		if(hijo->GetName().CmpNoCase(wxT("query-retrieve-level")) == 0){
 			propVal = hijo->GetPropVal(wxT("value"), wxEmptyString);
