@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parserxmlspanish.cpp 4034 2011-07-21 09:44:05Z tovar $
+ *  $Id: parserxmlspanish.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -218,7 +218,7 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 						throw HL7XMLException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
-						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), pacsServer.verify, pacsServer.cert, pacsServer.key), true );
+						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key), true );
 					} else {
 						throw HL7XMLException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
 					}
