@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: streamingloader.cpp 4314 2011-10-19 09:44:46Z carlos $
+ *  $Id: streamingloader.cpp 4438 2011-11-22 14:24:34Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -162,7 +162,8 @@ GNC::StreamingLoader::StreamingLoader()
 	m_IO = ImageIO::New();
 	m_IO->SetLoadPrivateTags(false);
 	//Esto da leaks no activar
-	m_IO->SetLoadSequences(false);
+	//m_IO->SetLoadSequences(false);
+	//
 	m_IO->SetUseStreamedReading(true);
 	m_IO->SetMaxSizeLoadEntry(1024); // No permitir cargar campos de mas de 1K
 	m_pOutput = vtkSmartPointer<vtkImageChangeInformation>::New();
