@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: xmlrpccontroller.cpp 3893 2011-06-21 13:01:56Z tovar $
+*  $Id: xmlrpccontroller.cpp 4477 2011-12-13 11:16:56Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -306,22 +306,25 @@ namespace XmlRpc {
 			std::string studyInstanceUID = std::string(params[0]["studyInstanceUID"]);
 			std::string seriesInstanceUID = std::string(params[0]["seriesInstanceUID"]);
 
-			if (seriesInstanceUID != "") {
-				GADAPI::ComandoPACSParams * pParams = new GADAPI::ComandoPACSParams(serverId, seriesInstanceUID, GADAPI::ComandoPACSParams::TA_Serie);
+			GIL::DICOM::TipoJerarquia base;
+			if (!accesssionNumber.empty()) {
+				base.tags["0008|0050"] = accesssionNumber;
+			}
+			if (!studyInstanceUID.empty()) {			
+				base.tags["0020|000d"] = studyInstanceUID; //study instance uid
+			}
+
+			if (!seriesInstanceUID.empty()) {
+				base.tags["0020|000e"] = seriesInstanceUID; //series instance uid
+				base.tags["0008|0052"] = "SERIES";
+				GADAPI::ComandoPACSParams * pParams = new GADAPI::ComandoPACSParams(serverId, base);
 				GADAPI::ComandoPACS* pComandoPACS = new GADAPI::ComandoPACS(pParams);
 				GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Downloading from PACS..."), pComandoPACS, NULL);
 			} else if (accesssionNumber != "" || studyInstanceUID != "")
 			{
-				GIL::DICOM::TipoJerarquia base;
 				base.tags["0008|0052"] = "STUDY";
-				if (studyInstanceUID != "") {
-					base.tags["0020|000d"] = studyInstanceUID;					
-				}
-				if (accesssionNumber != "") {
-					base.tags["0008|0050"] = accesssionNumber;					
-				}
 
-				GADAPI::ComandoPACSParams * pParams = new GADAPI::ComandoPACSParams("", base);
+				GADAPI::ComandoPACSParams * pParams = new GADAPI::ComandoPACSParams(serverId, base);
 				GADAPI::ComandoPACS* pComandoPACS = new GADAPI::ComandoPACS(pParams);
 				GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync("Descargando PACS...",pComandoPACS, NULL);
 			}
