@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: entorno.cpp 4327 2011-10-25 06:55:31Z carlos $
+ *  $Id: entorno.cpp 4508 2012-01-11 12:53:39Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -87,7 +87,10 @@ GNC::Entorno* GNC::Entorno::m_pInstancia = NULL;
 
 GNC::Entorno::Entorno()
 {
-	DJEncoderRegistration::registerCodecs();
+	DJEncoderRegistration::registerCodecs(ECC_lossyYCbCr,
+		EUC_default, // UID generation (never create new UID's)
+		OFFalse, // verbose
+		0, 0, 0, true, ESS_444, true); // optimize huffman table
 	DJDecoderRegistration::registerCodecs();
 
 	DcmRLEEncoderRegistration::registerCodecs();
@@ -103,7 +106,7 @@ GNC::Entorno::Entorno()
 	m_isChildInstance = false;
 	
 	std::ostringstream os;
-	os << GINKGO_VERSION << "." << GINKGO_SUB_VERSION << "." << GINKGO_SUB_RELEASE << " " << GINKGO_CODENAME;
+	os << GINKGO_VERSION << "." << GINKGO_SUB_VERSION << "." << GINKGO_SUB_RELEASE << "." << ParseSVNBuild(GINKGO_BUILD) << "-" << GINKGO_CODENAME;
 
 	m_GinkgoVersion = os.str();
 
@@ -342,6 +345,20 @@ std::string GNC::Entorno::CreateGinkgoTempDir()
 	return std::string(TOPATH(wxNuevoDirTemp));
 }
 
+void GNC::Entorno::RemoveDirRecursive(const std::string& path)
+{
+	wxString pathWx = FROMPATH(path);
+	RemoveTempDir(pathWx);
+}
+
+std::string GNC::Entorno::CreateGinkgoTempFile()
+{
+	std::string directory = CreateGinkgoTempDir();
+	std::ostringstream ostr;
+	ostr << directory << (char)wxFileName::GetPathSeparator() << "tmp";
+	return ostr.str();
+}
+
 const std::string& GNC::Entorno::GetGinkgoLanguageDir()
 {
 	return m_GinkgoLanguageDir;
