@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: dialogoadquisicion.cpp 4402 2011-11-11 13:44:34Z tovar $
+*  $Id: dialogoadquisicion.cpp 4477 2011-12-13 11:16:56Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -687,7 +687,7 @@ void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
 							forceInit = wxMessageBox(_("Studies are already in the download queue.\nDo you want to repeat download?"),_("Download warning"),wxICON_INFORMATION|wxYES_NO) == wxYES;
 						}
 
-						bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descStudy, uidStudy,modStudy, forceInit, false);
+						bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descStudy,modStudy, forceInit, false, uidStudy, "");
 						m_pTreeListResultados->SetItemBold(seleccion, downloaded);
 					}
 
@@ -698,6 +698,7 @@ void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
 						//estamos en un estudio
 						std::string uidPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion), COLUMNA_UID).ToUTF8());
 						std::string descPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion)).ToUTF8());
+						std::string uidStudy = std::string(m_pTreeListResultados->GetItemText(seleccion, COLUMNA_UID).ToUTF8());
 
 						// Necesitamos buscar las series
 
@@ -723,7 +724,7 @@ void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
 									}
 
 									std::string descSerie = std::string( (m_pTreeListResultados->GetItemText(cid) + _T("(") + m_pTreeListResultados->GetItemText(cid, COLUMNA_MODALIDAD) + _T(")") ).ToUTF8());
-									bool downloaded = m_pDownloadPanel->AddDownload(server, descPaciente, descSerie, uidSerie,modalidadSerie,forceInit, true);
+									bool downloaded = m_pDownloadPanel->AddDownload(server, descPaciente, descSerie, modalidadSerie,forceInit, true, uidStudy, uidSerie);
 									m_pTreeListResultados->SetItemBold(cid, downloaded);
 									numSeriesDescargadas++;
 								} else {
@@ -800,6 +801,7 @@ void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
 				//estamos en una serie
 				std::string uidPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(m_pTreeListResultados->GetItemParent(seleccion)), COLUMNA_UID).ToUTF8());
 				std::string descPaciente = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(m_pTreeListResultados->GetItemParent(seleccion))).ToUTF8());
+				std::string uidStudy = std::string(m_pTreeListResultados->GetItemText(m_pTreeListResultados->GetItemParent(seleccion), COLUMNA_UID).ToUTF8());
 
 				std::string uidSerie = std::string(m_pTreeListResultados->GetItemText(seleccion, COLUMNA_UID).ToUTF8());
 				std::string descSerie = std::string( (m_pTreeListResultados->GetItemText(seleccion) + _T("(") + m_pTreeListResultados->GetItemText(seleccion, COLUMNA_MODALIDAD) + _T(")") ).ToUTF8());
@@ -816,7 +818,7 @@ void GNC::GUI::DialogoAdquisicion::AddDescarga(bool lanzarBusqueda)
 							forceInit = wxMessageBox(_("Series were already in the download queue.\nDo you want to force download?"),_("Download warning"),wxICON_INFORMATION|wxYES_NO) == wxYES;
 						}
 
-						bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descSerie, uidSerie,modSerie, forceInit, true);
+						bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descSerie, modSerie, forceInit, true, uidStudy, uidSerie);
 						m_pTreeListResultados->SetItemBold(seleccion, downloaded);
 					}
 				}
@@ -1054,6 +1056,7 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 
 								std::string uidPaciente = std::string(m_pTreeListResultados->GetItemText(pacienteTreeId, COLUMNA_UID).ToUTF8());
 								std::string descPaciente = std::string(m_pTreeListResultados->GetItemText(pacienteTreeId).ToUTF8());
+								std::string uidStudy = std::string(m_pTreeListResultados->GetItemText(estudioTreeId, COLUMNA_UID).ToUTF8());
 
 								std::string uidSerie = std::string(m_pTreeListResultados->GetItemText(serieTreeId, COLUMNA_UID).ToUTF8());
 								std::string descSerie = std::string( (m_pTreeListResultados->GetItemText(serieTreeId) + _T("(") + m_pTreeListResultados->GetItemText(serieTreeId, COLUMNA_MODALIDAD) + _T(")") ).ToUTF8());
@@ -1068,7 +1071,7 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 										questionMade = true;
 									}
 
-									bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descSerie, uidSerie, modalidadSerie,forceInit, true);
+									bool downloaded = m_pDownloadPanel->AddDownload(GetServerSeleccionado(), descPaciente, descSerie, modalidadSerie,forceInit, true, uidStudy, uidSerie);
 									m_pTreeListResultados->SetItemBold(serieTreeId, downloaded);
 								} else {
 									listaModalidad.insert(modalidadSerie);
