@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguraciongeneral.cpp 4409 2011-11-17 14:03:02Z tovar $
+ *  $Id: panelconfiguraciongeneral.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -247,83 +247,7 @@ namespace GNC {
 			}
 		}
 
-		void PanelConfiguracionGeneral::Exportar(wxXmlNode* pRaiz)
-		{
-			wxXmlNode* pEstacion = NULL;
-			for(pEstacion =pRaiz->GetChildren(); pEstacion!=NULL; pEstacion = pEstacion->GetNext()) {
-				if(pEstacion->GetName() == wxT("Estacion")) {
-					break;
-				}
-			}
-			if(pEstacion == NULL) {
-				pEstacion = new wxXmlNode(pRaiz,wxXML_ELEMENT_NODE,wxT("Estacion"));
-			}
-
-			wxXmlNode* nodo = new wxXmlNode(pEstacion,wxXML_ELEMENT_NODE,wxT("DicomDir"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),m_pDICOMDir->GetValue());
-
-			if (m_pComboLanguage->GetStringSelection() != _("Default")) {
-				int language = wxLANGUAGE_ENGLISH;
-				{
-					std::string selectedLanguage(m_pComboLanguage->GetStringSelection().ToUTF8());
-					for (TMapLanguages::iterator it  = m_mapLanguages.begin(); it != m_mapLanguages.end(); ++it) {
-						if ((*it).first == selectedLanguage) {
-							language = (*it).second;
-							break;
-						}
-					}
-				}
-				nodo  = new wxXmlNode(pEstacion,wxXML_ELEMENT_NODE,wxT("Language"));
-				new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),wxString::Format(wxT("%d"), language));
-			}
-
-			nodo  = new wxXmlNode(pEstacion,wxXML_ELEMENT_NODE,wxT("CheckForUpdates"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""), m_pCheckForUpdates->GetValue()?wxT("true"):wxT("false"));
-
-		}
-
-		void PanelConfiguracionGeneral::Importar(wxXmlNode* pRaiz)
-		{
-			wxXmlNode* pEstacion = NULL;
-			for(pEstacion =pRaiz->GetChildren(); pEstacion!=NULL; pEstacion = pEstacion->GetNext()) {
-				if(pEstacion->GetName() == wxT("General")) {
-					break;
-				}
-			}
-
-			if(pEstacion != NULL) {
-				GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Estacion", "CheckForUpdates");
-				GNC::GCS::ConfigurationController::Instance()->deleteEntryUser("/GinkgoCore/Station", "Language");
-				//se actualiza el fichero de configuracion
-				//si hay vistas abiertas no se cambia el dicomdir
-				if(GNC::GCS::ControladorVistas::Instance()->GetVistas().size() == 0)
-				{
-					GNC::GCS::ConfigurationController::Instance()->deleteEntryUser("/GinkgoCore/Estacion", "DicomDir");
-				}
-
-				for(wxXmlNode* pNodo = pEstacion->GetChildren(); pNodo!= NULL; pNodo =pNodo->GetNext())
-				{
-					if(pNodo->GetChildren()!=NULL){
-						if(pNodo->GetName() == wxT("DicomDir")) {
-							//si hay vistas abiertas no se cambia el dicomdir
-							if(GNC::GCS::ControladorVistas::Instance()->GetVistas().size() == 0)
-							{
-								GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Estacion", "DicomDir", std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-								GNC::Entorno::Instance()->RefrescarDicomDir();
-								GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoRecargarHistorial());
-							}
-						}
-						if(pNodo->GetName() == wxT("Language")) {
-							GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Station", "Language", std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-						}
-						if(pNodo->GetName() == wxT("CheckForUpdates")) {
-							GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Station", "CheckForUpdates", (pNodo->GetChildren()->GetContent() == wxT("true"))?true:false);
-						}
-					}
-				}
-			}
-		}
-
+		
 		void PanelConfiguracionGeneral::OnSeleccionarDirectorio(wxCommandEvent &)
 		{
 			wxDirDialog seleccionarDirectorio(this,_("Select DICOMDIR"),m_pDICOMDir->GetValue(),wxDD_DEFAULT_STYLE|wxDD_NEW_DIR_BUTTON);
