@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionpacs.cpp 4386 2011-11-07 13:49:39Z tovar $
+ *  $Id: panelconfiguracionpacs.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -328,6 +328,8 @@ namespace GNC {
 				tipoPacs.retrieveWithMove = m_pRetrieveMethod->GetSelection() == 0;
 				tipoPacs.retrieveSeries = m_pRetrieveMode->GetSelection() == 0;
 
+				tipoPacs.reuseConnection = m_pReuseConnection->GetValue();
+
 				if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_tls")) {
 					tipoPacs.useTLS = m_pUseSSL->GetValue();
 
@@ -352,6 +354,8 @@ namespace GNC {
 				m_pRetrieveMethod->SetSelection(tipoPacs.retrieveWithMove?0:1);
 				m_pRetrieveMode->SetSelection(tipoPacs.retrieveSeries?0:1);
 
+				m_pReuseConnection->SetValue(tipoPacs.reuseConnection);
+
 				if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_tls")) {
 					m_pUseSSL->SetValue(tipoPacs.useTLS);
 					m_pUser->SetValue(wxString::FromUTF8(tipoPacs.pacsUser.c_str()));
@@ -588,15 +592,14 @@ namespace GNC {
 			m_configLocal.privateKey = serverLocal->GetPrivateKey();
 			m_configLocal.certificate = serverLocal->GetCertificate();
 
-
 			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","remote_pacs")) {
 				m_pPACSServers->Enable(true);
-
 				
 				m_pTreeListPACS->DeleteRoot();
 				wxTreeItemId idRoot = m_pTreeListPACS->AddRoot(wxT("Root"));
 				m_servidores.clear();
 
+				DicomServerList::Instance()->FreeInstance();
 				for (DicomServerHolder* sl = DicomServerList::Instance()->GetList(); sl != NULL; sl = sl->next) {
 					TipoPACS tp;
 					tp.id = sl->server.ID;
@@ -607,6 +610,8 @@ namespace GNC {
 					tp.pdu = sl->server.PDU;
 					tp.retrieveWithMove = sl->server.retrieveWithMove;
 					tp.retrieveSeries = sl->server.retrieveSeries;
+
+					tp.reuseConnection = sl->server.reuseConnection;
 					
 					tp.useTLS = sl->server.useTLS;
 					tp.pacsUser = sl->server.pacsUser;
@@ -706,6 +711,7 @@ namespace GNC {
 					pacs.insertBool("useTLS", (*it).useTLS);
 					pacs.insertBool("verifyCredentials", (*it).verifyCredentials);
 					pacs.insertBool("retrieveWithMove", (*it).retrieveWithMove);
+					pacs.insertBool("reuseConnection", (*it).reuseConnection);
 					pacs.insertBool("retrieveSeries", (*it).retrieveSeries);
 					pacs["pacsUser"] = (*it).pacsUser;
 					pacs["pacsPass"] = (*it).pacsPass;
@@ -724,212 +730,6 @@ namespace GNC {
 			return true;
 		}
 
-		void PanelConfiguracionPACS::Exportar(wxXmlNode* pNodo)
-		{
-			wxXmlNode* pPACS = NULL;
-			for(pPACS =pNodo->GetChildren(); pPACS!=NULL; pPACS = pPACS->GetNext()) {
-				if(pPACS->GetName() == wxT("PACS")) {
-					break;
-				}
-			}
-			if(pPACS == NULL) {
-				pPACS = new wxXmlNode(pNodo,wxXML_ELEMENT_NODE,wxT("PACS"));
-			}
-
-			wxXmlNode* pLocal = NULL;
-			for(pLocal =pPACS->GetChildren(); pLocal!=NULL; pLocal = pLocal->GetNext()) {
-				if(pLocal->GetName() == wxT("Local")) {
-					break;
-				}
-			}
-			if(pLocal == NULL) {
-				pLocal = new wxXmlNode(pPACS,wxXML_ELEMENT_NODE,wxT("Local"));
-			}
-
-			wxXmlNode* nodo  = new wxXmlNode(pLocal,wxXML_ELEMENT_NODE,wxT("AET"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),m_pAETLocal->GetValue());
-
-			nodo  = new wxXmlNode(pLocal,wxXML_ELEMENT_NODE,wxT("Puerto"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),m_pPuertoLocal->GetValue());
-
-			nodo  = new wxXmlNode(pLocal,wxXML_ELEMENT_NODE,wxT("useTLS"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),m_configLocal.useTLS?wxT("true"):wxT("false"));
-
-			nodo  = new wxXmlNode(pLocal,wxXML_ELEMENT_NODE,wxT("verifyCredentials"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),m_configLocal.verifyCredentials?wxT("true"):wxT("false"));
-
-			nodo  = new wxXmlNode(pLocal,wxXML_ELEMENT_NODE,wxT("privateKey"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),wxString::FromUTF8(m_configLocal.privateKey.c_str()));
-
-			nodo  = new wxXmlNode(pLocal,wxXML_ELEMENT_NODE,wxT("certificate"));
-			new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),wxString::FromUTF8(m_configLocal.certificate.c_str()));
-
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","remote_pacs")) {
-
-				wxXmlNode* pServidores = NULL;
-				for(pServidores =pPACS->GetChildren(); pServidores!=NULL; pServidores = pServidores->GetNext()) {
-					if(pServidores->GetName() == wxT("Servidores")) {
-						break;
-					}
-				}
-				if(pServidores == NULL) {
-					pServidores = new wxXmlNode(pPACS,wxXML_ELEMENT_NODE,wxT("Servidores"));
-				}
-
-				wxString clave;
-				wxString valor;
-				for(TipoListaPACS::iterator it = m_servidores.begin(); it!= m_servidores.end(); it++){
-					wxXmlNode* pTag = new wxXmlNode(pServidores,wxXML_ELEMENT_NODE,wxT("Servidor"));
-					pTag->AddProperty(wxT("Identificador"),wxString::FromUTF8((*it).id.c_str()));
-					pTag->AddProperty(wxT("AET"),wxString::FromUTF8((*it).aet.c_str()));
-					pTag->AddProperty(wxT("Host"),wxString::FromUTF8((*it).host.c_str()));
-					pTag->AddProperty(wxT("Puerto"),wxString::Format(wxT("%d"),(*it).puerto));
-					pTag->AddProperty(wxT("isDefault"), (*it).isDefault?wxT("true"):wxT("false"));
-					pTag->AddProperty(wxT("PDU"),wxString::Format(wxT("%d"),(*it).pdu));
-					pTag->AddProperty(wxT("useTLS"), (*it).useTLS?wxT("true"):wxT("false"));
-					pTag->AddProperty(wxT("pacsUser"), wxString::FromUTF8((*it).pacsUser.c_str()));
-					pTag->AddProperty(wxT("pacsPass"), wxString::FromUTF8((*it).pacsPass.c_str()));
-					pTag->AddProperty(wxT("verifyCredentials"), (*it).verifyCredentials?wxT("true"):wxT("false"));
-					pTag->AddProperty(wxT("certificate"), wxString::FromUTF8((*it).certificate.c_str()));
-					pTag->AddProperty(wxT("privateKey"), wxString::FromUTF8((*it).privateKey.c_str()));
-					pTag->AddProperty(wxT("retrieveWithMove"), (*it).retrieveWithMove?wxT("true"):wxT("false"));
-					pTag->AddProperty(wxT("retrieveSeries"), (*it).retrieveSeries?wxT("true"):wxT("false"));
-				}
-			}
-		}
-
-		void PanelConfiguracionPACS::Importar(wxXmlNode* pNodo)
-		{
-			//se actualiza el fichero de configuracion
-			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/PACS/Local");
-
-			wxXmlNode* pPACS = NULL;
-			for(pPACS = pNodo->GetChildren(); pPACS != NULL; pPACS = pPACS->GetNext()) {
-				if(pPACS->GetName() == wxT("PACS")) {
-					break;
-				}
-			}
-			if(pPACS != NULL) {
-				wxXmlNode* pLocal = NULL;
-				for(pLocal =pPACS->GetChildren(); pLocal!=NULL; pLocal = pLocal->GetNext()) {
-					if(pLocal->GetName() == wxT("Local")) {
-						break;
-					}
-				}
-				if(pLocal != NULL) {
-					for(wxXmlNode* pNodo = pLocal->GetChildren(); pNodo!= NULL; pNodo =pNodo->GetNext())
-					{
-						if(pNodo->GetChildren() != NULL) {
-							if(pNodo->GetName() == wxT("AET")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","AET",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("Puerto")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","Puerto",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("useTLS")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","useTLS",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("useUserPass")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","useUserPass",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("pacsUser")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","pacsUser",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("pacsPass")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","pacsPass",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("verifyCredentials")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","verifyCredentials",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("privateKey")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","privateKey",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-							if(pNodo->GetName() == wxT("certificate")) {
-								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","certificate",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
-							}
-						}
-					}
-				}
-			}
-
-			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/PACS/Servidores");
-
-			for(pPACS = pNodo->GetChildren(); pPACS != NULL; pPACS = pPACS->GetNext()) {
-				if(pPACS->GetName() == wxT("PACS")) {
-					break;
-				}
-			}
-			if(pPACS != NULL) {
-				wxXmlNode* pServidores = NULL;
-				for(pServidores =pPACS->GetChildren(); pServidores!=NULL; pServidores = pServidores->GetNext()) {
-					if(pServidores->GetName() == wxT("Servidores")) {
-						break;
-					}
-				}
-				if(pServidores != NULL) {
-					int i=0;
-					wxString clave;
-
-					GNC::GCS::ConfigurationController::TListGroups pacsList;
-
-					for(wxXmlNode* pTag=pServidores->GetChildren(); pTag!=NULL; pTag = pTag->GetNext(),i++) {
-						wxString identificador;
-						pTag->GetPropVal(wxT("Identificador"),&identificador);
-						wxString aet;
-						pTag->GetPropVal(wxT("AET"),&aet);
-						wxString host;
-						pTag->GetPropVal(wxT("Host"),&host);
-						wxString puerto;
-						pTag->GetPropVal(wxT("Puerto"),&puerto);
-						wxString pdu;
-						if(!pTag->GetPropVal(wxT("PDU"),&pdu)) {
-							std::stringstream sstream;
-							sstream << DEFAULT_PDU_LENGTH;
-							pdu = wxString::FromUTF8(sstream.str().c_str()); //16k es el default
-						}
-						wxString tmpStr;
-						TipoPACS pacsTmp;
-
-						tmpStr = pTag->GetPropVal(wxT("isDefault"),wxT("false"));
-						pacsTmp.isDefault = tmpStr == wxT("true");
-						tmpStr = pTag->GetPropVal(wxT("useTLS"),wxT("false"));
-						pacsTmp.useTLS = tmpStr == wxT("true");
-						tmpStr = pTag->GetPropVal(wxT("pacsUser"),wxT(""));
-						pacsTmp.pacsUser = tmpStr.ToUTF8();
-						tmpStr = pTag->GetPropVal(wxT("pacsPass"),wxT(""));
-						pacsTmp.pacsPass =  tmpStr.ToUTF8();
-						tmpStr = pTag->GetPropVal(wxT("verifyCredentials"),wxT("false"));
-						pacsTmp.verifyCredentials = tmpStr == wxT("true");
-						tmpStr = pTag->GetPropVal(wxT("certificate"),wxT(""));
-						pacsTmp.certificate = tmpStr.ToUTF8();
-						tmpStr = pTag->GetPropVal(wxT("privateKey"),wxT(""));
-						pacsTmp.privateKey = tmpStr.ToUTF8();
-						tmpStr = pTag->GetPropVal(wxT("retrieveWithMove"),wxT("true"));
-						pacsTmp.retrieveWithMove = tmpStr == wxT("true");
-						tmpStr = pTag->GetPropVal(wxT("retrieveSeries"),wxT("true"));
-						pacsTmp.retrieveSeries = tmpStr == wxT("true");
-
-						GNC::GCS::ConfigurationController::TMapValues pacs;
-						pacs["Identificador"] = identificador.ToUTF8();
-						pacs["AET"] = aet.ToUTF8();
-						pacs["Host"] = host.ToUTF8();
-						pacs["Puerto"] = puerto.ToUTF8();
-						pacs["PDU"] = pdu.ToUTF8();
-						pacs.insertBool("useTLS", pacsTmp.useTLS);
-						pacs.insertBool("verifyCredentials", pacsTmp.verifyCredentials);
-						pacs.insertBool("retrieveWithMove", pacsTmp.retrieveWithMove);
-						pacs.insertBool("retrieveSeries", pacsTmp.retrieveSeries);
-						pacs["pacsUser"] = pacsTmp.pacsUser;
-						pacs["pacsPass"] = pacsTmp.pacsPass;
-						pacs["certificate"] = pacsTmp.certificate;
-						pacs["privateKey"] = pacsTmp.privateKey;
-						pacsList.push_back(pacs);
-					}
-					GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/PACS/Servidores", pacsList, "Server");
-				}
-			}
-			DicomServerList::Instance()->Reload();
-		}
 		//endregion
 
 		void PanelConfiguracionPACS::OnAdvancedLocal(wxCommandEvent &)
