@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelconfiguracionpermisos.cpp 3901 2011-06-29 11:20:49Z tovar $
+ *  $Id: panelconfiguracionpermisos.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -379,66 +379,6 @@ namespace GNC {
 
 			return true;
 		}
-
-		void PanelConfiguracionPermisos::Exportar(wxXmlNode* pNodo)
-		{
-			wxXmlNode* pProfiles = NULL;
-			for(pProfiles =pNodo->GetChildren(); pProfiles!=NULL; pProfiles = pProfiles->GetNext()) {
-				if(pProfiles->GetName() == wxT("Profiles")) {
-					break;
-				}
-			}
-			if(pProfiles == NULL) {
-				pProfiles = new wxXmlNode(pNodo,wxXML_ELEMENT_NODE,wxT("Profiles"));
-			}
-
-			wxString clave;
-			wxString valor;
-			for(TipoListaProfiles::iterator it = m_profiles.begin(); it!= m_profiles.end(); it++){
-				wxXmlNode* pTag = new wxXmlNode(pProfiles,wxXML_ELEMENT_NODE,wxT("Profile"));
-				pTag->AddProperty(wxT("Name"),wxString::FromUTF8((*it).nombre.c_str()));
-				if((*it).aplicar)
-					pTag->AddProperty(wxT("Apply"),wxT("Yes"));
-				else
-					pTag->AddProperty(wxT("Apply"),wxT("No"));
-				pTag->AddProperty(wxT("XML"),wxString::FromUTF8((*it).xml.c_str()));
-			}
-		}
-
-		void PanelConfiguracionPermisos::Importar(wxXmlNode* pNodo)
-		{
-			//se actualiza el fichero de configuracion
-
-			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Profiles");
-
-			wxXmlNode* pProfiles = NULL;
-			for(pProfiles = pNodo->GetChildren(); pProfiles != NULL; pProfiles = pProfiles->GetNext()) {
-				if(pProfiles->GetName() == wxT("Profiles")) {
-					break;
-				}
-			}
-			if(pProfiles != NULL) {
-				wxString clave;
-				GNC::GCS::ConfigurationController::TListGroups profiles;
-				for(wxXmlNode* pTag=pProfiles->GetChildren(); pTag!=NULL; pTag = pTag->GetNext()) {
-					wxString nombre;
-					pTag->GetPropVal(wxT("Name"),&nombre);
-					wxString xml;
-					pTag->GetPropVal(wxT("XML"),&xml);
-					wxString aplicar;
-					pTag->GetPropVal(wxT("Apply"),&aplicar);
-					wxString puerto;
-
-					GNC::GCS::ConfigurationController::TMapValues profile;
-					profile["Name"] = nombre.ToUTF8();
-					profile["XML"] = xml.ToUTF8();
-					profile.insertBool("Apply", aplicar == wxT("Yes"));
-					profiles.push_back(profile);
-				}
-				GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Profiles", profiles, "Profile");
-			}
-		}
-
 		//endregion
 
 
