@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionubicaciones.cpp 4044 2011-07-22 12:21:07Z tovar $
+ *  $Id: panelconfiguracionubicaciones.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -507,83 +507,6 @@ namespace GNC {
 
 			return true;
 		}
-
-		void PanelConfiguracionUbicaciones::Exportar(wxXmlNode* pNodo)
-		{
-
-			wxXmlNode* pLocations = NULL;
-			for(pLocations = pNodo->GetChildren(); pLocations != NULL; pLocations = pLocations->GetNext()) {
-				if(pLocations->GetName() == wxT("Locations")) {
-					break;
-				}
-			}
-			if(pLocations == NULL) {
-				pLocations = new wxXmlNode(pNodo, wxXML_ELEMENT_NODE, wxT("Locations"));
-			}
-
-			wxString clave;
-			wxString valor;
-			for (GNC::GCS::IEntorno::MapaUbicaciones::iterator it = m_pUbicacionesGridTable->m_Ubicaciones.begin(); it != m_pUbicacionesGridTable->m_Ubicaciones.end(); it++) {
-				GIL::Ubicacion& u = (*it).second;
-				wxXmlNode* pTag = new wxXmlNode(pLocations, wxXML_ELEMENT_NODE,wxT("Location"));
-				pTag->AddProperty(wxT("Title"),wxString::FromUTF8(u.Titulo.c_str()));
-				pTag->AddProperty(wxT("Path"),wxString::FromUTF8(u.Ruta.c_str()));
-				pTag->AddProperty(wxT("Description"),wxString::FromUTF8(u.Descripcion.c_str()));
-				pTag->AddProperty(wxT("Monitorize"),u.Monitorize?wxT("true"):wxT("false"));
-				pTag->AddProperty(wxT("CleanBefore"),u.CleanBefore?wxT("true"):wxT("false"));
-				pTag->AddProperty(wxT("CleanAfter"),u.CleanAfter?wxT("true"):wxT("false"));
-			}
-		}
-
-		void PanelConfiguracionUbicaciones::Importar(wxXmlNode* pNodo)
-		{
-			GNC::GCS::IEntorno::MapaUbicaciones& mapa = GNC::Entorno::Instance()->GetUbicaciones();
-			mapa.clear();
-			
-			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Locations");
-
-			wxXmlNode* pLocations = NULL;
-			for(pLocations = pNodo->GetChildren(); pLocations!= NULL; pLocations = pLocations->GetNext()) {
-				if(pLocations->GetName() == wxT("Locations")) {
-					break;
-				}
-			}
-			if(pLocations != NULL) {
-				int i=0;
-				wxString clave;
-
-				GNC::GCS::ConfigurationController::TListGroups locations;
-				for(wxXmlNode* pTag = pLocations->GetChildren(); pTag != NULL; pTag = pTag->GetNext(), i++) {
-
-					wxString titulo;
-					pTag->GetPropVal(wxT("Title"),&titulo);
-					wxString ruta;
-					pTag->GetPropVal(wxT("Path"),&ruta);
-					wxString descripcion;
-					pTag->GetPropVal(wxT("Description"),&descripcion);
-					wxString monitorize;
-					pTag->GetPropVal(wxT("Monitorize"),&monitorize);
-					wxString cleanbefore;
-					pTag->GetPropVal(wxT("CleanBefore"),&cleanbefore);
-					wxString cleanafter;
-					pTag->GetPropVal(wxT("CleanAfter"),&cleanafter);
-
-					GIL::Ubicacion u (std::string(titulo.ToUTF8()), std::string(ruta.ToUTF8()), std::string(descripcion.ToUTF8()), monitorize==wxT("true"), cleanbefore == wxT("true"), cleanafter == wxT("true"));
-					mapa[u.Titulo] = u;
-
-					GNC::GCS::ConfigurationController::TMapValues location;
-					location["Title"] = u.Titulo;
-					location["Path"] = u.Ruta;
-					location["Description"] = u.Descripcion;
-					location.insertBool("Monitorize",u.Monitorize);
-					location.insertBool("CleanBefore", u.CleanBefore);
-					location.insertBool("CleanBefore", u.CleanAfter);
-					locations.push_back(location);
-				}
-				GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Locations", locations, "Location");
-			}
-		}
-
 		//endregion
 
 
