@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelserie.cpp 4334 2011-10-26 07:00:01Z tovar $
+ *  $Id: panelserie.cpp 4501 2011-12-20 11:13:41Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -274,6 +274,15 @@ namespace GNC {
 			event.Skip(false);
 		}
 
+		void PanelSerie::OnKeyDown(wxKeyEvent &event)
+		{
+
+			if (event.GetKeyCode() == WXK_DELETE) {
+				DoDelete(true);
+				event.Skip(false);
+			}
+		}
+
 		void PanelSerie::OnMenuMouse(wxMouseEvent &event)
 		{
 			//se selecciona
