@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectimagesimportation.cpp 4403 2011-11-14 10:59:24Z tovar $
+ *  $Id: selectimagesimportation.cpp 4602 2012-01-26 07:23:02Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -43,6 +43,7 @@
 #include "selectimagesimportation.h"
 #include <api/icontextoestudio.h>
 #include <resources/ginkgoresourcemanager.h>
+#include <main/controllers/controladorlog.h>
 
 #include <vtkImageData.h>
 #include <vtkUnsignedCharArray.h>
@@ -526,7 +527,7 @@ namespace GNC {
 
 		void SelectImagesImportation::UnCheckAll()
 		{
-			for (int i = 1; i < m_pButtonsBar->GetToolCount(); i++) {
+			for (unsigned int i = 1; i < m_pButtonsBar->GetToolCount(); i++) {
 				//uncheck ubicaciones
 				m_pButtonsBar->ToggleTool(i, false);
 			}
@@ -592,7 +593,7 @@ namespace GNC {
 		{
 			GNC::GCS::IEntorno::MapaUbicaciones& mapa = GNC::Entorno::Instance()->GetUbicaciones();
 			GNC::GCS::IEntorno::MapaUbicaciones::iterator it = mapa.begin();
-			for (int i = 1; i < m_pButtonsBar->GetToolCount() && it != mapa.end(); i++, ++it) {
+			for (unsigned int i = 1; i < m_pButtonsBar->GetToolCount() && it != mapa.end(); i++, ++it) {
 				if (m_pButtonsBar->GetToolToggled(i)) {
 					return &(*it).second;
 				}
@@ -610,7 +611,7 @@ namespace GNC {
 				GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Importacion", "LastLocation", lastLocation);
 				GNC::GCS::IEntorno::MapaUbicaciones& mapa = GNC::Entorno::Instance()->GetUbicaciones();
 				GNC::GCS::IEntorno::MapaUbicaciones::iterator it = mapa.begin();
-				int id = 1;
+				unsigned int id = 1;
 				for (; id < m_pButtonsBar->GetToolCount() && it != mapa.end(); id++, ++it) {
 					if ((*it).first == lastLocation) {
 						break;
@@ -704,7 +705,9 @@ namespace GNC {
 						//si existe se busca uno que no exista
 						nombreImagenTemporal= wxDirTmp + wxFileName::GetPathSeparator() + fileName.GetName() + wxString::Format(wxT("%d"),rand()) + wxT(".jpg");
 					}
-					wxCopyFile((*it), nombreImagenTemporal);
+					if (!wxCopyFile((*it), nombreImagenTemporal)) {
+						LOG_ERROR("SelectImagesImportation", "Error copying images from " << (*it).ToUTF8() << " TO " << nombreImagenTemporal.ToUTF8());
+					}
 					std::string path(TOPATH(nombreImagenTemporal));
 					m_pListaFicheros->push_back(path);					
 				} else {
