@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizardimportacionginkgo.cpp 4303 2011-10-18 10:31:44Z tovar $
+ *  $Id: wxwizardimportacionginkgo.cpp 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -186,43 +186,47 @@ namespace GNC {
 			if((*m_currentPaso)->Validar()){
 				Freeze();
 				
-				(*m_currentPaso)->Detach(m_pSizerPrincipal);
+				wxWindow* pCurrent = dynamic_cast<wxWindow*> (*m_currentPaso);
+				if (pCurrent != NULL && (*m_currentPaso)->Detach()) {
+					pCurrent->Hide();
+					m_pSizerPrincipal->Detach(pCurrent);
 				
-				PasoPefilImportacion* pasoPerfil = dynamic_cast<PasoPefilImportacion * > (*m_currentPaso);
-				if(pasoPerfil != NULL){
-					//cargamos los pasos del perfil seleccionado...
-					m_pControladorModulo = pasoPerfil->GetControladorSeleccionado();
-					std::string dir_temp(TOPATH(m_pathDirTemporal));
-					
-					m_ListaPasos.clear();
+					PasoPefilImportacion* pasoPerfil = dynamic_cast<PasoPefilImportacion * > (*m_currentPaso);
+					if(pasoPerfil != NULL){
+						//cargamos los pasos del perfil seleccionado...
+						m_pControladorModulo = pasoPerfil->GetControladorSeleccionado();
+						std::string dir_temp(TOPATH(m_pathDirTemporal));
+						
+						m_ListaPasos.clear();
 
-					std::list<IPasoWizard*> pasosModulo;
-										
-					m_pControladorModulo->GetPasosImportacion(this,pasosModulo,m_pPanelPrincipal,dir_temp,m_pModeloIntegracion);
-					if (m_pModeloIntegracion.IsValid()) {
-						m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
+						std::list<IPasoWizard*> pasosModulo;
+											
+						m_pControladorModulo->GetPasosImportacion(this,pasosModulo,m_pPanelPrincipal,dir_temp,m_pModeloIntegracion);
+						if (m_pModeloIntegracion.IsValid()) {
+							m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
+						}
+						
+						for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
+							m_ListaPasos.push_back(*it);
+							(*it)->AsignarListaFicheros(m_ListaFicheros);
+						}
+						
+						m_currentPaso = m_ListaPasos.begin();
+						m_currentPasoIndex=1;
+					} else {
+						++m_currentPasoIndex;
+						++m_currentPaso;
 					}
 					
-					for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
-						m_ListaPasos.push_back(*it);
-						(*it)->AsignarListaFicheros(m_ListaFicheros);
+					if(m_currentPaso==m_ListaPasos.end()){
+						m_OK=true;
+						if(m_ListaFicheros.size() > 0) {
+							GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoAddFicheroHistorial(m_ListaFicheros));
+						}
+						Close();
+					}else{
+						CargarCurrent();
 					}
-					
-					m_currentPaso = m_ListaPasos.begin();
-					m_currentPasoIndex=1;
-				} else {
-					++m_currentPasoIndex;
-					++m_currentPaso;
-				}
-				
-				if(m_currentPaso==m_ListaPasos.end()){
-					m_OK=true;
-					if(m_ListaFicheros.size() > 0) {
-						GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoAddFicheroHistorial(m_ListaFicheros));
-					}
-					Close();
-				}else{
-					CargarCurrent();
 				}
 				
 				Thaw();
@@ -232,10 +236,15 @@ namespace GNC {
 		void wxWizardImportacionGinkgo::OnAnteriorClick(wxCommandEvent &)
 		{
 			if(m_currentPaso!=m_ListaPasos.begin()){
-				(*m_currentPaso)->Detach(m_pSizerPrincipal);
-				--m_currentPaso;
-				--m_currentPasoIndex;
-				CargarCurrent();
+				wxWindow* pCurrent = dynamic_cast<wxWindow*> (*m_currentPaso);
+				if (pCurrent != NULL && (*m_currentPaso)->Detach()) {
+					pCurrent->Hide();
+					m_pSizerPrincipal->Detach(pCurrent);
+
+					--m_currentPaso;
+					--m_currentPasoIndex;
+					CargarCurrent();
+				}
 			}
 		}
 		
@@ -275,19 +284,26 @@ namespace GNC {
 		
 		
 		void wxWizardImportacionGinkgo::CargarCurrent(){
-			(*m_currentPaso)->Attach(m_pSizerPrincipal);
-			wxString label= wxString::Format(_("Step %d of %d: "),m_currentPasoIndex,m_ListaPasos.size());
-			m_pHeader->SetTitle(label+wxString::FromUTF8((*m_currentPaso)->GetTitle().c_str()));
-			m_pHeader->SetSubtitle(wxString::FromUTF8((*m_currentPaso)->GetSubTitle().c_str()));
-			m_pBSiguiente->Enable((*m_currentPaso)->Siguiente());
-			m_pBAnterior->Enable((*m_currentPaso)->Anterior());
-			m_pBCerrar->Enable((*m_currentPaso)->Cancelar());
-			PasoPefilImportacion* pasoPerfil = dynamic_cast<PasoPefilImportacion * > (*m_currentPaso);
-			if(*(m_currentPaso)==m_ListaPasos.back() && pasoPerfil == NULL){
-				m_pBSiguiente->SetLabel(_("&End"));
-			}else{
-				m_pBSiguiente->SetLabel(_("&Next >"));
+			wxWindow* pCurrent = dynamic_cast<wxWindow*> (*m_currentPaso);
+			if (pCurrent != NULL && (*m_currentPaso)->Attach()) 
+			{
+				pCurrent->Show(true);
+				m_pSizerPrincipal->Add(pCurrent, 10, wxEXPAND);
+
+				wxString label= wxString::Format(_("Step %d of %d: "),m_currentPasoIndex,m_ListaPasos.size());
+				m_pHeader->SetTitle(label+wxString::FromUTF8((*m_currentPaso)->GetTitle().c_str()));
+				m_pBSiguiente->Enable((*m_currentPaso)->Siguiente());
+				m_pBAnterior->Enable((*m_currentPaso)->Anterior());
+				m_pBCerrar->Enable((*m_currentPaso)->Cancelar());
+				PasoPefilImportacion* pasoPerfil = dynamic_cast<PasoPefilImportacion * > (*m_currentPaso);
+				if(*(m_currentPaso)==m_ListaPasos.back() && pasoPerfil == NULL){
+					m_pBSiguiente->SetLabel(_("&End"));
+				}else{
+					m_pBSiguiente->SetLabel(_("&Next >"));
+				}
 			}
+			
+			m_pPanelPrincipal->Layout();
 			Layout();
 		}
 	}
