@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ventanaprincipal.h 4391 2011-11-10 13:24:05Z tovar $
+ *  $Id: ventanaprincipal.h 4502 2012-01-09 12:19:39Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -168,6 +168,10 @@ public:
 	/*Evento de apertura de fichero*/
 	virtual void OnAbrirFichero(wxCommandEvent& event);
 
+	/*Evento de open disc*/
+	virtual void OnOpenRemovableUnit(wxCommandEvent& event);
+
+
 	/*Evento de apertura de directorio*/
 	virtual void OnAbrirDirectorio(wxCommandEvent& event);
 
