@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: abrir.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: abrir.cpp 4502 2012-01-09 12:19:39Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -23,9 +23,9 @@
 #include <main/controllers/configurationcontroller.h>
 #include <wx/msgdlg.h>
 #include <wx/treelistctrl/treelistctrl.h>
-#include "dialogodicomdirbase.h"
 
 #include "abrir.h"
+#include "opendialogs.h"
 
 
 
@@ -42,71 +42,10 @@
 #include <resources/ginkgoresourcemanager.h>
 #include <api/icontextoestudio.h>
 
-#define ICONO_ESTUDIO 0
-#define ICONO_SERIE 1
-#define ICONO_HOMBRE 2
-#define ICONO_MUJER 3
-#define ICONO_OTRO 4
-#define SIZE_ICONOS 16
-
-#define COLUMNA_DCMDIR_FECHA 2
-#define COLUMNA_DCMDIR_MODALIDAD 1
-#define COLUMNA_DCMDIR_MEDICO 3
-#define COLUMNA_DCMDIR_ACCNUMBER 4
-#define COLUMNA_DCMDIR_UID 5
 
 namespace GNC {
 	namespace GUI {
-		////////////////////////////////////////////////////
-		////////////DIALOGO DICOMDIR////////////////////////
-		////////////////////////////////////////////////////
-
-		class DialogoDicomDir: public DialogoDicomDirBase
-		{
-		public:
-			DialogoDicomDir(wxWindow* pParent, std::string pathDicomDir): DialogoDicomDirBase(pParent)
-			{
-				wxString pathWx = FROMPATH(pathDicomDir);
-				if (wxFile::Exists(pathWx)){
-					wxFileName file(pathWx);
-					IModeloDicom modelo;
-
-					if(GIL::DICOM::PACSController::Instance()->LeerDicomDir(pathDicomDir,&modelo) && modelo.ListaPacientes().size()!=0) {
-						m_pDICOMDIRResultPanel->SetModel(modelo);
-					}
-				} else {
-					wxMessageBox(_("Select a valid DICOMDIR file"), _("Info"),
-									 wxOK | wxICON_INFORMATION, this);
-				}
-			}
-
-			~DialogoDicomDir()
-			{
-			}
-
-			void OnEndClick(wxCommandEvent &)
-			{
-				//adquirimos desde dicomdir
-				std::list<std::string> listaPaths = m_pDICOMDIRResultPanel->GetSelectedPaths();
-
-				if(listaPaths.size() == 0) {
-					wxMessageBox(_("Select dicom dir files you want to acquire"), _("Info"),
-									 wxOK | wxICON_INFORMATION, this);
-					return;
-				} else {
-					//se lanza el comando de incluir en el historial
-					GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(listaPaths);
-					GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial* pCmd = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial(pParams);
-					GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Storing in the history..."),pCmd, NULL);
-
-					Close();
-				}
-			}
-
-		protected:
-		};
-		////////////////////////////////////////////////////
-
+		
 		Abrir::Abrir()
 		{
 		}
@@ -116,32 +55,52 @@ namespace GNC {
 
 		}
 
-		void Abrir::AbrirFichero(wxWindow* pParent)
+		void Abrir::AbrirFichero(wxWindow* pParent, const std::list<std::string>* directLoads)
 		{
-			std::string pathDefectoStd;
-			GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Adquisicion", "PathDefecto", pathDefectoStd);
-			wxString defPathWx = wxString::FromUTF8(pathDefectoStd.c_str());
-			if(!wxDirExists(defPathWx)){
-				defPathWx = wxEmptyString;
+			
+			bool success = false;
+			std::list<std::string> listaPaths;
+			wxString guiDir;
+			
+			if (directLoads != NULL) {
+				
+				listaPaths = (*directLoads);
+				
+				success = (listaPaths.size() > 0);
+				
 			}
-			//se muestra un dilogo de abrir fichero, si abre un fichero mira a ver si es dicomdir, si abre un directorio lo explora en profundidad
-			#if defined(_WINDOWS)
-			wxFileDialog fileDialog(NULL,_("Open..."),defPathWx,wxEmptyString,wxT("*.*"), wxFD_OPEN | wxFD_MULTIPLE);
-			#else
-			wxFileDialog fileDialog(pParent,_("Open..."),defPathWx,wxEmptyString,wxT("*"), wxFD_OPEN | wxFD_MULTIPLE);
-			#endif
-			fileDialog.SetDirectory(defPathWx);
-			int response = fileDialog.ShowModal();
-			if (response == wxID_OK) {
-				wxArrayString ficherosWx;
-				fileDialog.GetFilenames(ficherosWx);
-				std::list<std::string> listaPaths;
-				for(wxArrayString::iterator it = ficherosWx.begin(); it != ficherosWx.end(); ++it)
-				{
-					wxString wxPath = fileDialog.GetDirectory() + wxFileName::GetPathSeparator() + (*it);
-					listaPaths.push_back(std::string(TOPATH(wxPath)));
+			else {
+				std::string pathDefectoStd;
+				GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Adquisicion", "PathDefecto", pathDefectoStd);
+				wxString defPathWx = wxString::FromUTF8(pathDefectoStd.c_str());
+				if(!wxDirExists(defPathWx)){
+					defPathWx = wxEmptyString;
 				}
-
+				//se muestra un dialogo de abrir fichero, si abre un fichero mira a ver si es dicomdir, si abre un directorio lo explora en profundidad
+				#if defined(_WINDOWS)
+				wxFileDialog fileDialog(NULL,_("Open..."),defPathWx,wxEmptyString,wxT("*.*"), wxFD_OPEN | wxFD_MULTIPLE);
+				#else
+				wxFileDialog fileDialog(pParent,_("Open..."),defPathWx,wxEmptyString,wxT("*"), wxFD_OPEN | wxFD_MULTIPLE);
+				#endif
+				fileDialog.SetDirectory(defPathWx);
+				success = (fileDialog.ShowModal() == wxID_OK);				
+				
+				if (success) {
+					
+					guiDir = fileDialog.GetDirectory();
+					wxArrayString ficherosWx;
+					fileDialog.GetFilenames(ficherosWx);
+					
+					for(wxArrayString::iterator it = ficherosWx.begin(); it != ficherosWx.end(); ++it)
+					{
+						wxString wxPath = fileDialog.GetDirectory() + wxFileName::GetPathSeparator() + (*it);
+						listaPaths.push_back(std::string(TOPATH(wxPath)));
+					}
+				}
+			}
+			
+			if (success) {
+				
 				//si alguno de los ficheros es un dicomdir se pasa a tratarlos de una forma especial, si son ficheros normales, se lanza el comando
 				bool esDicomDir = false;
 				if (listaPaths.size() == 1 && GIL::DICOM::PACSController::Instance()->EsDICOM(listaPaths.front(),true,false)) {
@@ -160,10 +119,12 @@ namespace GNC {
 					DialogoDicomDir dicomDirDialog(pParent,listaPaths.front());
 					dicomDirDialog.ShowModal();
 				}
-
-				//se actualiza el fichero de configuracion
-				GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Adquisicion", "PathDefecto", std::string(fileDialog.GetDirectory().ToUTF8()));
-				GNC::GCS::ConfigurationController::Instance()->Flush();
+				
+				if (!guiDir.IsEmpty()) {
+					//se actualiza el fichero de configuracion
+					GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Adquisicion", "PathDefecto", std::string(guiDir.ToUTF8()));
+					GNC::GCS::ConfigurationController::Instance()->Flush();
+				}
 			}
 		}
 
