@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientadesencajar.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: herramientadesencajar.h 4478 2011-12-13 11:55:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -40,7 +40,7 @@ namespace GNC {
 
 		//cuando hacen click en ella...
 		bool EstaHabilitada();
-		virtual void SolicitarActivacion();
+		virtual void SolicitarActivacion(const GNC::GCS::TriggerButton& buttonmask);
 		virtual void Desencajar(GNC::GCS::IVista* pVista);
 		virtual bool IsDesencajada();
 
