@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientadeshacer.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: herramientadeshacer.h 4476 2011-12-13 08:23:27Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -38,8 +38,6 @@ namespace GNC {
 
 		//endregion
 
-		//cuando hacen click en ella...
-		virtual void SolicitarActivacion();
 		//deshacer
 		virtual void Deshacer();
 		//rehacer
