@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientascore.h 4394 2011-11-11 09:45:22Z carlos $
+ *  $Id: herramientascore.h 4468 2011-12-09 10:02:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -11,14 +11,20 @@
  *
  *
  */
-#include "herramientaangulo.h"
+
 #include "herramientapuntero.h"
-#include "herramientaslider.h"
+
+#include "toolpan.h"
+#include "toolslider.h"
+#include "toolzoom.h"
+#include "toolwindowlevel.h"
+
+#include "herramientalupa.h"
+#include "herramientaangulo.h"
 #include "herramientaregla.h"
 #include "herramientaelevacion.h"
 #include "herramientanota.h"
-#include "herramientawindowlevel.h"
-#include "herramientalupa.h"
+
 #include "herramientamarcado.h"
 #include "herramientarejillametrica.h"
 #include "herramientaanotacionesesquina.h"
