@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ginkgoresourcemanager.cpp 4394 2011-11-11 09:45:22Z carlos $
+ *  $Id: ginkgoresourcemanager.cpp 4511 2012-01-12 07:34:48Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -135,10 +135,16 @@ const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoDesencajar(){re
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoCornerAnnotations(){return wxMEMORY_BITMAP(ico_corner_annotations); }
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoInforme(){return wxMEMORY_BITMAP(ico_informe); }
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoSlider(){return wxMEMORY_BITMAP(ico_slider); }
+const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoLupa(){return wxMEMORY_BITMAP(ico_lupa); }
+const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoPan(){return wxMEMORY_BITMAP(ico_pan); }
+const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoMouseR(){return wxMEMORY_BITMAP(ico_mouse_r); }
+const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoMouseL(){return wxMEMORY_BITMAP(ico_mouse_l); }
+const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoMouseRL(){return wxMEMORY_BITMAP(ico_mouse_rl); }
 
 // Iconos de menus
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoAbrir(){return wxMEMORY_BITMAP(ico_abrir); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoOpenDir(){return wxMEMORY_BITMAP(ico_open_dir); }
+const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoRemovableUnit(){return wxMEMORY_BITMAP(ico_open_disc); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoOpenFile(){return wxMEMORY_BITMAP(ico_open_file); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoCerrarTab(){return wxMEMORY_BITMAP(ico_cerrar_tab); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoConfiguracion(){return wxMEMORY_BITMAP(ico_configuracion); }
