@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iconos.h 3630 2011-03-29 11:28:08Z tovar $
+ *  $Id: iconos.h 4367 2011-11-04 10:58:44Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -25,3 +25,5 @@
 #include "ico_plegar.h"
 #include "ico_desplegar.h"
 #include "ico_movie_preview.h"
+#include "ico_clean_all.h"
+#include "ico_all_patients.h"
