@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iconos.h 4326 2011-10-24 09:29:57Z carlos $
+ *  $Id: iconos.h 4502 2012-01-09 12:19:39Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -38,3 +38,5 @@
 #include "ico_acercade.h"
 #include "ico_send_to_pacs.h"
 #include "ico_obtain_extensions.h"
+#include "ico_dicom_dir.h"
+#include "ico_open_disc.h"
