@@ -96,7 +96,7 @@ void GinkgoInteractorStyleImage2D::OnMouseMove()
 			this->FindPokedRenderer(x, y);
 			this->Pan();
 			this->PropagateCameraFocalAndPosition();
-			this->InvokeEvent(vtkCommand::InteractionEvent, NULL);
+			this->InvokeEvent(vtkCommand::InteractionEvent, NULL);			
 			break;
 		default:
 			break;
@@ -152,11 +152,15 @@ void GinkgoInteractorStyleImage2D::OnLeftButtonDown()
 			break;
 		*/
 		case vtkGinkgoImageViewer::SELECT_INTERACTION :
+			/*
 			this->StartPick();
+			*/
 			break;
 		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
+			/*
 			this->StartPick();
 			this->StopState();
+			*/
 			//this->StartPan();
 			break;
 		/*
@@ -202,10 +206,11 @@ void GinkgoInteractorStyleImage2D::OnMiddleButtonDown()
 			break;
 		*/
 		case vtkGinkgoImageViewer::SELECT_INTERACTION :
-			this->StartPick();
+			//this->StartPick();
+			this->StartPan();
 			break;
 		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-			//this->StartPan();
+			this->StartPan();
 			break;
 		/*
 		case vtkGinkgoImageViewer::FULL_PAGE_INTERACTION :
@@ -216,7 +221,7 @@ void GinkgoInteractorStyleImage2D::OnMiddleButtonDown()
 			break;
 		*/
 		case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-			//this->StartPan();
+			this->StartPan();
 			break;
 	}
 }
@@ -227,22 +232,32 @@ void GinkgoInteractorStyleImage2D::OnMiddleButtonUp()
 {
 	switch (this->State) {
 		case VTKIS_ZSLICE_MOVE:
+			/*
 			this->EndZSliceMove();
+			*/
 			break;
 		case VTKIS_WINDOW_LEVEL:
+			/*
 			this->EndWindowLevel();
+			*/
 			break;
 		case VTKIS_PICK:
+			/*
 			this->EndPick();
+			*/
 			break;
 		case VTKIS_MEASURE:
+			/*
 			this->EndMeasure();
+			*/
 			break;
 		case VTKIS_PAN:
 			this->EndPan();
 			break;
 		case VTKIS_DOLLY:
+			/*
 			this->EndDolly(); // continuous zoom
+			*/
 			break;
 	}
 
@@ -254,22 +269,34 @@ void GinkgoInteractorStyleImage2D::OnLeftButtonUp()
 {
 	switch (this->State) {
 		case VTKIS_ZSLICE_MOVE:
+			/*
 			this->EndZSliceMove();
+			*/
 			break;
 		case VTKIS_WINDOW_LEVEL:
+			/*
 			this->EndWindowLevel();
+			*/
 			break;
 		case VTKIS_PICK:
+			/*
 			this->EndPick();
+			*/
 			break;
 		case VTKIS_MEASURE:
+			/*
 			this->EndMeasure();
+			*/
 			break;
 		case VTKIS_DOLLY: // continuous zoom
+			/*
 			this->EndDolly();
+			*/
 			break;
 		case VTKIS_PAN: // continuous zoom
+			/*
 			this->EndPan();
+			*/
 			break;
 	}
 }
@@ -295,11 +322,15 @@ void GinkgoInteractorStyleImage2D::OnRightButtonDown()
 			this->StartWindowLevel();
 			break;
 		*/
-		case vtkGinkgoImageViewer::SELECT_INTERACTION :
+		case vtkGinkgoImageViewer::SELECT_INTERACTION:
+			/*
 			this->StartPick();
+			*/
 			break;
-		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
+		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION:
+			/*
 			this->StartPan();
+			*/
 			break;
 		/*
 		case vtkGinkgoImageViewer::FULL_PAGE_INTERACTION :
@@ -309,8 +340,10 @@ void GinkgoInteractorStyleImage2D::OnRightButtonDown()
 			this->StartMeasure();
 			break;
 		*/
-		case vtkGinkgoImageViewer::ZOOM_INTERACTION :
+		case vtkGinkgoImageViewer::ZOOM_INTERACTION:
+			/*
 			this->StartPan();
+			*/
 			break;
 	}
 }
@@ -321,22 +354,34 @@ void GinkgoInteractorStyleImage2D::OnRightButtonUp()
 {
 	switch (this->State) {
 		case VTKIS_ZSLICE_MOVE:
+			/*
 			this->EndZSliceMove();
+			*/
 			break;
 		case VTKIS_WINDOW_LEVEL:
+			/*
 			this->EndWindowLevel();
+			*/
 			break;
 		case VTKIS_PICK:
+			/*
 			this->EndPick();
+			*/
 			break;
 		case VTKIS_MEASURE:
+			/*
 			this->EndMeasure();
+			*/
 			break;
 		case VTKIS_DOLLY: // continuous zoom
+			/*
 			this->EndDolly();
+			*/
 			break;
 		case VTKIS_PAN:
+			/*
 			this->EndPan();
+			*/
 			break;
 	}
 }
