@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wwindowlevel.h 3535 2011-03-18 17:57:05Z carlos $
+ *  $Id: wwindowlevel.h 4478 2011-12-13 11:55:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -28,7 +28,7 @@ namespace GNC {
 				typedef GNC::GCS::Vector TVector;
 				typedef GNC::GCS::Widgets::Observadores::IObservadorWindowLevel TObservador;
 
-				WWindowLevelBuilder(GNC::GCS::IWidgetsManager* pManager, long gid);
+				WWindowLevelBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid);
 
 				void SetObservador(TObservador* pObservador) {
 					m_pObservador = pObservador;
