@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: thumbnailctrl.cpp 4056 2011-08-03 09:10:43Z tovar $
+ *  $Id: thumbnailctrl.cpp 4437 2011-11-21 14:03:22Z tovar $
  *  Ginkgo CADx Project
  *
  *
@@ -1516,10 +1516,11 @@ bool wxThumbnailItem::DrawBackground(wxDC& dc, wxThumbnailCtrl* ctrl, const wxRe
     if (style & wxTHUMBNAIL_TAGGED)
     {
         wxPen bluePen = ctrl->GetTagColour();
+		  bluePen.SetWidth(3);
         dc.SetPen(bluePen);
 
         dc.DrawLine(rect.GetRight(), rect.GetTop(), rect.GetRight(), rect.GetBottom());
-        dc.DrawLine(rect.GetLeft(), rect.GetBottom(), rect.GetRight()+1, rect.GetBottom());
+        dc.DrawLine(rect.GetLeft(), rect.GetBottom(), rect.GetRight(), rect.GetBottom());
 
         dc.DrawLine(rect.GetLeft(), rect.GetTop(), rect.GetRight(), rect.GetTop());
         dc.DrawLine(rect.GetLeft(), rect.GetTop(), rect.GetLeft(), rect.GetBottom());
@@ -1537,10 +1538,9 @@ bool wxThumbnailItem::DrawBackground(wxDC& dc, wxThumbnailCtrl* ctrl, const wxRe
     else
     {
         dc.SetPen(*wxBLACK_PEN);
-        dc.DrawLine(rect.GetRight(), rect.GetTop(), rect.GetRight(), rect.GetBottom());
+		  dc.DrawLine(rect.GetRight(), rect.GetTop(), rect.GetRight(), rect.GetBottom());
         dc.DrawLine(rect.GetLeft(), rect.GetBottom(), rect.GetRight()+1, rect.GetBottom());
 
-        dc.SetPen(*wxWHITE_PEN);
         dc.DrawLine(rect.GetLeft(), rect.GetTop(), rect.GetRight(), rect.GetTop());
         dc.DrawLine(rect.GetLeft(), rect.GetTop(), rect.GetLeft(), rect.GetBottom());
     }
@@ -1662,32 +1662,62 @@ bool wxImageThumbnailItem::Draw(wxDC& dc, wxThumbnailCtrl* WXUNUSED(ctrl), const
 }
 
 /// Load the thumbnail
+class LoadThread: public wxThread {
+ public:
+	 LoadThread(const wxString& filename, wxBitmap& bitmap, wxThumbnailCtrl* ctrl): wxThread(wxTHREAD_JOINABLE), m_filename(filename), m_cachedBitmap(bitmap)
+	 {
+		 this->ctrl = ctrl;
+	 }
+
+	 virtual void *Entry() 
+	 {
+		 if (wxFileExists(m_filename))
+		 {
+			  wxImage image;
+			  if (image.LoadFile(m_filename, wxBITMAP_TYPE_ANY))
+			  {
+					wxSize thumbnailSize = ctrl->GetThumbnailImageSize();
+					double scaleX = ((double) thumbnailSize.x)/((double) image.GetWidth());
+					double scaleY = ((double) thumbnailSize.y)/((double) image.GetHeight());
+
+					if (scaleX < 1.0 || scaleY < 1.0)
+					{
+						 double scale = wxMin(scaleX, scaleY);
+						int newWidth = std::max<int>(1, (int) (scale * image.GetWidth()));
+						int newHeight = std::max<int>(1, (int) (scale * image.GetHeight()));
+						 image.Rescale(newWidth, newHeight);
+					}
+					m_cachedBitmap = wxBitmap(image);
+					ctrl->Refresh(true);
+			  }
+		 }
+		 return NULL;
+	 }
+	 wxBitmap& m_cachedBitmap;
+	 wxString m_filename;
+	 wxThumbnailCtrl* ctrl;
+ };
+
+wxImageThumbnailItem::~wxImageThumbnailItem()
+{
+	if (pThread != NULL) {
+		pThread->Wait();
+		delete pThread;
+	}
+}
+
 bool wxImageThumbnailItem::Load(wxThumbnailCtrl* ctrl, bool forceLoad)
 {
     if (m_cachedBitmap.Ok() && !forceLoad)
         return true;
 
-    if (wxFileExists(m_filename))
-    {
-        wxImage image;
-        if (image.LoadFile(m_filename, wxBITMAP_TYPE_ANY))
-        {
-            wxSize thumbnailSize = ctrl->GetThumbnailImageSize();
-            double scaleX = ((double) thumbnailSize.x)/((double) image.GetWidth());
-            double scaleY = ((double) thumbnailSize.y)/((double) image.GetHeight());
-
-            if (scaleX < 1.0 || scaleY < 1.0)
-            {
-                double scale = wxMin(scaleX, scaleY);
-				int newWidth = std::max<int>(1, (int) (scale * image.GetWidth()));
-				int newHeight = std::max<int>(1, (int) (scale * image.GetHeight()));
-                image.Rescale(newWidth, newHeight);
-            }
-            m_cachedBitmap = wxBitmap(image);
-
-            return true;
-        }
-    }
+	 
+	 pThread = new LoadThread(m_filename, m_cachedBitmap, ctrl);
+	 if (pThread->Create() == wxTHREAD_NO_ERROR) {
+		 pThread->Run();
+	 } else {
+		 delete pThread;
+	 }
     return false;
 }
 
