@@ -1,10 +1,10 @@
 /*
- *  $Id: lightvisualizatorcontroller.cpp 4365 2011-11-03 14:01:58Z carlos $
- *  Proyecto Ginkgo
- *
- *  Copyright 2008 MetaEmotion S.L. All rights reserved.
- *
- */
+*  $Id: lightvisualizatorcontroller.cpp 4555 2012-01-17 10:03:03Z tovar $
+*  Proyecto Ginkgo
+*
+*  Copyright 2008 MetaEmotion S.L. All rights reserved.
+*
+*/
 #include <api/globals.h>
 #include <vector>
 #include <set>
@@ -61,7 +61,7 @@ namespace LightVisualizator {
 		//returns true if this mode supports this pair of modality-transfer syntax
 		virtual bool SupportsModalityFile(const std::string &modalidad, const std::string& transferSyntax){
 			for(TipoListaModalidades::iterator it = m_listaModalidades.begin(); it!= m_listaModalidades.end(); ++it){
-				if((*it) == modalidad){					
+				if((*it) == modalidad && !(transferSyntax == "1.2.840.10008.1.2.4.100" || transferSyntax == "1.2.840.10008.1.2.4.101")){
 					return true;
 				}
 			}
@@ -78,22 +78,9 @@ namespace LightVisualizator {
 		}
 
 		m_pEntorno = pEntorno;
-		//name
-		m_Nombre = EXT_DESCRIPTION;
-		//copyright
-		m_CopyRight = EXT_COPYRIGHT;
-		//author
-		m_Author = EXT_PROVIDER;
-		m_VersionMayor = EXT_VERSION;
-		m_VersionMinor = EXT_SUBVERSION;
-		m_VersionRelease = EXT_RELEASE;
-		m_CodeName = EXT_CODENAME;
-		
-		std::ostringstream ostr;
-		ostr << m_VersionMayor << "." << m_VersionMinor << "." << m_VersionRelease << " " << m_CodeName;
-		m_Version = ostr.str();
 
-		
+
+
 		GNC::GCS::IControladorHerramientas* cH = pEntorno->GetControladorHerramientas();
 		cH->RegistrarHerramienta(new LightVisualizator::ToolWindowLevelLight());
 	}
@@ -116,17 +103,12 @@ namespace LightVisualizator {
 		for (int i = 0; i < m_ListaModos.size(); ++i) {
 			delete m_ListaModos[i];
 		}
-
-		if (m_Bitmap != NULL) {
-			delete m_Bitmap;
-			m_Bitmap = NULL;
-		}
 	}
 
 	//It's mandatory to implement this method, here you have to register views of this module (Controller modes), this will register LightVisualizatorView .
-	 void LightVisualizatorController::RegistrarVistas()
-	 {
-		 GNC::GCS::ModoControlador::TipoListaModalidades listaModalidades;
+	void LightVisualizatorController::RegistrarVistas()
+	{
+		GNC::GCS::ModoControlador::TipoListaModalidades listaModalidades;
 		listaModalidades.push_back(std::string("MR")); //resonancia
 		listaModalidades.push_back(std::string("CR")); //computed radiography
 		listaModalidades.push_back(std::string("US")); //ultrasonido
@@ -179,7 +161,7 @@ namespace LightVisualizator {
 		GNC::GCS::ModoControlador::TipoListaUIDsImportacion listaUIDsImportacion;
 
 		m_ListaModos.push_back(new LightVisualizatorControllerMode(0, EXT_DESCRIPTION, listaModalidades, listaUIDsImportacion, true));
-	 }
+	}
 
 
 	//it's call by Ginkgo CADx core when this extension has to open a series with required module and required Diagnostic Study UID, returns an IVista (view)
@@ -283,7 +265,3 @@ namespace LightVisualizator {
 	{
 	}
 };
-
-
-
-
