@@ -1,5 +1,5 @@
 /*
- *  $Id: glightvisualizatorview.cpp 3922 2011-07-06 12:51:23Z tovar $
+ *  $Id: glightvisualizatorview.cpp 4468 2011-12-09 10:02:00Z carlos $
  *  Proyecto Ginkgo
  *
  *  Copyright 2008 MetaEmotion S.L. All rights reserved.
@@ -287,7 +287,7 @@ namespace LightVisualizator {
 				//firstly calculate window/level
 				if (AutoWindowLevel) {
 					if (HasDefaultWindowLevel()) {
-						GNC::GCS::IContratoWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
+						GNC::GCS::IContractWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
 						CurrentWindow = wl.m_window;
 						CurrentLevel = wl.m_level;
 					} else {
@@ -724,7 +724,7 @@ namespace LightVisualizator {
 			if (vid != (unsigned int)View->GetEstudio()->IndiceFicheroActivo || force) {
 				View->GetEstudio()->SetIndiceActivo(vid);
 
-				GNC::GCS::IContratoWindowLevel::Setup(*View->GetEstudio()->GetTagsImagenDeImagenActiva());
+				GNC::GCS::IContractWindowLevel::Setup(*View->GetEstudio()->GetTagsImagenDeImagenActiva());
 
 				SetZoom(m_zoom, true);
 				GNC::GCS::Eventos::EventoModificacionImagen* pEvt = new GNC::GCS::Eventos::EventoModificacionImagen(View,GNC::GCS::Eventos::EventoModificacionImagen::SliceCambiado, -1, true);
