@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: visualizatorcontroller.cpp 4365 2011-11-03 14:01:58Z carlos $
+ *  $Id: visualizatorcontroller.cpp 4555 2012-01-17 10:03:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -59,6 +59,32 @@
 #include <visualizator/resources/aprimresourcemanager.h>
 #include "../exportacion/tagsprivados.h"
 
+namespace GNKVisualizator {
+	class GNKVisualizatorControllerMode: public GNC::GCS::ModoControlador
+	{
+	public:
+		//GNKVisualizatorControllerMode: defines ways of Dicom viewing of this extension
+		//id: unique in this controller
+		//listaModalidades: modality supporting list
+		//abreSeriesSueltas: true if it opens series, false if it opens studies
+		//bitmap: bitmap of this mode (for visualization purposes)
+		GNKVisualizatorControllerMode(int id, const std::string& descripcion, TipoListaModalidades listaModalidades, TipoListaUIDsImportacion listaUIDsImportacion, bool abreSeriesSueltas, wxBitmap * bitmap = NULL):GNC::GCS::ModoControlador(id, descripcion, listaModalidades, listaUIDsImportacion, abreSeriesSueltas, bitmap)
+		{
+		}
+		~GNKVisualizatorControllerMode() {}
+
+		//returns true if this mode supports this pair of modality-transfer syntax
+		virtual bool SupportsModalityFile(const std::string &modalidad, const std::string& transferSyntax){
+			for(TipoListaModalidades::iterator it = m_listaModalidades.begin(); it!= m_listaModalidades.end(); ++it){
+				if((*it) == modalidad && !(transferSyntax == "1.2.840.10008.1.2.4.100" || transferSyntax == "1.2.840.10008.1.2.4.101")){
+					return true;
+				}
+			}
+			return false;
+		}
+	};
+}
+
 
 /* Constructor */
 GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::GCS::IEntorno* pEntorno) : GNC::GCS::IControladorModulo(pEntorno, EXT_SID, 0)
@@ -83,19 +109,9 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.vista2d",_Std("Medical viewer"),"guardar cambios",_Std("Save changes with medical viewer"), true, "", true);
 
 
-	m_pEntorno = pEntorno;
-	m_Nombre = EXT_DESCRIPTION;
+	m_pEntorno = pEntorno;	
 	m_ImporterDescription = _Std("Default importer");
-	m_CopyRight = "(c) 2009 MetaEmotion S.L.";
-	m_Author = "MetaEmotion S.L.";
-	m_VersionMayor   = EXT_VERSION;
-	m_VersionMinor   = EXT_SUBVERSION;
-	m_VersionRelease = EXT_RELEASE;
-	m_CodeName       = EXT_CODENAME;
-	std::ostringstream oversion;
-	oversion << EXT_VERSION << "."<< EXT_SUBVERSION << "." << EXT_RELEASE;
-	m_Version = oversion.str();
-
+	
 	// Codigos LOINC de los informes de A. Primaria.
 	m_ListaInformes.push_back(GNC::GCS::IdHL7("TUID" + m_UID, "0", _Std("Ginkgo CADx Image Report"), "LN", "", "","v1.0"));
 
@@ -223,7 +239,7 @@ void GNKVisualizator::ControladorAtencionPrimaria::RegistrarVistas()
 	listaUIDsImportacion.push_back(EXT_IMPORTER_SID);
 
 	if(m_pEntorno->GetControladorPermisos()->Get("atencionprimaria", "vista2d")) {
-		m_ListaModos.push_back(new GNC::GCS::ModoControlador(idModo++, _Std("Medical Image Viewer"), listaModalidades, listaUIDsImportacion, true));
+		m_ListaModos.push_back(new GNKVisualizatorControllerMode(idModo++, _Std("Medical Image Viewer"), listaModalidades, listaUIDsImportacion, true));
 	}
 
 	listaModalidades.clear();
