@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: pasodatosgenerales.cpp 4303 2011-10-18 10:31:44Z tovar $
+ *  $Id: pasodatosgenerales.cpp 4516 2012-01-12 12:18:40Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -72,7 +72,7 @@ namespace GNKVisualizator {
 
 //region "Metodos heredados de Ipasowizard"
 
-		void PasoDatosGenerales::Attach(wxSizer *sizer)
+		bool PasoDatosGenerales::Attach()
 		{
 			//se mira a ver si los ficheros del panel estan correctamente etiquetados...
 			if(m_pDatosPersistentes->m_pModeloImportacion.IsValid()) {
@@ -215,17 +215,9 @@ namespace GNKVisualizator {
 				}
 			}
 
-			Show(true);
-
-			sizer->Add(this,10, wxEXPAND);
-			this->GetParent()->Layout();
+			return true;
 		}
 
-		void PasoDatosGenerales::Detach(wxSizer *sizer){
-			Hide();
-			sizer->Detach(this);
-			sizer->GetContainingWindow()->Layout();
-		}
 
 		std::string PasoDatosGenerales::GetTitle(){
 			return _Std("Overview data of DICOM files");
@@ -366,97 +358,6 @@ namespace GNKVisualizator {
 				}
 			}
 
-			void PasoDatosGenerales::OnCheckBoxReferenciarEstudioClick(wxCommandEvent &event){
-				if(m_pCheckReferenciarEstudio->IsChecked()){
-					//buscar fichero DCM
-					wxFileDialog referenciarDialogo (this, _("Refer Study"), wxT(""), wxT(""), _("DICOM Files (*.dcm)|*.dcm"), wxFD_SAVE);
-					int response = referenciarDialogo.ShowModal();
-					if (response == wxID_OK) {
-						wxString fPath = referenciarDialogo.GetPath();
-						std::string filePath(fPath.ToUTF8());
-
-						//leer dicom...
-						GIL::DICOM::IDICOMManager*	pDICOMManager= m_pEntorno->GetPACSController()->CrearInstanciaDeDICOMManager();
-						GIL::DICOM::TipoJerarquia base;
-						pDICOMManager->CargarFichero(filePath, base);
-
-						std::string tag;
-						if(base.getTag(std::string("0008|0020"),tag)){//fecha estudio
-							wxDateTime fecha;
-							fecha.ParseFormat(wxString::FromUTF8(tag.c_str()),wxT("%Y%m%d"));
-							if(fecha.IsValid()){
-								m_pEstudioFecha->SetValue(fecha);
-							}
-						}
-
-						if(base.getTag(std::string("0008|0030"),tag)){//hora estudio
-							wxDateTime fecha;
-							fecha.ParseFormat(wxString::FromUTF8(tag.c_str()),wxT("%H%M%S"));
-							if(fecha.IsValid()){
-								m_pEstudioTime->SetDateTimeValue(fecha);
-							}
-						}
-
-						if(base.getTag(std::string("0008|1030"),tag)){//descripcion estudio
-							m_pEstudioDescripcion->SetValue(wxString::FromUTF8(tag.c_str()));
-						}
-
-						if(base.getTag(std::string("0020|000d"),tag)){//uid estudio
-							m_pDatosPersistentes->StudyInstanceUID=tag;
-						}
-
-						if(base.getTag(std::string("0010|0010"),tag)){//nombre del paciente
-							if(tag.find_first_of('^')!=std::string::npos){
-								m_pDatosPersistentes->PacienteNombre = tag.substr(0,tag.find_first_of('^'));
-								tag = tag.substr(tag.find_first_of('^')+1,tag.size()-1);
-								if(tag.find_first_of('^')!=std::string::npos){
-									m_pDatosPersistentes->PacienteApellido1 = tag.substr(0,tag.find_first_of('^'));
-									tag = tag.substr(tag.find_first_of('^')+1,tag.size()-1);
-									if(tag.find_first_of('^')!=std::string::npos){
-										m_pDatosPersistentes->PacienteApellido2 = tag.substr(0,tag.find_first_of('^'));
-										tag = tag.substr(tag.find_first_of('^')+1,tag.size()-1);
-									}
-								}
-							}
-						}
-
-						if(base.getTag(std::string("0010|0020"),tag)){//id del paciente
-							m_pDatosPersistentes->PacienteIdentificador=tag;
-						}
-
-						if(base.getTag(std::string("0010|0030"),tag)){//fecha nacimiento
-							m_pDatosPersistentes->PacienteFechaNacimiento=tag;
-						}
-
-						if(base.getTag(std::string("0010|1010"),tag)){//edad
-							m_pDatosPersistentes->PacienteEdad=tag;
-						}
-
-						if(base.getTag(std::string("0010|1020"),tag)){//talla
-							m_pDatosPersistentes->PacienteAltura=tag;
-						}
-
-						if(base.getTag(std::string("0010|1030"),tag)){//peso
-							m_pDatosPersistentes->PacientePeso=tag;
-						}
-
-						if(base.getTag(std::string("0010|0040"),tag)){//sexo
-							m_pDatosPersistentes->PacienteSexo=tag;
-						}
-
-						m_pEntorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
-
-						//EnableComponents(false);
-					} else {
-						m_pCheckReferenciarEstudio->SetValue(false);
-					}
-				} else{
-					m_pDatosPersistentes->StudyInstanceUID="";
-					//EnableComponents(true);
-				}
-
-			}
-
 			void PasoDatosGenerales::EnableComponents(bool enable){
 				m_pEstudioDescripcion->Enable(enable);
 				m_pEstudioFecha->Enable(enable);
@@ -494,114 +395,6 @@ namespace GNKVisualizator {
 			}
 		}
 
-		void PasoDatosGenerales::OnCheckBoxReferenciarSerieClick(wxCommandEvent &event){
-			if(m_pCheckReferenciarSerie->IsChecked()){
-				//buscar fichero DCM
-				wxFileDialog referenciarDialogo (this, _("Series reference"), wxT(""), wxT(""), _("DICOM Files (*.dcm) | *.dcm"), wxFD_SAVE);
-				int response = referenciarDialogo.ShowModal();
-				if (response == wxID_OK) {
-					wxString fPath = referenciarDialogo.GetPath();
-					std::string filePath(fPath.ToUTF8());
-
-					//leer dicom...
-					GIL::DICOM::IDICOMManager*	pDICOMManager= m_pEntorno->GetPACSController()->CrearInstanciaDeDICOMManager();
-					GIL::DICOM::TipoJerarquia base;
-					pDICOMManager->CargarFichero(filePath, base);
-					std::string tag;
-
-					//se pillan los tags ...
-					if(base.getTag(std::string("0008|0021"),tag)){//fecha serie
-						wxDateTime fecha;
-						fecha.ParseFormat(wxString::FromUTF8(tag.c_str()),wxT("%Y%m%d"));
-						if(fecha.IsValid()){
-							m_pSerieFecha->SetValue(fecha);
-						}
-					}
-
-					if(base.getTag(std::string("0008|0031"),tag)){//hora serie
-						wxDateTime fecha;
-						fecha.ParseFormat(wxString::FromUTF8(tag.c_str()),wxT("%H%M%S"));
-						if(fecha.IsValid()){
-							m_pSerieTime->SetDateTimeValue(fecha);
-						}
-					}
-
-					if(base.getTag(std::string("0008|103e"),tag)){//descripcion serie
-						m_pSerieDescripcion->SetValue(wxString::FromUTF8(tag.c_str()));
-					}
-
-					if(base.getTag(std::string("0008|0020"),tag)){//fecha estudio
-						m_pDatosPersistentes->EstudioFecha = tag;
-					}
-
-					if(base.getTag(std::string("0008|0030"),tag)){//hora estudio
-						m_pDatosPersistentes->EstudioHora = tag;
-					}
-
-					if(base.getTag(std::string("0008|1030"),tag)){//descripcion estudio
-						m_pDatosPersistentes->EstudioDescripcion = tag;
-					}
-
-					if(base.getTag(std::string("0020|000d"),tag)){//uid estudio
-						m_pDatosPersistentes->StudyInstanceUID=tag;
-					}
-
-					if(base.getTag(std::string("0020|000e"),tag)){//uid serie
-						m_pDatosPersistentes->SerieUID=tag;
-					}
-
-					if(base.getTag(std::string("0010|0010"),tag)){//nombre del paciente
-						if(tag.find_first_of('^')!=std::string::npos){
-							m_pDatosPersistentes->PacienteNombre = tag.substr(0,tag.find_first_of('^'));
-							tag = tag.substr(tag.find_first_of('^')+1,tag.size()-1);
-							if(tag.find_first_of('^')!=std::string::npos){
-								m_pDatosPersistentes->PacienteApellido1 = tag.substr(0,tag.find_first_of('^'));
-								tag = tag.substr(tag.find_first_of('^')+1,tag.size()-1);
-								if(tag.find_first_of('^')!=std::string::npos){
-									m_pDatosPersistentes->PacienteApellido2 = tag.substr(0,tag.find_first_of('^'));
-									tag = tag.substr(tag.find_first_of('^')+1,tag.size()-1);
-								}
-							}
-						}
-					}
-
-					if(base.getTag(std::string("0010|0020"),tag)){//id del paciente
-						m_pDatosPersistentes->PacienteIdentificador=tag;
-					}
-
-					if(base.getTag(std::string("0010|0030"),tag)){//fecha nacimiento
-						m_pDatosPersistentes->PacienteFechaNacimiento=tag;
-					}
-
-					if(base.getTag(std::string("0010|1010"),tag)){//edad
-						m_pDatosPersistentes->PacienteEdad=tag;
-					}
-
-					if(base.getTag(std::string("0010|1020"),tag)){//talla
-						m_pDatosPersistentes->PacienteAltura=tag;
-					}
-
-					if(base.getTag(std::string("0010|1030"),tag)){//peso
-						m_pDatosPersistentes->PacientePeso=tag;
-					}
-
-					if(base.getTag(std::string("0010|0040"),tag)){//sexo
-						m_pDatosPersistentes->PacienteSexo=tag;
-					}
-
-					m_pEntorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
-
-					//EnableComponents(false);
-				} else {
-					m_pCheckReferenciarSerie->SetValue(false);
-				}
-			} else{
-				m_pDatosPersistentes->SerieUID="";
-				//EnableComponents(true);
-			}
-
-		}
-
 		std::string PasoDatosGenerales::GetSerieFecha(){
 			if(m_pSerieFecha->GetValue().IsValid()){
 				return std::string(m_pSerieFecha->GetValue().Format(wxT("%Y%m%d")).ToUTF8());
