@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientamapacolor.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: herramientamapacolor.cpp 4299 2011-10-17 08:58:25Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -26,7 +26,7 @@
 #include <vtkVISUManagement/vtkLookupTableManager.h>
 #include <vtkginkgoimageviewer.h>
 
-#include "../../recursos/aprimresourcemanager.h"
+#include <visualizator/resources/aprimresourcemanager.h>
 
 
 #define INVERTIR_COLORES  4100
