@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vista2d.cpp 4401 2011-11-11 13:25:38Z carlos $
+ *  $Id: vista2d.cpp 4501 2011-12-20 11:13:41Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -30,11 +30,13 @@
 #include <eventos/eventosginkgo.h>
 
 #include <export/iherramientapuntero.h>
-#include <export/iherramientaslider.h>
+#include <export/itoolzoom.h>
+#include <export/itoolpan.h>
+#include <export/itoolslider.h>
+#include <export/itoolwindowlevel.h>
 #include <export/iherramientaregla.h>
 #include <export/iherramientaangulo.h>
 #include <export/iherramientanota.h>
-#include <export/iherramientawindowlevel.h>
 #include <export/iherramientalupa.h>
 #include <export/iherramientamarcado.h>
 #include <export/iherramientarejillametrica.h>
@@ -83,7 +85,9 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();
 
 	GNC::GCS::IHerramientaPuntero*             hPuntero = NULL;
-	GNC::GCS::IHerramientaSlider*              hSlider = NULL;
+	GNC::GCS::IToolZoom*                       hZoom = NULL;
+	GNC::GCS::IToolPan*                        hPan = NULL;
+	GNC::GCS::IToolSlider*                     hSlider = NULL;
 	GNC::GCS::IHerramientaRegla*               hRegla = NULL;
 	GNC::GCS::IHerramientaAngulo*              hAngulo = NULL;
 	GNC::GCS::IHerramientaNota*                hNota = NULL;
@@ -105,10 +109,20 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 			contratablevtk->Subscribir(this, GVista);
 		}
 		
-		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaSlider>(GNC::GCS::IHerramientaSlider::ID);
+		hZoom = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolZoom>(GNC::GCS::IToolZoom::ID);
+		if (hZoom != NULL) {
+			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hZoom)->Subscribir(this, GVista);
+		}
+		
+		hPan = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolPan>(GNC::GCS::IToolPan::ID);
+		if (hPan != NULL) {
+			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hPan)->Subscribir(this, GVista);
+		}
+		
+		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolSlider>(GNC::GCS::IToolSlider::ID);
 		if (hSlider != NULL) {
 			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hSlider)->Subscribir(this, GVista);
-			((GNC::GCS::IContratable<GNC::GCS::IContratoSlider>*) hSlider)->Subscribir(this, this);
+			((GNC::GCS::IContratable<GNC::GCS::IContractSlider>*) hSlider)->Subscribir(this, this);
 		}
 
 		// Subscribimos la vista al contrato de regla
@@ -211,20 +225,22 @@ GNKVisualizator::Vista2D::~Vista2D()
 
 	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();
 	GNC::GCS::IHerramientaPuntero*            hPuntero = NULL;
-	GNC::GCS::IHerramientaSlider*             hSlider = NULL;
+	GNC::GCS::IToolZoom*                      hZoom = NULL;
+	GNC::GCS::IToolPan*                       hPan = NULL;
+	GNC::GCS::IToolSlider*                    hSlider = NULL;
 	GNC::GCS::IHerramientaRegla*              hRegla = NULL;
 	GNC::GCS::IHerramientaAngulo*             hAngulo = NULL;
 	GNC::GCS::IHerramientaNota*               hNota = NULL;
-	GNC::GCS::IHerramientaWindowLevel*        hWindowLevel = NULL;
+	GNC::GCS::IToolWindowLevel*               hWindowLevel = NULL;
 	GNC::GCS::IHerramientaAnotacionesEsquina* hAnotacionesEsquina = NULL;
 	GNC::GCS::IHerramientaLupa*               hLupa = NULL;
 	GNC::GCS::IHerramientaMarcado*            hMarcado       = NULL;
 	GNC::GCS::IHerramientaRejillaMetrica*     hRejilla = NULL;
 	GNC::GCS::IHerramientaReset*              hReset = NULL;
-	GNC::GCS::IHerramientaInterpolate*			 hInterpolate = NULL;
+	GNC::GCS::IHerramientaInterpolate*			hInterpolate = NULL;
 	GNC::GCS::IHerramientaLayoutVentana*      hHerramientaLayoutVentana = NULL;
-	GNKVisualizator::IHerramientaOverlays*          hOverlays = NULL;
-	GNKVisualizator::IHerramientaMapaColor*         hMapa = NULL;
+	GNKVisualizator::IHerramientaOverlays*    hOverlays = NULL;
+	GNKVisualizator::IHerramientaMapaColor*   hMapa = NULL;
 
 	try {
 		// Desubscribimos la vista al contrato de puntero
@@ -234,11 +250,21 @@ GNKVisualizator::Vista2D::~Vista2D()
 			contratablevtk->DesSubscribirsLosDeLaVista(this);
 		}
 		
+		hZoom = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolZoom>(GNC::GCS::IToolZoom::ID);
+		if (hZoom != NULL) {
+			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hZoom)->DesSubscribirsLosDeLaVista(this);
+		}
+		
+		hPan = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolPan>(GNC::GCS::IToolPan::ID);
+		if (hPan != NULL) {
+			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hPan)->DesSubscribirsLosDeLaVista(this);
+		}
+		
 		// Desubscribimos la vista al contrato de slider
-		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaSlider>(GNC::GCS::IHerramientaSlider::ID);
+		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolSlider>(GNC::GCS::IToolSlider::ID);
 		if (hSlider != NULL) {
 			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hSlider)->DesSubscribirsLosDeLaVista(this);
-			((GNC::GCS::IContratable<GNC::GCS::IContratoSlider>*) hSlider)->DesSubscribirsLosDeLaVista(this);
+			((GNC::GCS::IContratable<GNC::GCS::IContractSlider>*) hSlider)->DesSubscribirsLosDeLaVista(this);
 		}
 
 		// Desubscribimos la vista al contrato de puntero
@@ -260,10 +286,10 @@ GNKVisualizator::Vista2D::~Vista2D()
 		}
 
 		// dessuscribimos la vista al contrato de hWindowLevel
-		hWindowLevel = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaWindowLevel>(GNC::GCS::IHerramientaWindowLevel::ID);
+		hWindowLevel = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolWindowLevel>(GNC::GCS::IToolWindowLevel::ID);
 		if (hWindowLevel != NULL) {
 			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*)hWindowLevel)->DesSubscribirsLosDeLaVista(this);
-			((GNC::GCS::IContratable<GNC::GCS::IContratoWindowLevel>*)hWindowLevel)->DesSubscribirsLosDeLaVista(this);
+			((GNC::GCS::IContratable<GNC::GCS::IContractWindowLevel>*)hWindowLevel)->DesSubscribirsLosDeLaVista(this);
 		}
 
 		// dessuscribimos la vista al contrato de hLupa
