@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: gvistacompleja.cpp 4375 2011-11-04 13:49:41Z tovar $
+ *  $Id: gvistacompleja.cpp 4492 2011-12-14 11:14:13Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -47,7 +47,7 @@
 #include <export/iherramientaregla.h>
 #include <export/iherramientaangulo.h>
 #include <export/iherramientanota.h>
-#include <export/iherramientawindowlevel.h>
+#include <export/itoolwindowlevel.h>
 #include <export/iherramientalupa.h>
 #include <export/iherramientamarcado.h>
 #include <export/iherramientarejillametrica.h>
@@ -341,7 +341,7 @@ void GVistaCompleja::IniciarPipeline()
 	//esto es correcto porque en la creacion se mete siempre una vista simple
 
 
-	GNC::GCS::IContratoWindowLevel::Setup(*IVista->GetEstudio()->GetTagsImagenDeImagenActiva());
+	GNC::GCS::IContractWindowLevel::Setup(*IVista->GetEstudio()->GetTagsImagenDeImagenActiva());
 
 
 	///////////recorrer las vistas simples y pasarles las imagenes
@@ -354,7 +354,7 @@ void GVistaCompleja::IniciarPipeline()
 
 			//despues se establece el WL
 			if (HasDefaultWindowLevel()) {
-				GNC::GCS::IContratoWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
+				GNC::GCS::IContractWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
 				pvs->ViewImage2D->SetDefaultWindowLevel(wl.m_window, wl.m_level);
 			}
 			else {
@@ -371,14 +371,14 @@ void GVistaCompleja::IniciarPipeline()
 
 	//contrato window level, hay que preguntarle al viewer de la primera vista porque el estudioatencionprimaria no tiene viewer
 	GNC::GCS::IControladorHerramientas* cH = IVista->GetEstudio()->Entorno->GetControladorHerramientas();
-	GNC::GCS::IHerramientaWindowLevel* hWindowLevel = NULL;
+	GNC::GCS::IToolWindowLevel* hWindowLevel = NULL;
 	try {
 		if(m_VistasSimples[0]->ViewImage2D->GetNumberOfComponents() == 1){
 			// Subscribimos la vista al contrato de hWindowLevel
-			hWindowLevel = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaWindowLevel>(GNC::GCS::IHerramientaWindowLevel::ID);
+			hWindowLevel = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolWindowLevel>(GNC::GCS::IToolWindowLevel::ID);
 			if (hWindowLevel != NULL) {
 				((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*)hWindowLevel)->Subscribir(IVista, this);
-				((GNC::GCS::IContratable<GNC::GCS::IContratoWindowLevel>*)hWindowLevel)->Subscribir(IVista, this);
+				((GNC::GCS::IContratable<GNC::GCS::IContractWindowLevel>*)hWindowLevel)->Subscribir(IVista, this);
 			}
 		}
 	}
@@ -774,7 +774,7 @@ void GVistaCompleja::OnKeyDown( wxKeyEvent& event )
 			{
 				GNC::GCS::ISolicitadorCambioHerramienta* solicitador = dynamic_cast<GNC::GCS::ISolicitadorCambioHerramienta*>(IVista->GetEstudio()->Entorno->GetControladorHerramientas());
 				if(solicitador!=NULL){
-					solicitador->SolicitarActivacion(IVista->GetEstudio()->Entorno->GetControladorHerramientas()->ObtenerHerramienta(GNC::GCS::IHerramientaPuntero::ID));
+					solicitador->SolicitarActivacion(IVista->GetEstudio()->Entorno->GetControladorHerramientas()->ObtenerHerramienta(GNC::GCS::IHerramientaPuntero::ID), event.ShiftDown() ? GNC::GCS::TriggerButton().EnableRight() : GNC::GCS::TriggerButton().EnableLeft());
 				}
 			}
 			break;
@@ -792,21 +792,21 @@ void GVistaCompleja::OnMouseWheel(wxMouseEvent& event)
 			for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); it++) {
 				if(event.GetWheelRotation() > 0)
 				{
-					(*it)->GoToTSlice(-1);
+					(*it)->GoToTSlice(1);
 				}
 				else
 				{
-					(*it)->GoToTSlice(1);
+					(*it)->GoToTSlice(-1);
 				}
 			}
 		} else {
 			if(event.GetWheelRotation() > 0)
 			{
-				GoToSlice(1);
+				GoToSlice(-1);
 			}
 			else
 			{
-				GoToSlice(-1);
+				GoToSlice(1);
 			}
 		}
 	} 
@@ -1126,7 +1126,7 @@ void GVistaCompleja::GoToSlice(int pos, bool relativa, bool propagar, bool rende
 	m_posicion = posicion;
 
 	//se reestablece el window/level antes del evento de modificación porque ese evento lo escucha la herramienta
-	GNC::GCS::IContratoWindowLevel::Setup(*IVista->GetEstudio()->GetTagsImagenDeImagenActiva());
+	GNC::GCS::IContractWindowLevel::Setup(*IVista->GetEstudio()->GetTagsImagenDeImagenActiva());
 
 	//se le indica al manager el vid
 	IVista->GetEstudio()->IndiceFicheroActivo = posicion;
@@ -1135,10 +1135,10 @@ void GVistaCompleja::GoToSlice(int pos, bool relativa, bool propagar, bool rende
 
 		//despues se establece el WL
 		if (HasCurrentWindowLevel()) {
-			GNC::GCS::IContratoWindowLevel::WindowLevel wl = GetCurrentWindowLevel();
+			GNC::GCS::IContractWindowLevel::WindowLevel wl = GetCurrentWindowLevel();
 			(*it)->ViewImage2D->SetDefaultWindowLevel(wl.m_window, wl.m_level);
 		} else if (HasDefaultWindowLevel()) {
-			GNC::GCS::IContratoWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
+			GNC::GCS::IContractWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
 			(*it)->ViewImage2D->SetDefaultWindowLevel(wl.m_window, wl.m_level);			
 		} else {
 			(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
@@ -1162,6 +1162,11 @@ void GVistaCompleja::GoToSlice(int pos, bool relativa, bool propagar, bool rende
 	}
 }
 
+int GVistaCompleja::GetCurrentSlice()
+{
+	return m_posicion;
+}
+
 void GVistaCompleja::PreProcesarEvento(GNC::GCS::Eventos::IEvento* evt, GNC::GCS::IControladorEventos::TipoListaPunterosEventos& lista)
 {
 	if (evt == NULL) {
@@ -1303,7 +1308,7 @@ void GVistaCompleja::ProcesarEvento(GNC::GCS::Eventos::IEvento *evt)
 						for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); it++) {
 							if(pEvt->ResetWindowLevel()) {
 								if (HasDefaultWindowLevel()) {
-									GNC::GCS::IContratoWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
+									GNC::GCS::IContractWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
 									(*it)->ViewImage2D->SetDefaultWindowLevel(wl.m_window, wl.m_level);			
 								} else {
 									(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
