@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: gvistasimple.cpp 4335 2011-10-26 09:42:35Z tovar $
+ *  $Id: gvistasimple.cpp 4500 2011-12-20 08:00:51Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -661,6 +661,10 @@ void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Cont
 	os.precision(2);
 	os.fill('0');
 
+	double spacing[3] = {0.0, 0.0, 0.0};
+
+	bool hasSpacing = EstudioReferido->GetSpacingActiva(spacing[0], spacing[1], spacing[2]);
+
 	w->GetPosicion(posimagen);
 	{
 		double arrIm[2] = {posimagen.x, posimagen.y};
@@ -688,25 +692,41 @@ void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Cont
 			}
 			else {
 
-				if (area > (double)1000000.0f) {
-					os << area / (double)1000000.0f << " m²." << std::endl;
-				}
-				else if (area > (double)100.0f) {
-					os << area / (double)100.0f << " cm²." << std::endl;
+				if (hasSpacing) {
+					if (area > (double)1000000.0f) {
+						os << area / (double)1000000.0f << " m²." << std::endl;
+					}
+					else if (area > (double)100.0f) {
+						os << area / (double)100.0f << " cm²." << std::endl;
+					}
+					else if (area < 1.0f) {
+						os << area * (double)1000000.0f << " µm²." << std::endl;
+					}
+					else {
+						os << area << " mm²." << std::endl;
+					}
 				}
 				else {
-					os << area << " mm²." << std::endl;
+					os << area << "px²." << std::endl;
 				}
 			}
 			os << _Std("Perimeter : ");
-			if (perimetro > (double)1000.0f) {
-				os << perimetro / (double)1000.0f << " m.";
-			}
-			else if (perimetro > (double)10.0f) {
-				os << perimetro / (double)10.0f << " cm.";
+			if (hasSpacing) {
+				if (perimetro > (double)1000.0f) {
+					os << perimetro / (double)1000.0f << " m.";
+				}
+				else if (perimetro > (double)10.0f) {
+					os << perimetro / (double)10.0f << " cm.";
+				}
+				else if (perimetro < 1.0f) {
+					os << perimetro * (double)1000.0f << " µm." << std::endl;
+				}
+				else {
+					os << perimetro << " mm.";
+				}
 			}
 			else {
-				os << perimetro << " mm." ;
+				os << perimetro << " px.";
 			}
 		} else if(!w->DelimitaTendencia()){
 			//se imprime r = tal g = tal y b=tal
@@ -802,26 +822,42 @@ void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Cont
 				os << "indeterminada" << std::endl;
 			}
 			else {
-				if (area > (double)1000000.0f) {
-					os << area / (double)1000000.0f << " m²." << std::endl;
-				}
-				else if (area > (double)100.0f) {
-					os << area / (double)100.0f << " cm²." << std::endl;
+				if (hasSpacing) {
+					if (area > (double)1000000.0f) {
+						os << area / (double)1000000.0f << " m²." << std::endl;
+					}
+					else if (area > (double)100.0f) {
+						os << area / (double)100.0f << " cm²." << std::endl;
+					}
+					else if (area < 1.0f) {
+						os << area * (double)1000000.0f << " µm²." << std::endl;
+					}
+					else {
+						os << area << " mm²." << std::endl;
+
+					}
 				}
 				else {
-					os << area << " mm²." << std::endl;
-
+					os << area << " px²." << std::endl;
 				}
 			}
 			os << _Std("Perimeter:");
-			if (perimetro > (double)1000.0f) {
-				os << perimetro / (double)1000.0f << " m." << std::endl;
-			}
-			else if (perimetro > (double)10.0f) {
-				os << perimetro / (double)10.0f << " cm." << std::endl;
+			if (hasSpacing) {
+				if (perimetro > (double)1000.0f) {
+					os << perimetro / (double)1000.0f << " m." << std::endl;
+				}
+				else if (perimetro > (double)10.0f) {
+					os << perimetro / (double)10.0f << " cm." << std::endl;
+				}
+				else if (perimetro < 1.0f) {
+					os << perimetro * (double)1000.0f << " µm." << std::endl;
+				}
+				else {
+					os << perimetro << " mm." << std::endl;
+				}
 			}
 			else {
-				os << perimetro << " mm." << std::endl;
+				os << perimetro << " px." << std::endl;
 			}
 			os << _Std("Rating: mean =") << media << _Std(", dev =") << varianza;
 		}
